;Testname=unoptimized; Arguments=-fbin -oriprel.bin -O0; Files=stdout stderr riprel.bin
;Testname=optimized;   Arguments=-fbin -oriprel.bin -Ox; Files=stdout stderr riprel.bin
	bits 64

	default abs

	mov al,[foo]
	mov bl,[foo]
	mov ax,[foo]
	mov bx,[foo]
	mov eax,[foo]
	mov ebx,[foo]
	mov rax,[foo]
	mov rbx,[foo]
	mov al,[0xaaaaaaaaaaaaaaaa]
	mov bl,[0xaaaaaaaaaaaaaaaa]
	mov ax,[0xaaaaaaaaaaaaaaaa]
	mov bx,[0xaaaaaaaaaaaaaaaa]
	mov eax,[0xaaaaaaaaaaaaaaaa]
	mov ebx,[0xaaaaaaaaaaaaaaaa]
	mov rax,[0xaaaaaaaaaaaaaaaa]
	mov rbx,[0xaaaaaaaaaaaaaaaa]
	mov al,[0xbbbbbbbb]
	mov bl,[0xbbbbbbbb]
	mov ax,[0xbbbbbbbb]
	mov bx,[0xbbbbbbbb]
	mov eax,[0xbbbbbbbb]
	mov ebx,[0xbbbbbbbb]
	mov rax,[0xbbbbbbbb]
	mov rbx,[0xbbbbbbbb]
	mov al,[0xffffffffcccccccc]
	mov bl,[0xffffffffcccccccc]
	mov ax,[0xffffffffcccccccc]
	mov bx,[0xffffffffcccccccc]
	mov eax,[0xffffffffcccccccc]
	mov ebx,[0xffffffffcccccccc]
	mov rax,[0xffffffffcccccccc]
	mov rbx,[0xffffffffcccccccc]

	mov al,[dword foo]
	mov bl,[dword foo]
	mov ax,[dword foo]
	mov bx,[dword foo]
	mov eax,[dword foo]
	mov ebx,[dword foo]
	mov rax,[dword foo]
	mov rbx,[dword foo]
	mov al,[dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword 0xaaaaaaaaaaaaaaaa]
	mov al,[dword 0xbbbbbbbb]
	mov bl,[dword 0xbbbbbbbb]
	mov ax,[dword 0xbbbbbbbb]
	mov bx,[dword 0xbbbbbbbb]
	mov eax,[dword 0xbbbbbbbb]
	mov ebx,[dword 0xbbbbbbbb]
	mov rax,[dword 0xbbbbbbbb]
	mov rbx,[dword 0xbbbbbbbb]
	mov al,[dword 0xffffffffcccccccc]
	mov bl,[dword 0xffffffffcccccccc]
	mov ax,[dword 0xffffffffcccccccc]
	mov bx,[dword 0xffffffffcccccccc]
	mov eax,[dword 0xffffffffcccccccc]
	mov ebx,[dword 0xffffffffcccccccc]
	mov rax,[dword 0xffffffffcccccccc]
	mov rbx,[dword 0xffffffffcccccccc]

	mov al,[qword foo]
	mov bl,[qword foo]
	mov ax,[qword foo]
	mov bx,[qword foo]
	mov eax,[qword foo]
	mov ebx,[qword foo]
	mov rax,[qword foo]
	mov rbx,[qword foo]
	mov al,[qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword 0xaaaaaaaaaaaaaaaa]
	mov al,[qword 0xbbbbbbbb]
	mov bl,[qword 0xbbbbbbbb]
	mov ax,[qword 0xbbbbbbbb]
	mov bx,[qword 0xbbbbbbbb]
	mov eax,[qword 0xbbbbbbbb]
	mov ebx,[qword 0xbbbbbbbb]
	mov rax,[qword 0xbbbbbbbb]
	mov rbx,[qword 0xbbbbbbbb]
	mov al,[qword 0xffffffffcccccccc]
	mov bl,[qword 0xffffffffcccccccc]
	mov ax,[qword 0xffffffffcccccccc]
	mov bx,[qword 0xffffffffcccccccc]
	mov eax,[qword 0xffffffffcccccccc]
	mov ebx,[qword 0xffffffffcccccccc]
	mov rax,[qword 0xffffffffcccccccc]
	mov rbx,[qword 0xffffffffcccccccc]

	mov al,[a64 foo]
	mov bl,[a64 foo]
	mov ax,[a64 foo]
	mov bx,[a64 foo]
	mov eax,[a64 foo]
	mov ebx,[a64 foo]
	mov rax,[a64 foo]
	mov rbx,[a64 foo]
	mov al,[a64 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 0xbbbbbbbb]
	mov bl,[a64 0xbbbbbbbb]
	mov ax,[a64 0xbbbbbbbb]
	mov bx,[a64 0xbbbbbbbb]
	mov eax,[a64 0xbbbbbbbb]
	mov ebx,[a64 0xbbbbbbbb]
	mov rax,[a64 0xbbbbbbbb]
	mov rbx,[a64 0xbbbbbbbb]
	mov al,[a64 0xffffffffcccccccc]
	mov bl,[a64 0xffffffffcccccccc]
	mov ax,[a64 0xffffffffcccccccc]
	mov bx,[a64 0xffffffffcccccccc]
	mov eax,[a64 0xffffffffcccccccc]
	mov ebx,[a64 0xffffffffcccccccc]
	mov rax,[a64 0xffffffffcccccccc]
	mov rbx,[a64 0xffffffffcccccccc]

	mov al,[a64 dword foo]
	mov bl,[a64 dword foo]
	mov ax,[a64 dword foo]
	mov bx,[a64 dword foo]
	mov eax,[a64 dword foo]
	mov ebx,[a64 dword foo]
	mov rax,[a64 dword foo]
	mov rbx,[a64 dword foo]
	mov al,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword 0xbbbbbbbb]
	mov bl,[a64 dword 0xbbbbbbbb]
	mov ax,[a64 dword 0xbbbbbbbb]
	mov bx,[a64 dword 0xbbbbbbbb]
	mov eax,[a64 dword 0xbbbbbbbb]
	mov ebx,[a64 dword 0xbbbbbbbb]
	mov rax,[a64 dword 0xbbbbbbbb]
	mov rbx,[a64 dword 0xbbbbbbbb]
	mov al,[a64 dword 0xffffffffcccccccc]
	mov bl,[a64 dword 0xffffffffcccccccc]
	mov ax,[a64 dword 0xffffffffcccccccc]
	mov bx,[a64 dword 0xffffffffcccccccc]
	mov eax,[a64 dword 0xffffffffcccccccc]
	mov ebx,[a64 dword 0xffffffffcccccccc]
	mov rax,[a64 dword 0xffffffffcccccccc]
	mov rbx,[a64 dword 0xffffffffcccccccc]

	mov al,[a64 qword foo]
	mov bl,[a64 qword foo]
	mov ax,[a64 qword foo]
	mov bx,[a64 qword foo]
	mov eax,[a64 qword foo]
	mov ebx,[a64 qword foo]
	mov rax,[a64 qword foo]
	mov rbx,[a64 qword foo]
	mov al,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword 0xbbbbbbbb]
	mov bl,[a64 qword 0xbbbbbbbb]
	mov ax,[a64 qword 0xbbbbbbbb]
	mov bx,[a64 qword 0xbbbbbbbb]
	mov eax,[a64 qword 0xbbbbbbbb]
	mov ebx,[a64 qword 0xbbbbbbbb]
	mov rax,[a64 qword 0xbbbbbbbb]
	mov rbx,[a64 qword 0xbbbbbbbb]
	mov al,[a64 qword 0xffffffffcccccccc]
	mov bl,[a64 qword 0xffffffffcccccccc]
	mov ax,[a64 qword 0xffffffffcccccccc]
	mov bx,[a64 qword 0xffffffffcccccccc]
	mov eax,[a64 qword 0xffffffffcccccccc]
	mov ebx,[a64 qword 0xffffffffcccccccc]
	mov rax,[a64 qword 0xffffffffcccccccc]
	mov rbx,[a64 qword 0xffffffffcccccccc]

	mov al,[a32 foo]
	mov bl,[a32 foo]
	mov ax,[a32 foo]
	mov bx,[a32 foo]
	mov eax,[a32 foo]
	mov ebx,[a32 foo]
	mov rax,[a32 foo]
	mov rbx,[a32 foo]
	mov al,[a32 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 0xbbbbbbbb]
	mov bl,[a32 0xbbbbbbbb]
	mov ax,[a32 0xbbbbbbbb]
	mov bx,[a32 0xbbbbbbbb]
	mov eax,[a32 0xbbbbbbbb]
	mov ebx,[a32 0xbbbbbbbb]
	mov rax,[a32 0xbbbbbbbb]
	mov rbx,[a32 0xbbbbbbbb]
	mov al,[a32 0xffffffffcccccccc]
	mov bl,[a32 0xffffffffcccccccc]
	mov ax,[a32 0xffffffffcccccccc]
	mov bx,[a32 0xffffffffcccccccc]
	mov eax,[a32 0xffffffffcccccccc]
	mov ebx,[a32 0xffffffffcccccccc]
	mov rax,[a32 0xffffffffcccccccc]
	mov rbx,[a32 0xffffffffcccccccc]

	mov al,[a32 dword foo]
	mov bl,[a32 dword foo]
	mov ax,[a32 dword foo]
	mov bx,[a32 dword foo]
	mov eax,[a32 dword foo]
	mov ebx,[a32 dword foo]
	mov rax,[a32 dword foo]
	mov rbx,[a32 dword foo]
	mov al,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword 0xbbbbbbbb]
	mov bl,[a32 dword 0xbbbbbbbb]
	mov ax,[a32 dword 0xbbbbbbbb]
	mov bx,[a32 dword 0xbbbbbbbb]
	mov eax,[a32 dword 0xbbbbbbbb]
	mov ebx,[a32 dword 0xbbbbbbbb]
	mov rax,[a32 dword 0xbbbbbbbb]
	mov rbx,[a32 dword 0xbbbbbbbb]
	mov al,[a32 dword 0xffffffffcccccccc]
	mov bl,[a32 dword 0xffffffffcccccccc]
	mov ax,[a32 dword 0xffffffffcccccccc]
	mov bx,[a32 dword 0xffffffffcccccccc]
	mov eax,[a32 dword 0xffffffffcccccccc]
	mov ebx,[a32 dword 0xffffffffcccccccc]
	mov rax,[a32 dword 0xffffffffcccccccc]
	mov rbx,[a32 dword 0xffffffffcccccccc]

	mov al,[a32 qword foo]
	mov bl,[a32 qword foo]
	mov ax,[a32 qword foo]
	mov bx,[a32 qword foo]
	mov eax,[a32 qword foo]
	mov ebx,[a32 qword foo]
	mov rax,[a32 qword foo]
	mov rbx,[a32 qword foo]
	mov al,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword 0xbbbbbbbb]
	mov bl,[a32 qword 0xbbbbbbbb]
	mov ax,[a32 qword 0xbbbbbbbb]
	mov bx,[a32 qword 0xbbbbbbbb]
	mov eax,[a32 qword 0xbbbbbbbb]
	mov ebx,[a32 qword 0xbbbbbbbb]
	mov rax,[a32 qword 0xbbbbbbbb]
	mov rbx,[a32 qword 0xbbbbbbbb]
	mov al,[a32 qword 0xffffffffcccccccc]
	mov bl,[a32 qword 0xffffffffcccccccc]
	mov ax,[a32 qword 0xffffffffcccccccc]
	mov bx,[a32 qword 0xffffffffcccccccc]
	mov eax,[a32 qword 0xffffffffcccccccc]
	mov ebx,[a32 qword 0xffffffffcccccccc]
	mov rax,[a32 qword 0xffffffffcccccccc]
	mov rbx,[a32 qword 0xffffffffcccccccc]

	mov al,[abs foo]
	mov bl,[abs foo]
	mov ax,[abs foo]
	mov bx,[abs foo]
	mov eax,[abs foo]
	mov ebx,[abs foo]
	mov rax,[abs foo]
	mov rbx,[abs foo]
	mov al,[abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs 0xaaaaaaaaaaaaaaaa]
	mov al,[abs 0xbbbbbbbb]
	mov bl,[abs 0xbbbbbbbb]
	mov ax,[abs 0xbbbbbbbb]
	mov bx,[abs 0xbbbbbbbb]
	mov eax,[abs 0xbbbbbbbb]
	mov ebx,[abs 0xbbbbbbbb]
	mov rax,[abs 0xbbbbbbbb]
	mov rbx,[abs 0xbbbbbbbb]
	mov al,[abs 0xffffffffcccccccc]
	mov bl,[abs 0xffffffffcccccccc]
	mov ax,[abs 0xffffffffcccccccc]
	mov bx,[abs 0xffffffffcccccccc]
	mov eax,[abs 0xffffffffcccccccc]
	mov ebx,[abs 0xffffffffcccccccc]
	mov rax,[abs 0xffffffffcccccccc]
	mov rbx,[abs 0xffffffffcccccccc]

	mov al,[abs dword foo]
	mov bl,[abs dword foo]
	mov ax,[abs dword foo]
	mov bx,[abs dword foo]
	mov eax,[abs dword foo]
	mov ebx,[abs dword foo]
	mov rax,[abs dword foo]
	mov rbx,[abs dword foo]
	mov al,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword 0xbbbbbbbb]
	mov bl,[abs dword 0xbbbbbbbb]
	mov ax,[abs dword 0xbbbbbbbb]
	mov bx,[abs dword 0xbbbbbbbb]
	mov eax,[abs dword 0xbbbbbbbb]
	mov ebx,[abs dword 0xbbbbbbbb]
	mov rax,[abs dword 0xbbbbbbbb]
	mov rbx,[abs dword 0xbbbbbbbb]
	mov al,[abs dword 0xffffffffcccccccc]
	mov bl,[abs dword 0xffffffffcccccccc]
	mov ax,[abs dword 0xffffffffcccccccc]
	mov bx,[abs dword 0xffffffffcccccccc]
	mov eax,[abs dword 0xffffffffcccccccc]
	mov ebx,[abs dword 0xffffffffcccccccc]
	mov rax,[abs dword 0xffffffffcccccccc]
	mov rbx,[abs dword 0xffffffffcccccccc]

	mov al,[abs qword foo]
	mov bl,[abs qword foo]
	mov ax,[abs qword foo]
	mov bx,[abs qword foo]
	mov eax,[abs qword foo]
	mov ebx,[abs qword foo]
	mov rax,[abs qword foo]
	mov rbx,[abs qword foo]
	mov al,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword 0xbbbbbbbb]
	mov bl,[abs qword 0xbbbbbbbb]
	mov ax,[abs qword 0xbbbbbbbb]
	mov bx,[abs qword 0xbbbbbbbb]
	mov eax,[abs qword 0xbbbbbbbb]
	mov ebx,[abs qword 0xbbbbbbbb]
	mov rax,[abs qword 0xbbbbbbbb]
	mov rbx,[abs qword 0xbbbbbbbb]
	mov al,[abs qword 0xffffffffcccccccc]
	mov bl,[abs qword 0xffffffffcccccccc]
	mov ax,[abs qword 0xffffffffcccccccc]
	mov bx,[abs qword 0xffffffffcccccccc]
	mov eax,[abs qword 0xffffffffcccccccc]
	mov ebx,[abs qword 0xffffffffcccccccc]
	mov rax,[abs qword 0xffffffffcccccccc]
	mov rbx,[abs qword 0xffffffffcccccccc]

	mov al,[a64 abs foo]
	mov bl,[a64 abs foo]
	mov ax,[a64 abs foo]
	mov bx,[a64 abs foo]
	mov eax,[a64 abs foo]
	mov ebx,[a64 abs foo]
	mov rax,[a64 abs foo]
	mov rbx,[a64 abs foo]
	mov al,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs 0xbbbbbbbb]
	mov bl,[a64 abs 0xbbbbbbbb]
	mov ax,[a64 abs 0xbbbbbbbb]
	mov bx,[a64 abs 0xbbbbbbbb]
	mov eax,[a64 abs 0xbbbbbbbb]
	mov ebx,[a64 abs 0xbbbbbbbb]
	mov rax,[a64 abs 0xbbbbbbbb]
	mov rbx,[a64 abs 0xbbbbbbbb]
	mov al,[a64 abs 0xffffffffcccccccc]
	mov bl,[a64 abs 0xffffffffcccccccc]
	mov ax,[a64 abs 0xffffffffcccccccc]
	mov bx,[a64 abs 0xffffffffcccccccc]
	mov eax,[a64 abs 0xffffffffcccccccc]
	mov ebx,[a64 abs 0xffffffffcccccccc]
	mov rax,[a64 abs 0xffffffffcccccccc]
	mov rbx,[a64 abs 0xffffffffcccccccc]

	mov al,[a64 abs dword foo]
	mov bl,[a64 abs dword foo]
	mov ax,[a64 abs dword foo]
	mov bx,[a64 abs dword foo]
	mov eax,[a64 abs dword foo]
	mov ebx,[a64 abs dword foo]
	mov rax,[a64 abs dword foo]
	mov rbx,[a64 abs dword foo]
	mov al,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword 0xbbbbbbbb]
	mov bl,[a64 abs dword 0xbbbbbbbb]
	mov ax,[a64 abs dword 0xbbbbbbbb]
	mov bx,[a64 abs dword 0xbbbbbbbb]
	mov eax,[a64 abs dword 0xbbbbbbbb]
	mov ebx,[a64 abs dword 0xbbbbbbbb]
	mov rax,[a64 abs dword 0xbbbbbbbb]
	mov rbx,[a64 abs dword 0xbbbbbbbb]
	mov al,[a64 abs dword 0xffffffffcccccccc]
	mov bl,[a64 abs dword 0xffffffffcccccccc]
	mov ax,[a64 abs dword 0xffffffffcccccccc]
	mov bx,[a64 abs dword 0xffffffffcccccccc]
	mov eax,[a64 abs dword 0xffffffffcccccccc]
	mov ebx,[a64 abs dword 0xffffffffcccccccc]
	mov rax,[a64 abs dword 0xffffffffcccccccc]
	mov rbx,[a64 abs dword 0xffffffffcccccccc]

	mov al,[a64 abs qword foo]
	mov bl,[a64 abs qword foo]
	mov ax,[a64 abs qword foo]
	mov bx,[a64 abs qword foo]
	mov eax,[a64 abs qword foo]
	mov ebx,[a64 abs qword foo]
	mov rax,[a64 abs qword foo]
	mov rbx,[a64 abs qword foo]
	mov al,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword 0xbbbbbbbb]
	mov bl,[a64 abs qword 0xbbbbbbbb]
	mov ax,[a64 abs qword 0xbbbbbbbb]
	mov bx,[a64 abs qword 0xbbbbbbbb]
	mov eax,[a64 abs qword 0xbbbbbbbb]
	mov ebx,[a64 abs qword 0xbbbbbbbb]
	mov rax,[a64 abs qword 0xbbbbbbbb]
	mov rbx,[a64 abs qword 0xbbbbbbbb]
	mov al,[a64 abs qword 0xffffffffcccccccc]
	mov bl,[a64 abs qword 0xffffffffcccccccc]
	mov ax,[a64 abs qword 0xffffffffcccccccc]
	mov bx,[a64 abs qword 0xffffffffcccccccc]
	mov eax,[a64 abs qword 0xffffffffcccccccc]
	mov ebx,[a64 abs qword 0xffffffffcccccccc]
	mov rax,[a64 abs qword 0xffffffffcccccccc]
	mov rbx,[a64 abs qword 0xffffffffcccccccc]

	mov al,[a32 abs foo]
	mov bl,[a32 abs foo]
	mov ax,[a32 abs foo]
	mov bx,[a32 abs foo]
	mov eax,[a32 abs foo]
	mov ebx,[a32 abs foo]
	mov rax,[a32 abs foo]
	mov rbx,[a32 abs foo]
	mov al,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs 0xbbbbbbbb]
	mov bl,[a32 abs 0xbbbbbbbb]
	mov ax,[a32 abs 0xbbbbbbbb]
	mov bx,[a32 abs 0xbbbbbbbb]
	mov eax,[a32 abs 0xbbbbbbbb]
	mov ebx,[a32 abs 0xbbbbbbbb]
	mov rax,[a32 abs 0xbbbbbbbb]
	mov rbx,[a32 abs 0xbbbbbbbb]
	mov al,[a32 abs 0xffffffffcccccccc]
	mov bl,[a32 abs 0xffffffffcccccccc]
	mov ax,[a32 abs 0xffffffffcccccccc]
	mov bx,[a32 abs 0xffffffffcccccccc]
	mov eax,[a32 abs 0xffffffffcccccccc]
	mov ebx,[a32 abs 0xffffffffcccccccc]
	mov rax,[a32 abs 0xffffffffcccccccc]
	mov rbx,[a32 abs 0xffffffffcccccccc]

	mov al,[a32 abs dword foo]
	mov bl,[a32 abs dword foo]
	mov ax,[a32 abs dword foo]
	mov bx,[a32 abs dword foo]
	mov eax,[a32 abs dword foo]
	mov ebx,[a32 abs dword foo]
	mov rax,[a32 abs dword foo]
	mov rbx,[a32 abs dword foo]
	mov al,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword 0xbbbbbbbb]
	mov bl,[a32 abs dword 0xbbbbbbbb]
	mov ax,[a32 abs dword 0xbbbbbbbb]
	mov bx,[a32 abs dword 0xbbbbbbbb]
	mov eax,[a32 abs dword 0xbbbbbbbb]
	mov ebx,[a32 abs dword 0xbbbbbbbb]
	mov rax,[a32 abs dword 0xbbbbbbbb]
	mov rbx,[a32 abs dword 0xbbbbbbbb]
	mov al,[a32 abs dword 0xffffffffcccccccc]
	mov bl,[a32 abs dword 0xffffffffcccccccc]
	mov ax,[a32 abs dword 0xffffffffcccccccc]
	mov bx,[a32 abs dword 0xffffffffcccccccc]
	mov eax,[a32 abs dword 0xffffffffcccccccc]
	mov ebx,[a32 abs dword 0xffffffffcccccccc]
	mov rax,[a32 abs dword 0xffffffffcccccccc]
	mov rbx,[a32 abs dword 0xffffffffcccccccc]

	mov al,[a32 abs qword foo]
	mov bl,[a32 abs qword foo]
	mov ax,[a32 abs qword foo]
	mov bx,[a32 abs qword foo]
	mov eax,[a32 abs qword foo]
	mov ebx,[a32 abs qword foo]
	mov rax,[a32 abs qword foo]
	mov rbx,[a32 abs qword foo]
	mov al,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword 0xbbbbbbbb]
	mov bl,[a32 abs qword 0xbbbbbbbb]
	mov ax,[a32 abs qword 0xbbbbbbbb]
	mov bx,[a32 abs qword 0xbbbbbbbb]
	mov eax,[a32 abs qword 0xbbbbbbbb]
	mov ebx,[a32 abs qword 0xbbbbbbbb]
	mov rax,[a32 abs qword 0xbbbbbbbb]
	mov rbx,[a32 abs qword 0xbbbbbbbb]
	mov al,[a32 abs qword 0xffffffffcccccccc]
	mov bl,[a32 abs qword 0xffffffffcccccccc]
	mov ax,[a32 abs qword 0xffffffffcccccccc]
	mov bx,[a32 abs qword 0xffffffffcccccccc]
	mov eax,[a32 abs qword 0xffffffffcccccccc]
	mov ebx,[a32 abs qword 0xffffffffcccccccc]
	mov rax,[a32 abs qword 0xffffffffcccccccc]
	mov rbx,[a32 abs qword 0xffffffffcccccccc]

	mov al,[rel foo]
	mov bl,[rel foo]
	mov ax,[rel foo]
	mov bx,[rel foo]
	mov eax,[rel foo]
	mov ebx,[rel foo]
	mov rax,[rel foo]
	mov rbx,[rel foo]
	mov al,[rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel 0xaaaaaaaaaaaaaaaa]
	mov al,[rel 0xbbbbbbbb]
	mov bl,[rel 0xbbbbbbbb]
	mov ax,[rel 0xbbbbbbbb]
	mov bx,[rel 0xbbbbbbbb]
	mov eax,[rel 0xbbbbbbbb]
	mov ebx,[rel 0xbbbbbbbb]
	mov rax,[rel 0xbbbbbbbb]
	mov rbx,[rel 0xbbbbbbbb]
	mov al,[rel 0xffffffffcccccccc]
	mov bl,[rel 0xffffffffcccccccc]
	mov ax,[rel 0xffffffffcccccccc]
	mov bx,[rel 0xffffffffcccccccc]
	mov eax,[rel 0xffffffffcccccccc]
	mov ebx,[rel 0xffffffffcccccccc]
	mov rax,[rel 0xffffffffcccccccc]
	mov rbx,[rel 0xffffffffcccccccc]

	mov al,[rel dword foo]
	mov bl,[rel dword foo]
	mov ax,[rel dword foo]
	mov bx,[rel dword foo]
	mov eax,[rel dword foo]
	mov ebx,[rel dword foo]
	mov rax,[rel dword foo]
	mov rbx,[rel dword foo]
	mov al,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword 0xbbbbbbbb]
	mov bl,[rel dword 0xbbbbbbbb]
	mov ax,[rel dword 0xbbbbbbbb]
	mov bx,[rel dword 0xbbbbbbbb]
	mov eax,[rel dword 0xbbbbbbbb]
	mov ebx,[rel dword 0xbbbbbbbb]
	mov rax,[rel dword 0xbbbbbbbb]
	mov rbx,[rel dword 0xbbbbbbbb]
	mov al,[rel dword 0xffffffffcccccccc]
	mov bl,[rel dword 0xffffffffcccccccc]
	mov ax,[rel dword 0xffffffffcccccccc]
	mov bx,[rel dword 0xffffffffcccccccc]
	mov eax,[rel dword 0xffffffffcccccccc]
	mov ebx,[rel dword 0xffffffffcccccccc]
	mov rax,[rel dword 0xffffffffcccccccc]
	mov rbx,[rel dword 0xffffffffcccccccc]

	mov al,[rel qword foo]
	mov bl,[rel qword foo]
	mov ax,[rel qword foo]
	mov bx,[rel qword foo]
	mov eax,[rel qword foo]
	mov ebx,[rel qword foo]
	mov rax,[rel qword foo]
	mov rbx,[rel qword foo]
	mov al,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword 0xbbbbbbbb]
	mov bl,[rel qword 0xbbbbbbbb]
	mov ax,[rel qword 0xbbbbbbbb]
	mov bx,[rel qword 0xbbbbbbbb]
	mov eax,[rel qword 0xbbbbbbbb]
	mov ebx,[rel qword 0xbbbbbbbb]
	mov rax,[rel qword 0xbbbbbbbb]
	mov rbx,[rel qword 0xbbbbbbbb]
	mov al,[rel qword 0xffffffffcccccccc]
	mov bl,[rel qword 0xffffffffcccccccc]
	mov ax,[rel qword 0xffffffffcccccccc]
	mov bx,[rel qword 0xffffffffcccccccc]
	mov eax,[rel qword 0xffffffffcccccccc]
	mov ebx,[rel qword 0xffffffffcccccccc]
	mov rax,[rel qword 0xffffffffcccccccc]
	mov rbx,[rel qword 0xffffffffcccccccc]

	mov al,[a64 rel foo]
	mov bl,[a64 rel foo]
	mov ax,[a64 rel foo]
	mov bx,[a64 rel foo]
	mov eax,[a64 rel foo]
	mov ebx,[a64 rel foo]
	mov rax,[a64 rel foo]
	mov rbx,[a64 rel foo]
	mov al,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel 0xbbbbbbbb]
	mov bl,[a64 rel 0xbbbbbbbb]
	mov ax,[a64 rel 0xbbbbbbbb]
	mov bx,[a64 rel 0xbbbbbbbb]
	mov eax,[a64 rel 0xbbbbbbbb]
	mov ebx,[a64 rel 0xbbbbbbbb]
	mov rax,[a64 rel 0xbbbbbbbb]
	mov rbx,[a64 rel 0xbbbbbbbb]
	mov al,[a64 rel 0xffffffffcccccccc]
	mov bl,[a64 rel 0xffffffffcccccccc]
	mov ax,[a64 rel 0xffffffffcccccccc]
	mov bx,[a64 rel 0xffffffffcccccccc]
	mov eax,[a64 rel 0xffffffffcccccccc]
	mov ebx,[a64 rel 0xffffffffcccccccc]
	mov rax,[a64 rel 0xffffffffcccccccc]
	mov rbx,[a64 rel 0xffffffffcccccccc]

	mov al,[a64 rel dword foo]
	mov bl,[a64 rel dword foo]
	mov ax,[a64 rel dword foo]
	mov bx,[a64 rel dword foo]
	mov eax,[a64 rel dword foo]
	mov ebx,[a64 rel dword foo]
	mov rax,[a64 rel dword foo]
	mov rbx,[a64 rel dword foo]
	mov al,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword 0xbbbbbbbb]
	mov bl,[a64 rel dword 0xbbbbbbbb]
	mov ax,[a64 rel dword 0xbbbbbbbb]
	mov bx,[a64 rel dword 0xbbbbbbbb]
	mov eax,[a64 rel dword 0xbbbbbbbb]
	mov ebx,[a64 rel dword 0xbbbbbbbb]
	mov rax,[a64 rel dword 0xbbbbbbbb]
	mov rbx,[a64 rel dword 0xbbbbbbbb]
	mov al,[a64 rel dword 0xffffffffcccccccc]
	mov bl,[a64 rel dword 0xffffffffcccccccc]
	mov ax,[a64 rel dword 0xffffffffcccccccc]
	mov bx,[a64 rel dword 0xffffffffcccccccc]
	mov eax,[a64 rel dword 0xffffffffcccccccc]
	mov ebx,[a64 rel dword 0xffffffffcccccccc]
	mov rax,[a64 rel dword 0xffffffffcccccccc]
	mov rbx,[a64 rel dword 0xffffffffcccccccc]

	mov al,[a64 rel qword foo]
	mov bl,[a64 rel qword foo]
	mov ax,[a64 rel qword foo]
	mov bx,[a64 rel qword foo]
	mov eax,[a64 rel qword foo]
	mov ebx,[a64 rel qword foo]
	mov rax,[a64 rel qword foo]
	mov rbx,[a64 rel qword foo]
	mov al,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword 0xbbbbbbbb]
	mov bl,[a64 rel qword 0xbbbbbbbb]
	mov ax,[a64 rel qword 0xbbbbbbbb]
	mov bx,[a64 rel qword 0xbbbbbbbb]
	mov eax,[a64 rel qword 0xbbbbbbbb]
	mov ebx,[a64 rel qword 0xbbbbbbbb]
	mov rax,[a64 rel qword 0xbbbbbbbb]
	mov rbx,[a64 rel qword 0xbbbbbbbb]
	mov al,[a64 rel qword 0xffffffffcccccccc]
	mov bl,[a64 rel qword 0xffffffffcccccccc]
	mov ax,[a64 rel qword 0xffffffffcccccccc]
	mov bx,[a64 rel qword 0xffffffffcccccccc]
	mov eax,[a64 rel qword 0xffffffffcccccccc]
	mov ebx,[a64 rel qword 0xffffffffcccccccc]
	mov rax,[a64 rel qword 0xffffffffcccccccc]
	mov rbx,[a64 rel qword 0xffffffffcccccccc]

	mov al,[a32 rel foo]
	mov bl,[a32 rel foo]
	mov ax,[a32 rel foo]
	mov bx,[a32 rel foo]
	mov eax,[a32 rel foo]
	mov ebx,[a32 rel foo]
	mov rax,[a32 rel foo]
	mov rbx,[a32 rel foo]
	mov al,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel 0xbbbbbbbb]
	mov bl,[a32 rel 0xbbbbbbbb]
	mov ax,[a32 rel 0xbbbbbbbb]
	mov bx,[a32 rel 0xbbbbbbbb]
	mov eax,[a32 rel 0xbbbbbbbb]
	mov ebx,[a32 rel 0xbbbbbbbb]
	mov rax,[a32 rel 0xbbbbbbbb]
	mov rbx,[a32 rel 0xbbbbbbbb]
	mov al,[a32 rel 0xffffffffcccccccc]
	mov bl,[a32 rel 0xffffffffcccccccc]
	mov ax,[a32 rel 0xffffffffcccccccc]
	mov bx,[a32 rel 0xffffffffcccccccc]
	mov eax,[a32 rel 0xffffffffcccccccc]
	mov ebx,[a32 rel 0xffffffffcccccccc]
	mov rax,[a32 rel 0xffffffffcccccccc]
	mov rbx,[a32 rel 0xffffffffcccccccc]

	mov al,[a32 rel dword foo]
	mov bl,[a32 rel dword foo]
	mov ax,[a32 rel dword foo]
	mov bx,[a32 rel dword foo]
	mov eax,[a32 rel dword foo]
	mov ebx,[a32 rel dword foo]
	mov rax,[a32 rel dword foo]
	mov rbx,[a32 rel dword foo]
	mov al,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword 0xbbbbbbbb]
	mov bl,[a32 rel dword 0xbbbbbbbb]
	mov ax,[a32 rel dword 0xbbbbbbbb]
	mov bx,[a32 rel dword 0xbbbbbbbb]
	mov eax,[a32 rel dword 0xbbbbbbbb]
	mov ebx,[a32 rel dword 0xbbbbbbbb]
	mov rax,[a32 rel dword 0xbbbbbbbb]
	mov rbx,[a32 rel dword 0xbbbbbbbb]
	mov al,[a32 rel dword 0xffffffffcccccccc]
	mov bl,[a32 rel dword 0xffffffffcccccccc]
	mov ax,[a32 rel dword 0xffffffffcccccccc]
	mov bx,[a32 rel dword 0xffffffffcccccccc]
	mov eax,[a32 rel dword 0xffffffffcccccccc]
	mov ebx,[a32 rel dword 0xffffffffcccccccc]
	mov rax,[a32 rel dword 0xffffffffcccccccc]
	mov rbx,[a32 rel dword 0xffffffffcccccccc]

	mov al,[a32 rel qword foo]
	mov bl,[a32 rel qword foo]
	mov ax,[a32 rel qword foo]
	mov bx,[a32 rel qword foo]
	mov eax,[a32 rel qword foo]
	mov ebx,[a32 rel qword foo]
	mov rax,[a32 rel qword foo]
	mov rbx,[a32 rel qword foo]
	mov al,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword 0xbbbbbbbb]
	mov bl,[a32 rel qword 0xbbbbbbbb]
	mov ax,[a32 rel qword 0xbbbbbbbb]
	mov bx,[a32 rel qword 0xbbbbbbbb]
	mov eax,[a32 rel qword 0xbbbbbbbb]
	mov ebx,[a32 rel qword 0xbbbbbbbb]
	mov rax,[a32 rel qword 0xbbbbbbbb]
	mov rbx,[a32 rel qword 0xbbbbbbbb]
	mov al,[a32 rel qword 0xffffffffcccccccc]
	mov bl,[a32 rel qword 0xffffffffcccccccc]
	mov ax,[a32 rel qword 0xffffffffcccccccc]
	mov bx,[a32 rel qword 0xffffffffcccccccc]
	mov eax,[a32 rel qword 0xffffffffcccccccc]
	mov ebx,[a32 rel qword 0xffffffffcccccccc]
	mov rax,[a32 rel qword 0xffffffffcccccccc]
	mov rbx,[a32 rel qword 0xffffffffcccccccc]

	mov al,[fs:foo]
	mov bl,[fs:foo]
	mov ax,[fs:foo]
	mov bx,[fs:foo]
	mov eax,[fs:foo]
	mov ebx,[fs:foo]
	mov rax,[fs:foo]
	mov rbx,[fs:foo]
	mov al,[fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[fs:0xaaaaaaaaaaaaaaaa]
	mov al,[fs:0xbbbbbbbb]
	mov bl,[fs:0xbbbbbbbb]
	mov ax,[fs:0xbbbbbbbb]
	mov bx,[fs:0xbbbbbbbb]
	mov eax,[fs:0xbbbbbbbb]
	mov ebx,[fs:0xbbbbbbbb]
	mov rax,[fs:0xbbbbbbbb]
	mov rbx,[fs:0xbbbbbbbb]
	mov al,[fs:0xffffffffcccccccc]
	mov bl,[fs:0xffffffffcccccccc]
	mov ax,[fs:0xffffffffcccccccc]
	mov bx,[fs:0xffffffffcccccccc]
	mov eax,[fs:0xffffffffcccccccc]
	mov ebx,[fs:0xffffffffcccccccc]
	mov rax,[fs:0xffffffffcccccccc]
	mov rbx,[fs:0xffffffffcccccccc]

	mov al,[dword fs:foo]
	mov bl,[dword fs:foo]
	mov ax,[dword fs:foo]
	mov bx,[dword fs:foo]
	mov eax,[dword fs:foo]
	mov ebx,[dword fs:foo]
	mov rax,[dword fs:foo]
	mov rbx,[dword fs:foo]
	mov al,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[dword fs:0xbbbbbbbb]
	mov bl,[dword fs:0xbbbbbbbb]
	mov ax,[dword fs:0xbbbbbbbb]
	mov bx,[dword fs:0xbbbbbbbb]
	mov eax,[dword fs:0xbbbbbbbb]
	mov ebx,[dword fs:0xbbbbbbbb]
	mov rax,[dword fs:0xbbbbbbbb]
	mov rbx,[dword fs:0xbbbbbbbb]
	mov al,[dword fs:0xffffffffcccccccc]
	mov bl,[dword fs:0xffffffffcccccccc]
	mov ax,[dword fs:0xffffffffcccccccc]
	mov bx,[dword fs:0xffffffffcccccccc]
	mov eax,[dword fs:0xffffffffcccccccc]
	mov ebx,[dword fs:0xffffffffcccccccc]
	mov rax,[dword fs:0xffffffffcccccccc]
	mov rbx,[dword fs:0xffffffffcccccccc]

	mov al,[qword fs:foo]
	mov bl,[qword fs:foo]
	mov ax,[qword fs:foo]
	mov bx,[qword fs:foo]
	mov eax,[qword fs:foo]
	mov ebx,[qword fs:foo]
	mov rax,[qword fs:foo]
	mov rbx,[qword fs:foo]
	mov al,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[qword fs:0xbbbbbbbb]
	mov bl,[qword fs:0xbbbbbbbb]
	mov ax,[qword fs:0xbbbbbbbb]
	mov bx,[qword fs:0xbbbbbbbb]
	mov eax,[qword fs:0xbbbbbbbb]
	mov ebx,[qword fs:0xbbbbbbbb]
	mov rax,[qword fs:0xbbbbbbbb]
	mov rbx,[qword fs:0xbbbbbbbb]
	mov al,[qword fs:0xffffffffcccccccc]
	mov bl,[qword fs:0xffffffffcccccccc]
	mov ax,[qword fs:0xffffffffcccccccc]
	mov bx,[qword fs:0xffffffffcccccccc]
	mov eax,[qword fs:0xffffffffcccccccc]
	mov ebx,[qword fs:0xffffffffcccccccc]
	mov rax,[qword fs:0xffffffffcccccccc]
	mov rbx,[qword fs:0xffffffffcccccccc]

	mov al,[a64 fs:foo]
	mov bl,[a64 fs:foo]
	mov ax,[a64 fs:foo]
	mov bx,[a64 fs:foo]
	mov eax,[a64 fs:foo]
	mov ebx,[a64 fs:foo]
	mov rax,[a64 fs:foo]
	mov rbx,[a64 fs:foo]
	mov al,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 fs:0xbbbbbbbb]
	mov bl,[a64 fs:0xbbbbbbbb]
	mov ax,[a64 fs:0xbbbbbbbb]
	mov bx,[a64 fs:0xbbbbbbbb]
	mov eax,[a64 fs:0xbbbbbbbb]
	mov ebx,[a64 fs:0xbbbbbbbb]
	mov rax,[a64 fs:0xbbbbbbbb]
	mov rbx,[a64 fs:0xbbbbbbbb]
	mov al,[a64 fs:0xffffffffcccccccc]
	mov bl,[a64 fs:0xffffffffcccccccc]
	mov ax,[a64 fs:0xffffffffcccccccc]
	mov bx,[a64 fs:0xffffffffcccccccc]
	mov eax,[a64 fs:0xffffffffcccccccc]
	mov ebx,[a64 fs:0xffffffffcccccccc]
	mov rax,[a64 fs:0xffffffffcccccccc]
	mov rbx,[a64 fs:0xffffffffcccccccc]

	mov al,[a64 dword fs:foo]
	mov bl,[a64 dword fs:foo]
	mov ax,[a64 dword fs:foo]
	mov bx,[a64 dword fs:foo]
	mov eax,[a64 dword fs:foo]
	mov ebx,[a64 dword fs:foo]
	mov rax,[a64 dword fs:foo]
	mov rbx,[a64 dword fs:foo]
	mov al,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword fs:0xbbbbbbbb]
	mov bl,[a64 dword fs:0xbbbbbbbb]
	mov ax,[a64 dword fs:0xbbbbbbbb]
	mov bx,[a64 dword fs:0xbbbbbbbb]
	mov eax,[a64 dword fs:0xbbbbbbbb]
	mov ebx,[a64 dword fs:0xbbbbbbbb]
	mov rax,[a64 dword fs:0xbbbbbbbb]
	mov rbx,[a64 dword fs:0xbbbbbbbb]
	mov al,[a64 dword fs:0xffffffffcccccccc]
	mov bl,[a64 dword fs:0xffffffffcccccccc]
	mov ax,[a64 dword fs:0xffffffffcccccccc]
	mov bx,[a64 dword fs:0xffffffffcccccccc]
	mov eax,[a64 dword fs:0xffffffffcccccccc]
	mov ebx,[a64 dword fs:0xffffffffcccccccc]
	mov rax,[a64 dword fs:0xffffffffcccccccc]
	mov rbx,[a64 dword fs:0xffffffffcccccccc]

	mov al,[a64 qword fs:foo]
	mov bl,[a64 qword fs:foo]
	mov ax,[a64 qword fs:foo]
	mov bx,[a64 qword fs:foo]
	mov eax,[a64 qword fs:foo]
	mov ebx,[a64 qword fs:foo]
	mov rax,[a64 qword fs:foo]
	mov rbx,[a64 qword fs:foo]
	mov al,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword fs:0xbbbbbbbb]
	mov bl,[a64 qword fs:0xbbbbbbbb]
	mov ax,[a64 qword fs:0xbbbbbbbb]
	mov bx,[a64 qword fs:0xbbbbbbbb]
	mov eax,[a64 qword fs:0xbbbbbbbb]
	mov ebx,[a64 qword fs:0xbbbbbbbb]
	mov rax,[a64 qword fs:0xbbbbbbbb]
	mov rbx,[a64 qword fs:0xbbbbbbbb]
	mov al,[a64 qword fs:0xffffffffcccccccc]
	mov bl,[a64 qword fs:0xffffffffcccccccc]
	mov ax,[a64 qword fs:0xffffffffcccccccc]
	mov bx,[a64 qword fs:0xffffffffcccccccc]
	mov eax,[a64 qword fs:0xffffffffcccccccc]
	mov ebx,[a64 qword fs:0xffffffffcccccccc]
	mov rax,[a64 qword fs:0xffffffffcccccccc]
	mov rbx,[a64 qword fs:0xffffffffcccccccc]

	mov al,[a32 fs:foo]
	mov bl,[a32 fs:foo]
	mov ax,[a32 fs:foo]
	mov bx,[a32 fs:foo]
	mov eax,[a32 fs:foo]
	mov ebx,[a32 fs:foo]
	mov rax,[a32 fs:foo]
	mov rbx,[a32 fs:foo]
	mov al,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 fs:0xbbbbbbbb]
	mov bl,[a32 fs:0xbbbbbbbb]
	mov ax,[a32 fs:0xbbbbbbbb]
	mov bx,[a32 fs:0xbbbbbbbb]
	mov eax,[a32 fs:0xbbbbbbbb]
	mov ebx,[a32 fs:0xbbbbbbbb]
	mov rax,[a32 fs:0xbbbbbbbb]
	mov rbx,[a32 fs:0xbbbbbbbb]
	mov al,[a32 fs:0xffffffffcccccccc]
	mov bl,[a32 fs:0xffffffffcccccccc]
	mov ax,[a32 fs:0xffffffffcccccccc]
	mov bx,[a32 fs:0xffffffffcccccccc]
	mov eax,[a32 fs:0xffffffffcccccccc]
	mov ebx,[a32 fs:0xffffffffcccccccc]
	mov rax,[a32 fs:0xffffffffcccccccc]
	mov rbx,[a32 fs:0xffffffffcccccccc]

	mov al,[a32 dword fs:foo]
	mov bl,[a32 dword fs:foo]
	mov ax,[a32 dword fs:foo]
	mov bx,[a32 dword fs:foo]
	mov eax,[a32 dword fs:foo]
	mov ebx,[a32 dword fs:foo]
	mov rax,[a32 dword fs:foo]
	mov rbx,[a32 dword fs:foo]
	mov al,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword fs:0xbbbbbbbb]
	mov bl,[a32 dword fs:0xbbbbbbbb]
	mov ax,[a32 dword fs:0xbbbbbbbb]
	mov bx,[a32 dword fs:0xbbbbbbbb]
	mov eax,[a32 dword fs:0xbbbbbbbb]
	mov ebx,[a32 dword fs:0xbbbbbbbb]
	mov rax,[a32 dword fs:0xbbbbbbbb]
	mov rbx,[a32 dword fs:0xbbbbbbbb]
	mov al,[a32 dword fs:0xffffffffcccccccc]
	mov bl,[a32 dword fs:0xffffffffcccccccc]
	mov ax,[a32 dword fs:0xffffffffcccccccc]
	mov bx,[a32 dword fs:0xffffffffcccccccc]
	mov eax,[a32 dword fs:0xffffffffcccccccc]
	mov ebx,[a32 dword fs:0xffffffffcccccccc]
	mov rax,[a32 dword fs:0xffffffffcccccccc]
	mov rbx,[a32 dword fs:0xffffffffcccccccc]

	mov al,[a32 qword fs:foo]
	mov bl,[a32 qword fs:foo]
	mov ax,[a32 qword fs:foo]
	mov bx,[a32 qword fs:foo]
	mov eax,[a32 qword fs:foo]
	mov ebx,[a32 qword fs:foo]
	mov rax,[a32 qword fs:foo]
	mov rbx,[a32 qword fs:foo]
	mov al,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword fs:0xbbbbbbbb]
	mov bl,[a32 qword fs:0xbbbbbbbb]
	mov ax,[a32 qword fs:0xbbbbbbbb]
	mov bx,[a32 qword fs:0xbbbbbbbb]
	mov eax,[a32 qword fs:0xbbbbbbbb]
	mov ebx,[a32 qword fs:0xbbbbbbbb]
	mov rax,[a32 qword fs:0xbbbbbbbb]
	mov rbx,[a32 qword fs:0xbbbbbbbb]
	mov al,[a32 qword fs:0xffffffffcccccccc]
	mov bl,[a32 qword fs:0xffffffffcccccccc]
	mov ax,[a32 qword fs:0xffffffffcccccccc]
	mov bx,[a32 qword fs:0xffffffffcccccccc]
	mov eax,[a32 qword fs:0xffffffffcccccccc]
	mov ebx,[a32 qword fs:0xffffffffcccccccc]
	mov rax,[a32 qword fs:0xffffffffcccccccc]
	mov rbx,[a32 qword fs:0xffffffffcccccccc]

	mov al,[abs fs:foo]
	mov bl,[abs fs:foo]
	mov ax,[abs fs:foo]
	mov bx,[abs fs:foo]
	mov eax,[abs fs:foo]
	mov ebx,[abs fs:foo]
	mov rax,[abs fs:foo]
	mov rbx,[abs fs:foo]
	mov al,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs fs:0xbbbbbbbb]
	mov bl,[abs fs:0xbbbbbbbb]
	mov ax,[abs fs:0xbbbbbbbb]
	mov bx,[abs fs:0xbbbbbbbb]
	mov eax,[abs fs:0xbbbbbbbb]
	mov ebx,[abs fs:0xbbbbbbbb]
	mov rax,[abs fs:0xbbbbbbbb]
	mov rbx,[abs fs:0xbbbbbbbb]
	mov al,[abs fs:0xffffffffcccccccc]
	mov bl,[abs fs:0xffffffffcccccccc]
	mov ax,[abs fs:0xffffffffcccccccc]
	mov bx,[abs fs:0xffffffffcccccccc]
	mov eax,[abs fs:0xffffffffcccccccc]
	mov ebx,[abs fs:0xffffffffcccccccc]
	mov rax,[abs fs:0xffffffffcccccccc]
	mov rbx,[abs fs:0xffffffffcccccccc]

	mov al,[abs dword fs:foo]
	mov bl,[abs dword fs:foo]
	mov ax,[abs dword fs:foo]
	mov bx,[abs dword fs:foo]
	mov eax,[abs dword fs:foo]
	mov ebx,[abs dword fs:foo]
	mov rax,[abs dword fs:foo]
	mov rbx,[abs dword fs:foo]
	mov al,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword fs:0xbbbbbbbb]
	mov bl,[abs dword fs:0xbbbbbbbb]
	mov ax,[abs dword fs:0xbbbbbbbb]
	mov bx,[abs dword fs:0xbbbbbbbb]
	mov eax,[abs dword fs:0xbbbbbbbb]
	mov ebx,[abs dword fs:0xbbbbbbbb]
	mov rax,[abs dword fs:0xbbbbbbbb]
	mov rbx,[abs dword fs:0xbbbbbbbb]
	mov al,[abs dword fs:0xffffffffcccccccc]
	mov bl,[abs dword fs:0xffffffffcccccccc]
	mov ax,[abs dword fs:0xffffffffcccccccc]
	mov bx,[abs dword fs:0xffffffffcccccccc]
	mov eax,[abs dword fs:0xffffffffcccccccc]
	mov ebx,[abs dword fs:0xffffffffcccccccc]
	mov rax,[abs dword fs:0xffffffffcccccccc]
	mov rbx,[abs dword fs:0xffffffffcccccccc]

	mov al,[abs qword fs:foo]
	mov bl,[abs qword fs:foo]
	mov ax,[abs qword fs:foo]
	mov bx,[abs qword fs:foo]
	mov eax,[abs qword fs:foo]
	mov ebx,[abs qword fs:foo]
	mov rax,[abs qword fs:foo]
	mov rbx,[abs qword fs:foo]
	mov al,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword fs:0xbbbbbbbb]
	mov bl,[abs qword fs:0xbbbbbbbb]
	mov ax,[abs qword fs:0xbbbbbbbb]
	mov bx,[abs qword fs:0xbbbbbbbb]
	mov eax,[abs qword fs:0xbbbbbbbb]
	mov ebx,[abs qword fs:0xbbbbbbbb]
	mov rax,[abs qword fs:0xbbbbbbbb]
	mov rbx,[abs qword fs:0xbbbbbbbb]
	mov al,[abs qword fs:0xffffffffcccccccc]
	mov bl,[abs qword fs:0xffffffffcccccccc]
	mov ax,[abs qword fs:0xffffffffcccccccc]
	mov bx,[abs qword fs:0xffffffffcccccccc]
	mov eax,[abs qword fs:0xffffffffcccccccc]
	mov ebx,[abs qword fs:0xffffffffcccccccc]
	mov rax,[abs qword fs:0xffffffffcccccccc]
	mov rbx,[abs qword fs:0xffffffffcccccccc]

	mov al,[a64 abs fs:foo]
	mov bl,[a64 abs fs:foo]
	mov ax,[a64 abs fs:foo]
	mov bx,[a64 abs fs:foo]
	mov eax,[a64 abs fs:foo]
	mov ebx,[a64 abs fs:foo]
	mov rax,[a64 abs fs:foo]
	mov rbx,[a64 abs fs:foo]
	mov al,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs fs:0xbbbbbbbb]
	mov bl,[a64 abs fs:0xbbbbbbbb]
	mov ax,[a64 abs fs:0xbbbbbbbb]
	mov bx,[a64 abs fs:0xbbbbbbbb]
	mov eax,[a64 abs fs:0xbbbbbbbb]
	mov ebx,[a64 abs fs:0xbbbbbbbb]
	mov rax,[a64 abs fs:0xbbbbbbbb]
	mov rbx,[a64 abs fs:0xbbbbbbbb]
	mov al,[a64 abs fs:0xffffffffcccccccc]
	mov bl,[a64 abs fs:0xffffffffcccccccc]
	mov ax,[a64 abs fs:0xffffffffcccccccc]
	mov bx,[a64 abs fs:0xffffffffcccccccc]
	mov eax,[a64 abs fs:0xffffffffcccccccc]
	mov ebx,[a64 abs fs:0xffffffffcccccccc]
	mov rax,[a64 abs fs:0xffffffffcccccccc]
	mov rbx,[a64 abs fs:0xffffffffcccccccc]

	mov al,[a64 abs dword fs:foo]
	mov bl,[a64 abs dword fs:foo]
	mov ax,[a64 abs dword fs:foo]
	mov bx,[a64 abs dword fs:foo]
	mov eax,[a64 abs dword fs:foo]
	mov ebx,[a64 abs dword fs:foo]
	mov rax,[a64 abs dword fs:foo]
	mov rbx,[a64 abs dword fs:foo]
	mov al,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword fs:0xbbbbbbbb]
	mov bl,[a64 abs dword fs:0xbbbbbbbb]
	mov ax,[a64 abs dword fs:0xbbbbbbbb]
	mov bx,[a64 abs dword fs:0xbbbbbbbb]
	mov eax,[a64 abs dword fs:0xbbbbbbbb]
	mov ebx,[a64 abs dword fs:0xbbbbbbbb]
	mov rax,[a64 abs dword fs:0xbbbbbbbb]
	mov rbx,[a64 abs dword fs:0xbbbbbbbb]
	mov al,[a64 abs dword fs:0xffffffffcccccccc]
	mov bl,[a64 abs dword fs:0xffffffffcccccccc]
	mov ax,[a64 abs dword fs:0xffffffffcccccccc]
	mov bx,[a64 abs dword fs:0xffffffffcccccccc]
	mov eax,[a64 abs dword fs:0xffffffffcccccccc]
	mov ebx,[a64 abs dword fs:0xffffffffcccccccc]
	mov rax,[a64 abs dword fs:0xffffffffcccccccc]
	mov rbx,[a64 abs dword fs:0xffffffffcccccccc]

	mov al,[a64 abs qword fs:foo]
	mov bl,[a64 abs qword fs:foo]
	mov ax,[a64 abs qword fs:foo]
	mov bx,[a64 abs qword fs:foo]
	mov eax,[a64 abs qword fs:foo]
	mov ebx,[a64 abs qword fs:foo]
	mov rax,[a64 abs qword fs:foo]
	mov rbx,[a64 abs qword fs:foo]
	mov al,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword fs:0xbbbbbbbb]
	mov bl,[a64 abs qword fs:0xbbbbbbbb]
	mov ax,[a64 abs qword fs:0xbbbbbbbb]
	mov bx,[a64 abs qword fs:0xbbbbbbbb]
	mov eax,[a64 abs qword fs:0xbbbbbbbb]
	mov ebx,[a64 abs qword fs:0xbbbbbbbb]
	mov rax,[a64 abs qword fs:0xbbbbbbbb]
	mov rbx,[a64 abs qword fs:0xbbbbbbbb]
	mov al,[a64 abs qword fs:0xffffffffcccccccc]
	mov bl,[a64 abs qword fs:0xffffffffcccccccc]
	mov ax,[a64 abs qword fs:0xffffffffcccccccc]
	mov bx,[a64 abs qword fs:0xffffffffcccccccc]
	mov eax,[a64 abs qword fs:0xffffffffcccccccc]
	mov ebx,[a64 abs qword fs:0xffffffffcccccccc]
	mov rax,[a64 abs qword fs:0xffffffffcccccccc]
	mov rbx,[a64 abs qword fs:0xffffffffcccccccc]

	mov al,[a32 abs fs:foo]
	mov bl,[a32 abs fs:foo]
	mov ax,[a32 abs fs:foo]
	mov bx,[a32 abs fs:foo]
	mov eax,[a32 abs fs:foo]
	mov ebx,[a32 abs fs:foo]
	mov rax,[a32 abs fs:foo]
	mov rbx,[a32 abs fs:foo]
	mov al,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs fs:0xbbbbbbbb]
	mov bl,[a32 abs fs:0xbbbbbbbb]
	mov ax,[a32 abs fs:0xbbbbbbbb]
	mov bx,[a32 abs fs:0xbbbbbbbb]
	mov eax,[a32 abs fs:0xbbbbbbbb]
	mov ebx,[a32 abs fs:0xbbbbbbbb]
	mov rax,[a32 abs fs:0xbbbbbbbb]
	mov rbx,[a32 abs fs:0xbbbbbbbb]
	mov al,[a32 abs fs:0xffffffffcccccccc]
	mov bl,[a32 abs fs:0xffffffffcccccccc]
	mov ax,[a32 abs fs:0xffffffffcccccccc]
	mov bx,[a32 abs fs:0xffffffffcccccccc]
	mov eax,[a32 abs fs:0xffffffffcccccccc]
	mov ebx,[a32 abs fs:0xffffffffcccccccc]
	mov rax,[a32 abs fs:0xffffffffcccccccc]
	mov rbx,[a32 abs fs:0xffffffffcccccccc]

	mov al,[a32 abs dword fs:foo]
	mov bl,[a32 abs dword fs:foo]
	mov ax,[a32 abs dword fs:foo]
	mov bx,[a32 abs dword fs:foo]
	mov eax,[a32 abs dword fs:foo]
	mov ebx,[a32 abs dword fs:foo]
	mov rax,[a32 abs dword fs:foo]
	mov rbx,[a32 abs dword fs:foo]
	mov al,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword fs:0xbbbbbbbb]
	mov bl,[a32 abs dword fs:0xbbbbbbbb]
	mov ax,[a32 abs dword fs:0xbbbbbbbb]
	mov bx,[a32 abs dword fs:0xbbbbbbbb]
	mov eax,[a32 abs dword fs:0xbbbbbbbb]
	mov ebx,[a32 abs dword fs:0xbbbbbbbb]
	mov rax,[a32 abs dword fs:0xbbbbbbbb]
	mov rbx,[a32 abs dword fs:0xbbbbbbbb]
	mov al,[a32 abs dword fs:0xffffffffcccccccc]
	mov bl,[a32 abs dword fs:0xffffffffcccccccc]
	mov ax,[a32 abs dword fs:0xffffffffcccccccc]
	mov bx,[a32 abs dword fs:0xffffffffcccccccc]
	mov eax,[a32 abs dword fs:0xffffffffcccccccc]
	mov ebx,[a32 abs dword fs:0xffffffffcccccccc]
	mov rax,[a32 abs dword fs:0xffffffffcccccccc]
	mov rbx,[a32 abs dword fs:0xffffffffcccccccc]

	mov al,[a32 abs qword fs:foo]
	mov bl,[a32 abs qword fs:foo]
	mov ax,[a32 abs qword fs:foo]
	mov bx,[a32 abs qword fs:foo]
	mov eax,[a32 abs qword fs:foo]
	mov ebx,[a32 abs qword fs:foo]
	mov rax,[a32 abs qword fs:foo]
	mov rbx,[a32 abs qword fs:foo]
	mov al,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword fs:0xbbbbbbbb]
	mov bl,[a32 abs qword fs:0xbbbbbbbb]
	mov ax,[a32 abs qword fs:0xbbbbbbbb]
	mov bx,[a32 abs qword fs:0xbbbbbbbb]
	mov eax,[a32 abs qword fs:0xbbbbbbbb]
	mov ebx,[a32 abs qword fs:0xbbbbbbbb]
	mov rax,[a32 abs qword fs:0xbbbbbbbb]
	mov rbx,[a32 abs qword fs:0xbbbbbbbb]
	mov al,[a32 abs qword fs:0xffffffffcccccccc]
	mov bl,[a32 abs qword fs:0xffffffffcccccccc]
	mov ax,[a32 abs qword fs:0xffffffffcccccccc]
	mov bx,[a32 abs qword fs:0xffffffffcccccccc]
	mov eax,[a32 abs qword fs:0xffffffffcccccccc]
	mov ebx,[a32 abs qword fs:0xffffffffcccccccc]
	mov rax,[a32 abs qword fs:0xffffffffcccccccc]
	mov rbx,[a32 abs qword fs:0xffffffffcccccccc]

	mov al,[rel fs:foo]
	mov bl,[rel fs:foo]
	mov ax,[rel fs:foo]
	mov bx,[rel fs:foo]
	mov eax,[rel fs:foo]
	mov ebx,[rel fs:foo]
	mov rax,[rel fs:foo]
	mov rbx,[rel fs:foo]
	mov al,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel fs:0xbbbbbbbb]
	mov bl,[rel fs:0xbbbbbbbb]
	mov ax,[rel fs:0xbbbbbbbb]
	mov bx,[rel fs:0xbbbbbbbb]
	mov eax,[rel fs:0xbbbbbbbb]
	mov ebx,[rel fs:0xbbbbbbbb]
	mov rax,[rel fs:0xbbbbbbbb]
	mov rbx,[rel fs:0xbbbbbbbb]
	mov al,[rel fs:0xffffffffcccccccc]
	mov bl,[rel fs:0xffffffffcccccccc]
	mov ax,[rel fs:0xffffffffcccccccc]
	mov bx,[rel fs:0xffffffffcccccccc]
	mov eax,[rel fs:0xffffffffcccccccc]
	mov ebx,[rel fs:0xffffffffcccccccc]
	mov rax,[rel fs:0xffffffffcccccccc]
	mov rbx,[rel fs:0xffffffffcccccccc]

	mov al,[rel dword fs:foo]
	mov bl,[rel dword fs:foo]
	mov ax,[rel dword fs:foo]
	mov bx,[rel dword fs:foo]
	mov eax,[rel dword fs:foo]
	mov ebx,[rel dword fs:foo]
	mov rax,[rel dword fs:foo]
	mov rbx,[rel dword fs:foo]
	mov al,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword fs:0xbbbbbbbb]
	mov bl,[rel dword fs:0xbbbbbbbb]
	mov ax,[rel dword fs:0xbbbbbbbb]
	mov bx,[rel dword fs:0xbbbbbbbb]
	mov eax,[rel dword fs:0xbbbbbbbb]
	mov ebx,[rel dword fs:0xbbbbbbbb]
	mov rax,[rel dword fs:0xbbbbbbbb]
	mov rbx,[rel dword fs:0xbbbbbbbb]
	mov al,[rel dword fs:0xffffffffcccccccc]
	mov bl,[rel dword fs:0xffffffffcccccccc]
	mov ax,[rel dword fs:0xffffffffcccccccc]
	mov bx,[rel dword fs:0xffffffffcccccccc]
	mov eax,[rel dword fs:0xffffffffcccccccc]
	mov ebx,[rel dword fs:0xffffffffcccccccc]
	mov rax,[rel dword fs:0xffffffffcccccccc]
	mov rbx,[rel dword fs:0xffffffffcccccccc]

	mov al,[rel qword fs:foo]
	mov bl,[rel qword fs:foo]
	mov ax,[rel qword fs:foo]
	mov bx,[rel qword fs:foo]
	mov eax,[rel qword fs:foo]
	mov ebx,[rel qword fs:foo]
	mov rax,[rel qword fs:foo]
	mov rbx,[rel qword fs:foo]
	mov al,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword fs:0xbbbbbbbb]
	mov bl,[rel qword fs:0xbbbbbbbb]
	mov ax,[rel qword fs:0xbbbbbbbb]
	mov bx,[rel qword fs:0xbbbbbbbb]
	mov eax,[rel qword fs:0xbbbbbbbb]
	mov ebx,[rel qword fs:0xbbbbbbbb]
	mov rax,[rel qword fs:0xbbbbbbbb]
	mov rbx,[rel qword fs:0xbbbbbbbb]
	mov al,[rel qword fs:0xffffffffcccccccc]
	mov bl,[rel qword fs:0xffffffffcccccccc]
	mov ax,[rel qword fs:0xffffffffcccccccc]
	mov bx,[rel qword fs:0xffffffffcccccccc]
	mov eax,[rel qword fs:0xffffffffcccccccc]
	mov ebx,[rel qword fs:0xffffffffcccccccc]
	mov rax,[rel qword fs:0xffffffffcccccccc]
	mov rbx,[rel qword fs:0xffffffffcccccccc]

	mov al,[a64 rel fs:foo]
	mov bl,[a64 rel fs:foo]
	mov ax,[a64 rel fs:foo]
	mov bx,[a64 rel fs:foo]
	mov eax,[a64 rel fs:foo]
	mov ebx,[a64 rel fs:foo]
	mov rax,[a64 rel fs:foo]
	mov rbx,[a64 rel fs:foo]
	mov al,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel fs:0xbbbbbbbb]
	mov bl,[a64 rel fs:0xbbbbbbbb]
	mov ax,[a64 rel fs:0xbbbbbbbb]
	mov bx,[a64 rel fs:0xbbbbbbbb]
	mov eax,[a64 rel fs:0xbbbbbbbb]
	mov ebx,[a64 rel fs:0xbbbbbbbb]
	mov rax,[a64 rel fs:0xbbbbbbbb]
	mov rbx,[a64 rel fs:0xbbbbbbbb]
	mov al,[a64 rel fs:0xffffffffcccccccc]
	mov bl,[a64 rel fs:0xffffffffcccccccc]
	mov ax,[a64 rel fs:0xffffffffcccccccc]
	mov bx,[a64 rel fs:0xffffffffcccccccc]
	mov eax,[a64 rel fs:0xffffffffcccccccc]
	mov ebx,[a64 rel fs:0xffffffffcccccccc]
	mov rax,[a64 rel fs:0xffffffffcccccccc]
	mov rbx,[a64 rel fs:0xffffffffcccccccc]

	mov al,[a64 rel dword fs:foo]
	mov bl,[a64 rel dword fs:foo]
	mov ax,[a64 rel dword fs:foo]
	mov bx,[a64 rel dword fs:foo]
	mov eax,[a64 rel dword fs:foo]
	mov ebx,[a64 rel dword fs:foo]
	mov rax,[a64 rel dword fs:foo]
	mov rbx,[a64 rel dword fs:foo]
	mov al,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword fs:0xbbbbbbbb]
	mov bl,[a64 rel dword fs:0xbbbbbbbb]
	mov ax,[a64 rel dword fs:0xbbbbbbbb]
	mov bx,[a64 rel dword fs:0xbbbbbbbb]
	mov eax,[a64 rel dword fs:0xbbbbbbbb]
	mov ebx,[a64 rel dword fs:0xbbbbbbbb]
	mov rax,[a64 rel dword fs:0xbbbbbbbb]
	mov rbx,[a64 rel dword fs:0xbbbbbbbb]
	mov al,[a64 rel dword fs:0xffffffffcccccccc]
	mov bl,[a64 rel dword fs:0xffffffffcccccccc]
	mov ax,[a64 rel dword fs:0xffffffffcccccccc]
	mov bx,[a64 rel dword fs:0xffffffffcccccccc]
	mov eax,[a64 rel dword fs:0xffffffffcccccccc]
	mov ebx,[a64 rel dword fs:0xffffffffcccccccc]
	mov rax,[a64 rel dword fs:0xffffffffcccccccc]
	mov rbx,[a64 rel dword fs:0xffffffffcccccccc]

	mov al,[a64 rel qword fs:foo]
	mov bl,[a64 rel qword fs:foo]
	mov ax,[a64 rel qword fs:foo]
	mov bx,[a64 rel qword fs:foo]
	mov eax,[a64 rel qword fs:foo]
	mov ebx,[a64 rel qword fs:foo]
	mov rax,[a64 rel qword fs:foo]
	mov rbx,[a64 rel qword fs:foo]
	mov al,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword fs:0xbbbbbbbb]
	mov bl,[a64 rel qword fs:0xbbbbbbbb]
	mov ax,[a64 rel qword fs:0xbbbbbbbb]
	mov bx,[a64 rel qword fs:0xbbbbbbbb]
	mov eax,[a64 rel qword fs:0xbbbbbbbb]
	mov ebx,[a64 rel qword fs:0xbbbbbbbb]
	mov rax,[a64 rel qword fs:0xbbbbbbbb]
	mov rbx,[a64 rel qword fs:0xbbbbbbbb]
	mov al,[a64 rel qword fs:0xffffffffcccccccc]
	mov bl,[a64 rel qword fs:0xffffffffcccccccc]
	mov ax,[a64 rel qword fs:0xffffffffcccccccc]
	mov bx,[a64 rel qword fs:0xffffffffcccccccc]
	mov eax,[a64 rel qword fs:0xffffffffcccccccc]
	mov ebx,[a64 rel qword fs:0xffffffffcccccccc]
	mov rax,[a64 rel qword fs:0xffffffffcccccccc]
	mov rbx,[a64 rel qword fs:0xffffffffcccccccc]

	mov al,[a32 rel fs:foo]
	mov bl,[a32 rel fs:foo]
	mov ax,[a32 rel fs:foo]
	mov bx,[a32 rel fs:foo]
	mov eax,[a32 rel fs:foo]
	mov ebx,[a32 rel fs:foo]
	mov rax,[a32 rel fs:foo]
	mov rbx,[a32 rel fs:foo]
	mov al,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel fs:0xbbbbbbbb]
	mov bl,[a32 rel fs:0xbbbbbbbb]
	mov ax,[a32 rel fs:0xbbbbbbbb]
	mov bx,[a32 rel fs:0xbbbbbbbb]
	mov eax,[a32 rel fs:0xbbbbbbbb]
	mov ebx,[a32 rel fs:0xbbbbbbbb]
	mov rax,[a32 rel fs:0xbbbbbbbb]
	mov rbx,[a32 rel fs:0xbbbbbbbb]
	mov al,[a32 rel fs:0xffffffffcccccccc]
	mov bl,[a32 rel fs:0xffffffffcccccccc]
	mov ax,[a32 rel fs:0xffffffffcccccccc]
	mov bx,[a32 rel fs:0xffffffffcccccccc]
	mov eax,[a32 rel fs:0xffffffffcccccccc]
	mov ebx,[a32 rel fs:0xffffffffcccccccc]
	mov rax,[a32 rel fs:0xffffffffcccccccc]
	mov rbx,[a32 rel fs:0xffffffffcccccccc]

	mov al,[a32 rel dword fs:foo]
	mov bl,[a32 rel dword fs:foo]
	mov ax,[a32 rel dword fs:foo]
	mov bx,[a32 rel dword fs:foo]
	mov eax,[a32 rel dword fs:foo]
	mov ebx,[a32 rel dword fs:foo]
	mov rax,[a32 rel dword fs:foo]
	mov rbx,[a32 rel dword fs:foo]
	mov al,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword fs:0xbbbbbbbb]
	mov bl,[a32 rel dword fs:0xbbbbbbbb]
	mov ax,[a32 rel dword fs:0xbbbbbbbb]
	mov bx,[a32 rel dword fs:0xbbbbbbbb]
	mov eax,[a32 rel dword fs:0xbbbbbbbb]
	mov ebx,[a32 rel dword fs:0xbbbbbbbb]
	mov rax,[a32 rel dword fs:0xbbbbbbbb]
	mov rbx,[a32 rel dword fs:0xbbbbbbbb]
	mov al,[a32 rel dword fs:0xffffffffcccccccc]
	mov bl,[a32 rel dword fs:0xffffffffcccccccc]
	mov ax,[a32 rel dword fs:0xffffffffcccccccc]
	mov bx,[a32 rel dword fs:0xffffffffcccccccc]
	mov eax,[a32 rel dword fs:0xffffffffcccccccc]
	mov ebx,[a32 rel dword fs:0xffffffffcccccccc]
	mov rax,[a32 rel dword fs:0xffffffffcccccccc]
	mov rbx,[a32 rel dword fs:0xffffffffcccccccc]

	mov al,[a32 rel qword fs:foo]
	mov bl,[a32 rel qword fs:foo]
	mov ax,[a32 rel qword fs:foo]
	mov bx,[a32 rel qword fs:foo]
	mov eax,[a32 rel qword fs:foo]
	mov ebx,[a32 rel qword fs:foo]
	mov rax,[a32 rel qword fs:foo]
	mov rbx,[a32 rel qword fs:foo]
	mov al,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword fs:0xbbbbbbbb]
	mov bl,[a32 rel qword fs:0xbbbbbbbb]
	mov ax,[a32 rel qword fs:0xbbbbbbbb]
	mov bx,[a32 rel qword fs:0xbbbbbbbb]
	mov eax,[a32 rel qword fs:0xbbbbbbbb]
	mov ebx,[a32 rel qword fs:0xbbbbbbbb]
	mov rax,[a32 rel qword fs:0xbbbbbbbb]
	mov rbx,[a32 rel qword fs:0xbbbbbbbb]
	mov al,[a32 rel qword fs:0xffffffffcccccccc]
	mov bl,[a32 rel qword fs:0xffffffffcccccccc]
	mov ax,[a32 rel qword fs:0xffffffffcccccccc]
	mov bx,[a32 rel qword fs:0xffffffffcccccccc]
	mov eax,[a32 rel qword fs:0xffffffffcccccccc]
	mov ebx,[a32 rel qword fs:0xffffffffcccccccc]
	mov rax,[a32 rel qword fs:0xffffffffcccccccc]
	mov rbx,[a32 rel qword fs:0xffffffffcccccccc]

	mov al,[es:foo]
	mov bl,[es:foo]
	mov ax,[es:foo]
	mov bx,[es:foo]
	mov eax,[es:foo]
	mov ebx,[es:foo]
	mov rax,[es:foo]
	mov rbx,[es:foo]
	mov al,[es:0xaaaaaaaaaaaaaaaa]
	mov bl,[es:0xaaaaaaaaaaaaaaaa]
	mov ax,[es:0xaaaaaaaaaaaaaaaa]
	mov bx,[es:0xaaaaaaaaaaaaaaaa]
	mov eax,[es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[es:0xaaaaaaaaaaaaaaaa]
	mov rax,[es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[es:0xaaaaaaaaaaaaaaaa]
	mov al,[es:0xbbbbbbbb]
	mov bl,[es:0xbbbbbbbb]
	mov ax,[es:0xbbbbbbbb]
	mov bx,[es:0xbbbbbbbb]
	mov eax,[es:0xbbbbbbbb]
	mov ebx,[es:0xbbbbbbbb]
	mov rax,[es:0xbbbbbbbb]
	mov rbx,[es:0xbbbbbbbb]
	mov al,[es:0xffffffffcccccccc]
	mov bl,[es:0xffffffffcccccccc]
	mov ax,[es:0xffffffffcccccccc]
	mov bx,[es:0xffffffffcccccccc]
	mov eax,[es:0xffffffffcccccccc]
	mov ebx,[es:0xffffffffcccccccc]
	mov rax,[es:0xffffffffcccccccc]
	mov rbx,[es:0xffffffffcccccccc]

	mov al,[dword es:foo]
	mov bl,[dword es:foo]
	mov ax,[dword es:foo]
	mov bx,[dword es:foo]
	mov eax,[dword es:foo]
	mov ebx,[dword es:foo]
	mov rax,[dword es:foo]
	mov rbx,[dword es:foo]
	mov al,[dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[dword es:0xbbbbbbbb]
	mov bl,[dword es:0xbbbbbbbb]
	mov ax,[dword es:0xbbbbbbbb]
	mov bx,[dword es:0xbbbbbbbb]
	mov eax,[dword es:0xbbbbbbbb]
	mov ebx,[dword es:0xbbbbbbbb]
	mov rax,[dword es:0xbbbbbbbb]
	mov rbx,[dword es:0xbbbbbbbb]
	mov al,[dword es:0xffffffffcccccccc]
	mov bl,[dword es:0xffffffffcccccccc]
	mov ax,[dword es:0xffffffffcccccccc]
	mov bx,[dword es:0xffffffffcccccccc]
	mov eax,[dword es:0xffffffffcccccccc]
	mov ebx,[dword es:0xffffffffcccccccc]
	mov rax,[dword es:0xffffffffcccccccc]
	mov rbx,[dword es:0xffffffffcccccccc]

	mov al,[qword es:foo]
	mov bl,[qword es:foo]
	mov ax,[qword es:foo]
	mov bx,[qword es:foo]
	mov eax,[qword es:foo]
	mov ebx,[qword es:foo]
	mov rax,[qword es:foo]
	mov rbx,[qword es:foo]
	mov al,[qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[qword es:0xbbbbbbbb]
	mov bl,[qword es:0xbbbbbbbb]
	mov ax,[qword es:0xbbbbbbbb]
	mov bx,[qword es:0xbbbbbbbb]
	mov eax,[qword es:0xbbbbbbbb]
	mov ebx,[qword es:0xbbbbbbbb]
	mov rax,[qword es:0xbbbbbbbb]
	mov rbx,[qword es:0xbbbbbbbb]
	mov al,[qword es:0xffffffffcccccccc]
	mov bl,[qword es:0xffffffffcccccccc]
	mov ax,[qword es:0xffffffffcccccccc]
	mov bx,[qword es:0xffffffffcccccccc]
	mov eax,[qword es:0xffffffffcccccccc]
	mov ebx,[qword es:0xffffffffcccccccc]
	mov rax,[qword es:0xffffffffcccccccc]
	mov rbx,[qword es:0xffffffffcccccccc]

	mov al,[a64 es:foo]
	mov bl,[a64 es:foo]
	mov ax,[a64 es:foo]
	mov bx,[a64 es:foo]
	mov eax,[a64 es:foo]
	mov ebx,[a64 es:foo]
	mov rax,[a64 es:foo]
	mov rbx,[a64 es:foo]
	mov al,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 es:0xbbbbbbbb]
	mov bl,[a64 es:0xbbbbbbbb]
	mov ax,[a64 es:0xbbbbbbbb]
	mov bx,[a64 es:0xbbbbbbbb]
	mov eax,[a64 es:0xbbbbbbbb]
	mov ebx,[a64 es:0xbbbbbbbb]
	mov rax,[a64 es:0xbbbbbbbb]
	mov rbx,[a64 es:0xbbbbbbbb]
	mov al,[a64 es:0xffffffffcccccccc]
	mov bl,[a64 es:0xffffffffcccccccc]
	mov ax,[a64 es:0xffffffffcccccccc]
	mov bx,[a64 es:0xffffffffcccccccc]
	mov eax,[a64 es:0xffffffffcccccccc]
	mov ebx,[a64 es:0xffffffffcccccccc]
	mov rax,[a64 es:0xffffffffcccccccc]
	mov rbx,[a64 es:0xffffffffcccccccc]

	mov al,[a64 dword es:foo]
	mov bl,[a64 dword es:foo]
	mov ax,[a64 dword es:foo]
	mov bx,[a64 dword es:foo]
	mov eax,[a64 dword es:foo]
	mov ebx,[a64 dword es:foo]
	mov rax,[a64 dword es:foo]
	mov rbx,[a64 dword es:foo]
	mov al,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword es:0xbbbbbbbb]
	mov bl,[a64 dword es:0xbbbbbbbb]
	mov ax,[a64 dword es:0xbbbbbbbb]
	mov bx,[a64 dword es:0xbbbbbbbb]
	mov eax,[a64 dword es:0xbbbbbbbb]
	mov ebx,[a64 dword es:0xbbbbbbbb]
	mov rax,[a64 dword es:0xbbbbbbbb]
	mov rbx,[a64 dword es:0xbbbbbbbb]
	mov al,[a64 dword es:0xffffffffcccccccc]
	mov bl,[a64 dword es:0xffffffffcccccccc]
	mov ax,[a64 dword es:0xffffffffcccccccc]
	mov bx,[a64 dword es:0xffffffffcccccccc]
	mov eax,[a64 dword es:0xffffffffcccccccc]
	mov ebx,[a64 dword es:0xffffffffcccccccc]
	mov rax,[a64 dword es:0xffffffffcccccccc]
	mov rbx,[a64 dword es:0xffffffffcccccccc]

	mov al,[a64 qword es:foo]
	mov bl,[a64 qword es:foo]
	mov ax,[a64 qword es:foo]
	mov bx,[a64 qword es:foo]
	mov eax,[a64 qword es:foo]
	mov ebx,[a64 qword es:foo]
	mov rax,[a64 qword es:foo]
	mov rbx,[a64 qword es:foo]
	mov al,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword es:0xbbbbbbbb]
	mov bl,[a64 qword es:0xbbbbbbbb]
	mov ax,[a64 qword es:0xbbbbbbbb]
	mov bx,[a64 qword es:0xbbbbbbbb]
	mov eax,[a64 qword es:0xbbbbbbbb]
	mov ebx,[a64 qword es:0xbbbbbbbb]
	mov rax,[a64 qword es:0xbbbbbbbb]
	mov rbx,[a64 qword es:0xbbbbbbbb]
	mov al,[a64 qword es:0xffffffffcccccccc]
	mov bl,[a64 qword es:0xffffffffcccccccc]
	mov ax,[a64 qword es:0xffffffffcccccccc]
	mov bx,[a64 qword es:0xffffffffcccccccc]
	mov eax,[a64 qword es:0xffffffffcccccccc]
	mov ebx,[a64 qword es:0xffffffffcccccccc]
	mov rax,[a64 qword es:0xffffffffcccccccc]
	mov rbx,[a64 qword es:0xffffffffcccccccc]

	mov al,[a32 es:foo]
	mov bl,[a32 es:foo]
	mov ax,[a32 es:foo]
	mov bx,[a32 es:foo]
	mov eax,[a32 es:foo]
	mov ebx,[a32 es:foo]
	mov rax,[a32 es:foo]
	mov rbx,[a32 es:foo]
	mov al,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 es:0xbbbbbbbb]
	mov bl,[a32 es:0xbbbbbbbb]
	mov ax,[a32 es:0xbbbbbbbb]
	mov bx,[a32 es:0xbbbbbbbb]
	mov eax,[a32 es:0xbbbbbbbb]
	mov ebx,[a32 es:0xbbbbbbbb]
	mov rax,[a32 es:0xbbbbbbbb]
	mov rbx,[a32 es:0xbbbbbbbb]
	mov al,[a32 es:0xffffffffcccccccc]
	mov bl,[a32 es:0xffffffffcccccccc]
	mov ax,[a32 es:0xffffffffcccccccc]
	mov bx,[a32 es:0xffffffffcccccccc]
	mov eax,[a32 es:0xffffffffcccccccc]
	mov ebx,[a32 es:0xffffffffcccccccc]
	mov rax,[a32 es:0xffffffffcccccccc]
	mov rbx,[a32 es:0xffffffffcccccccc]

	mov al,[a32 dword es:foo]
	mov bl,[a32 dword es:foo]
	mov ax,[a32 dword es:foo]
	mov bx,[a32 dword es:foo]
	mov eax,[a32 dword es:foo]
	mov ebx,[a32 dword es:foo]
	mov rax,[a32 dword es:foo]
	mov rbx,[a32 dword es:foo]
	mov al,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword es:0xbbbbbbbb]
	mov bl,[a32 dword es:0xbbbbbbbb]
	mov ax,[a32 dword es:0xbbbbbbbb]
	mov bx,[a32 dword es:0xbbbbbbbb]
	mov eax,[a32 dword es:0xbbbbbbbb]
	mov ebx,[a32 dword es:0xbbbbbbbb]
	mov rax,[a32 dword es:0xbbbbbbbb]
	mov rbx,[a32 dword es:0xbbbbbbbb]
	mov al,[a32 dword es:0xffffffffcccccccc]
	mov bl,[a32 dword es:0xffffffffcccccccc]
	mov ax,[a32 dword es:0xffffffffcccccccc]
	mov bx,[a32 dword es:0xffffffffcccccccc]
	mov eax,[a32 dword es:0xffffffffcccccccc]
	mov ebx,[a32 dword es:0xffffffffcccccccc]
	mov rax,[a32 dword es:0xffffffffcccccccc]
	mov rbx,[a32 dword es:0xffffffffcccccccc]

	mov al,[a32 qword es:foo]
	mov bl,[a32 qword es:foo]
	mov ax,[a32 qword es:foo]
	mov bx,[a32 qword es:foo]
	mov eax,[a32 qword es:foo]
	mov ebx,[a32 qword es:foo]
	mov rax,[a32 qword es:foo]
	mov rbx,[a32 qword es:foo]
	mov al,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword es:0xbbbbbbbb]
	mov bl,[a32 qword es:0xbbbbbbbb]
	mov ax,[a32 qword es:0xbbbbbbbb]
	mov bx,[a32 qword es:0xbbbbbbbb]
	mov eax,[a32 qword es:0xbbbbbbbb]
	mov ebx,[a32 qword es:0xbbbbbbbb]
	mov rax,[a32 qword es:0xbbbbbbbb]
	mov rbx,[a32 qword es:0xbbbbbbbb]
	mov al,[a32 qword es:0xffffffffcccccccc]
	mov bl,[a32 qword es:0xffffffffcccccccc]
	mov ax,[a32 qword es:0xffffffffcccccccc]
	mov bx,[a32 qword es:0xffffffffcccccccc]
	mov eax,[a32 qword es:0xffffffffcccccccc]
	mov ebx,[a32 qword es:0xffffffffcccccccc]
	mov rax,[a32 qword es:0xffffffffcccccccc]
	mov rbx,[a32 qword es:0xffffffffcccccccc]

	mov al,[abs es:foo]
	mov bl,[abs es:foo]
	mov ax,[abs es:foo]
	mov bx,[abs es:foo]
	mov eax,[abs es:foo]
	mov ebx,[abs es:foo]
	mov rax,[abs es:foo]
	mov rbx,[abs es:foo]
	mov al,[abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs es:0xbbbbbbbb]
	mov bl,[abs es:0xbbbbbbbb]
	mov ax,[abs es:0xbbbbbbbb]
	mov bx,[abs es:0xbbbbbbbb]
	mov eax,[abs es:0xbbbbbbbb]
	mov ebx,[abs es:0xbbbbbbbb]
	mov rax,[abs es:0xbbbbbbbb]
	mov rbx,[abs es:0xbbbbbbbb]
	mov al,[abs es:0xffffffffcccccccc]
	mov bl,[abs es:0xffffffffcccccccc]
	mov ax,[abs es:0xffffffffcccccccc]
	mov bx,[abs es:0xffffffffcccccccc]
	mov eax,[abs es:0xffffffffcccccccc]
	mov ebx,[abs es:0xffffffffcccccccc]
	mov rax,[abs es:0xffffffffcccccccc]
	mov rbx,[abs es:0xffffffffcccccccc]

	mov al,[abs dword es:foo]
	mov bl,[abs dword es:foo]
	mov ax,[abs dword es:foo]
	mov bx,[abs dword es:foo]
	mov eax,[abs dword es:foo]
	mov ebx,[abs dword es:foo]
	mov rax,[abs dword es:foo]
	mov rbx,[abs dword es:foo]
	mov al,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword es:0xbbbbbbbb]
	mov bl,[abs dword es:0xbbbbbbbb]
	mov ax,[abs dword es:0xbbbbbbbb]
	mov bx,[abs dword es:0xbbbbbbbb]
	mov eax,[abs dword es:0xbbbbbbbb]
	mov ebx,[abs dword es:0xbbbbbbbb]
	mov rax,[abs dword es:0xbbbbbbbb]
	mov rbx,[abs dword es:0xbbbbbbbb]
	mov al,[abs dword es:0xffffffffcccccccc]
	mov bl,[abs dword es:0xffffffffcccccccc]
	mov ax,[abs dword es:0xffffffffcccccccc]
	mov bx,[abs dword es:0xffffffffcccccccc]
	mov eax,[abs dword es:0xffffffffcccccccc]
	mov ebx,[abs dword es:0xffffffffcccccccc]
	mov rax,[abs dword es:0xffffffffcccccccc]
	mov rbx,[abs dword es:0xffffffffcccccccc]

	mov al,[abs qword es:foo]
	mov bl,[abs qword es:foo]
	mov ax,[abs qword es:foo]
	mov bx,[abs qword es:foo]
	mov eax,[abs qword es:foo]
	mov ebx,[abs qword es:foo]
	mov rax,[abs qword es:foo]
	mov rbx,[abs qword es:foo]
	mov al,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword es:0xbbbbbbbb]
	mov bl,[abs qword es:0xbbbbbbbb]
	mov ax,[abs qword es:0xbbbbbbbb]
	mov bx,[abs qword es:0xbbbbbbbb]
	mov eax,[abs qword es:0xbbbbbbbb]
	mov ebx,[abs qword es:0xbbbbbbbb]
	mov rax,[abs qword es:0xbbbbbbbb]
	mov rbx,[abs qword es:0xbbbbbbbb]
	mov al,[abs qword es:0xffffffffcccccccc]
	mov bl,[abs qword es:0xffffffffcccccccc]
	mov ax,[abs qword es:0xffffffffcccccccc]
	mov bx,[abs qword es:0xffffffffcccccccc]
	mov eax,[abs qword es:0xffffffffcccccccc]
	mov ebx,[abs qword es:0xffffffffcccccccc]
	mov rax,[abs qword es:0xffffffffcccccccc]
	mov rbx,[abs qword es:0xffffffffcccccccc]

	mov al,[a64 abs es:foo]
	mov bl,[a64 abs es:foo]
	mov ax,[a64 abs es:foo]
	mov bx,[a64 abs es:foo]
	mov eax,[a64 abs es:foo]
	mov ebx,[a64 abs es:foo]
	mov rax,[a64 abs es:foo]
	mov rbx,[a64 abs es:foo]
	mov al,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs es:0xbbbbbbbb]
	mov bl,[a64 abs es:0xbbbbbbbb]
	mov ax,[a64 abs es:0xbbbbbbbb]
	mov bx,[a64 abs es:0xbbbbbbbb]
	mov eax,[a64 abs es:0xbbbbbbbb]
	mov ebx,[a64 abs es:0xbbbbbbbb]
	mov rax,[a64 abs es:0xbbbbbbbb]
	mov rbx,[a64 abs es:0xbbbbbbbb]
	mov al,[a64 abs es:0xffffffffcccccccc]
	mov bl,[a64 abs es:0xffffffffcccccccc]
	mov ax,[a64 abs es:0xffffffffcccccccc]
	mov bx,[a64 abs es:0xffffffffcccccccc]
	mov eax,[a64 abs es:0xffffffffcccccccc]
	mov ebx,[a64 abs es:0xffffffffcccccccc]
	mov rax,[a64 abs es:0xffffffffcccccccc]
	mov rbx,[a64 abs es:0xffffffffcccccccc]

	mov al,[a64 abs dword es:foo]
	mov bl,[a64 abs dword es:foo]
	mov ax,[a64 abs dword es:foo]
	mov bx,[a64 abs dword es:foo]
	mov eax,[a64 abs dword es:foo]
	mov ebx,[a64 abs dword es:foo]
	mov rax,[a64 abs dword es:foo]
	mov rbx,[a64 abs dword es:foo]
	mov al,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword es:0xbbbbbbbb]
	mov bl,[a64 abs dword es:0xbbbbbbbb]
	mov ax,[a64 abs dword es:0xbbbbbbbb]
	mov bx,[a64 abs dword es:0xbbbbbbbb]
	mov eax,[a64 abs dword es:0xbbbbbbbb]
	mov ebx,[a64 abs dword es:0xbbbbbbbb]
	mov rax,[a64 abs dword es:0xbbbbbbbb]
	mov rbx,[a64 abs dword es:0xbbbbbbbb]
	mov al,[a64 abs dword es:0xffffffffcccccccc]
	mov bl,[a64 abs dword es:0xffffffffcccccccc]
	mov ax,[a64 abs dword es:0xffffffffcccccccc]
	mov bx,[a64 abs dword es:0xffffffffcccccccc]
	mov eax,[a64 abs dword es:0xffffffffcccccccc]
	mov ebx,[a64 abs dword es:0xffffffffcccccccc]
	mov rax,[a64 abs dword es:0xffffffffcccccccc]
	mov rbx,[a64 abs dword es:0xffffffffcccccccc]

	mov al,[a64 abs qword es:foo]
	mov bl,[a64 abs qword es:foo]
	mov ax,[a64 abs qword es:foo]
	mov bx,[a64 abs qword es:foo]
	mov eax,[a64 abs qword es:foo]
	mov ebx,[a64 abs qword es:foo]
	mov rax,[a64 abs qword es:foo]
	mov rbx,[a64 abs qword es:foo]
	mov al,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword es:0xbbbbbbbb]
	mov bl,[a64 abs qword es:0xbbbbbbbb]
	mov ax,[a64 abs qword es:0xbbbbbbbb]
	mov bx,[a64 abs qword es:0xbbbbbbbb]
	mov eax,[a64 abs qword es:0xbbbbbbbb]
	mov ebx,[a64 abs qword es:0xbbbbbbbb]
	mov rax,[a64 abs qword es:0xbbbbbbbb]
	mov rbx,[a64 abs qword es:0xbbbbbbbb]
	mov al,[a64 abs qword es:0xffffffffcccccccc]
	mov bl,[a64 abs qword es:0xffffffffcccccccc]
	mov ax,[a64 abs qword es:0xffffffffcccccccc]
	mov bx,[a64 abs qword es:0xffffffffcccccccc]
	mov eax,[a64 abs qword es:0xffffffffcccccccc]
	mov ebx,[a64 abs qword es:0xffffffffcccccccc]
	mov rax,[a64 abs qword es:0xffffffffcccccccc]
	mov rbx,[a64 abs qword es:0xffffffffcccccccc]

	mov al,[a32 abs es:foo]
	mov bl,[a32 abs es:foo]
	mov ax,[a32 abs es:foo]
	mov bx,[a32 abs es:foo]
	mov eax,[a32 abs es:foo]
	mov ebx,[a32 abs es:foo]
	mov rax,[a32 abs es:foo]
	mov rbx,[a32 abs es:foo]
	mov al,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs es:0xbbbbbbbb]
	mov bl,[a32 abs es:0xbbbbbbbb]
	mov ax,[a32 abs es:0xbbbbbbbb]
	mov bx,[a32 abs es:0xbbbbbbbb]
	mov eax,[a32 abs es:0xbbbbbbbb]
	mov ebx,[a32 abs es:0xbbbbbbbb]
	mov rax,[a32 abs es:0xbbbbbbbb]
	mov rbx,[a32 abs es:0xbbbbbbbb]
	mov al,[a32 abs es:0xffffffffcccccccc]
	mov bl,[a32 abs es:0xffffffffcccccccc]
	mov ax,[a32 abs es:0xffffffffcccccccc]
	mov bx,[a32 abs es:0xffffffffcccccccc]
	mov eax,[a32 abs es:0xffffffffcccccccc]
	mov ebx,[a32 abs es:0xffffffffcccccccc]
	mov rax,[a32 abs es:0xffffffffcccccccc]
	mov rbx,[a32 abs es:0xffffffffcccccccc]

	mov al,[a32 abs dword es:foo]
	mov bl,[a32 abs dword es:foo]
	mov ax,[a32 abs dword es:foo]
	mov bx,[a32 abs dword es:foo]
	mov eax,[a32 abs dword es:foo]
	mov ebx,[a32 abs dword es:foo]
	mov rax,[a32 abs dword es:foo]
	mov rbx,[a32 abs dword es:foo]
	mov al,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword es:0xbbbbbbbb]
	mov bl,[a32 abs dword es:0xbbbbbbbb]
	mov ax,[a32 abs dword es:0xbbbbbbbb]
	mov bx,[a32 abs dword es:0xbbbbbbbb]
	mov eax,[a32 abs dword es:0xbbbbbbbb]
	mov ebx,[a32 abs dword es:0xbbbbbbbb]
	mov rax,[a32 abs dword es:0xbbbbbbbb]
	mov rbx,[a32 abs dword es:0xbbbbbbbb]
	mov al,[a32 abs dword es:0xffffffffcccccccc]
	mov bl,[a32 abs dword es:0xffffffffcccccccc]
	mov ax,[a32 abs dword es:0xffffffffcccccccc]
	mov bx,[a32 abs dword es:0xffffffffcccccccc]
	mov eax,[a32 abs dword es:0xffffffffcccccccc]
	mov ebx,[a32 abs dword es:0xffffffffcccccccc]
	mov rax,[a32 abs dword es:0xffffffffcccccccc]
	mov rbx,[a32 abs dword es:0xffffffffcccccccc]

	mov al,[a32 abs qword es:foo]
	mov bl,[a32 abs qword es:foo]
	mov ax,[a32 abs qword es:foo]
	mov bx,[a32 abs qword es:foo]
	mov eax,[a32 abs qword es:foo]
	mov ebx,[a32 abs qword es:foo]
	mov rax,[a32 abs qword es:foo]
	mov rbx,[a32 abs qword es:foo]
	mov al,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword es:0xbbbbbbbb]
	mov bl,[a32 abs qword es:0xbbbbbbbb]
	mov ax,[a32 abs qword es:0xbbbbbbbb]
	mov bx,[a32 abs qword es:0xbbbbbbbb]
	mov eax,[a32 abs qword es:0xbbbbbbbb]
	mov ebx,[a32 abs qword es:0xbbbbbbbb]
	mov rax,[a32 abs qword es:0xbbbbbbbb]
	mov rbx,[a32 abs qword es:0xbbbbbbbb]
	mov al,[a32 abs qword es:0xffffffffcccccccc]
	mov bl,[a32 abs qword es:0xffffffffcccccccc]
	mov ax,[a32 abs qword es:0xffffffffcccccccc]
	mov bx,[a32 abs qword es:0xffffffffcccccccc]
	mov eax,[a32 abs qword es:0xffffffffcccccccc]
	mov ebx,[a32 abs qword es:0xffffffffcccccccc]
	mov rax,[a32 abs qword es:0xffffffffcccccccc]
	mov rbx,[a32 abs qword es:0xffffffffcccccccc]

	mov al,[rel es:foo]
	mov bl,[rel es:foo]
	mov ax,[rel es:foo]
	mov bx,[rel es:foo]
	mov eax,[rel es:foo]
	mov ebx,[rel es:foo]
	mov rax,[rel es:foo]
	mov rbx,[rel es:foo]
	mov al,[rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel es:0xbbbbbbbb]
	mov bl,[rel es:0xbbbbbbbb]
	mov ax,[rel es:0xbbbbbbbb]
	mov bx,[rel es:0xbbbbbbbb]
	mov eax,[rel es:0xbbbbbbbb]
	mov ebx,[rel es:0xbbbbbbbb]
	mov rax,[rel es:0xbbbbbbbb]
	mov rbx,[rel es:0xbbbbbbbb]
	mov al,[rel es:0xffffffffcccccccc]
	mov bl,[rel es:0xffffffffcccccccc]
	mov ax,[rel es:0xffffffffcccccccc]
	mov bx,[rel es:0xffffffffcccccccc]
	mov eax,[rel es:0xffffffffcccccccc]
	mov ebx,[rel es:0xffffffffcccccccc]
	mov rax,[rel es:0xffffffffcccccccc]
	mov rbx,[rel es:0xffffffffcccccccc]

	mov al,[rel dword es:foo]
	mov bl,[rel dword es:foo]
	mov ax,[rel dword es:foo]
	mov bx,[rel dword es:foo]
	mov eax,[rel dword es:foo]
	mov ebx,[rel dword es:foo]
	mov rax,[rel dword es:foo]
	mov rbx,[rel dword es:foo]
	mov al,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword es:0xbbbbbbbb]
	mov bl,[rel dword es:0xbbbbbbbb]
	mov ax,[rel dword es:0xbbbbbbbb]
	mov bx,[rel dword es:0xbbbbbbbb]
	mov eax,[rel dword es:0xbbbbbbbb]
	mov ebx,[rel dword es:0xbbbbbbbb]
	mov rax,[rel dword es:0xbbbbbbbb]
	mov rbx,[rel dword es:0xbbbbbbbb]
	mov al,[rel dword es:0xffffffffcccccccc]
	mov bl,[rel dword es:0xffffffffcccccccc]
	mov ax,[rel dword es:0xffffffffcccccccc]
	mov bx,[rel dword es:0xffffffffcccccccc]
	mov eax,[rel dword es:0xffffffffcccccccc]
	mov ebx,[rel dword es:0xffffffffcccccccc]
	mov rax,[rel dword es:0xffffffffcccccccc]
	mov rbx,[rel dword es:0xffffffffcccccccc]

	mov al,[rel qword es:foo]
	mov bl,[rel qword es:foo]
	mov ax,[rel qword es:foo]
	mov bx,[rel qword es:foo]
	mov eax,[rel qword es:foo]
	mov ebx,[rel qword es:foo]
	mov rax,[rel qword es:foo]
	mov rbx,[rel qword es:foo]
	mov al,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword es:0xbbbbbbbb]
	mov bl,[rel qword es:0xbbbbbbbb]
	mov ax,[rel qword es:0xbbbbbbbb]
	mov bx,[rel qword es:0xbbbbbbbb]
	mov eax,[rel qword es:0xbbbbbbbb]
	mov ebx,[rel qword es:0xbbbbbbbb]
	mov rax,[rel qword es:0xbbbbbbbb]
	mov rbx,[rel qword es:0xbbbbbbbb]
	mov al,[rel qword es:0xffffffffcccccccc]
	mov bl,[rel qword es:0xffffffffcccccccc]
	mov ax,[rel qword es:0xffffffffcccccccc]
	mov bx,[rel qword es:0xffffffffcccccccc]
	mov eax,[rel qword es:0xffffffffcccccccc]
	mov ebx,[rel qword es:0xffffffffcccccccc]
	mov rax,[rel qword es:0xffffffffcccccccc]
	mov rbx,[rel qword es:0xffffffffcccccccc]

	mov al,[a64 rel es:foo]
	mov bl,[a64 rel es:foo]
	mov ax,[a64 rel es:foo]
	mov bx,[a64 rel es:foo]
	mov eax,[a64 rel es:foo]
	mov ebx,[a64 rel es:foo]
	mov rax,[a64 rel es:foo]
	mov rbx,[a64 rel es:foo]
	mov al,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel es:0xbbbbbbbb]
	mov bl,[a64 rel es:0xbbbbbbbb]
	mov ax,[a64 rel es:0xbbbbbbbb]
	mov bx,[a64 rel es:0xbbbbbbbb]
	mov eax,[a64 rel es:0xbbbbbbbb]
	mov ebx,[a64 rel es:0xbbbbbbbb]
	mov rax,[a64 rel es:0xbbbbbbbb]
	mov rbx,[a64 rel es:0xbbbbbbbb]
	mov al,[a64 rel es:0xffffffffcccccccc]
	mov bl,[a64 rel es:0xffffffffcccccccc]
	mov ax,[a64 rel es:0xffffffffcccccccc]
	mov bx,[a64 rel es:0xffffffffcccccccc]
	mov eax,[a64 rel es:0xffffffffcccccccc]
	mov ebx,[a64 rel es:0xffffffffcccccccc]
	mov rax,[a64 rel es:0xffffffffcccccccc]
	mov rbx,[a64 rel es:0xffffffffcccccccc]

	mov al,[a64 rel dword es:foo]
	mov bl,[a64 rel dword es:foo]
	mov ax,[a64 rel dword es:foo]
	mov bx,[a64 rel dword es:foo]
	mov eax,[a64 rel dword es:foo]
	mov ebx,[a64 rel dword es:foo]
	mov rax,[a64 rel dword es:foo]
	mov rbx,[a64 rel dword es:foo]
	mov al,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword es:0xbbbbbbbb]
	mov bl,[a64 rel dword es:0xbbbbbbbb]
	mov ax,[a64 rel dword es:0xbbbbbbbb]
	mov bx,[a64 rel dword es:0xbbbbbbbb]
	mov eax,[a64 rel dword es:0xbbbbbbbb]
	mov ebx,[a64 rel dword es:0xbbbbbbbb]
	mov rax,[a64 rel dword es:0xbbbbbbbb]
	mov rbx,[a64 rel dword es:0xbbbbbbbb]
	mov al,[a64 rel dword es:0xffffffffcccccccc]
	mov bl,[a64 rel dword es:0xffffffffcccccccc]
	mov ax,[a64 rel dword es:0xffffffffcccccccc]
	mov bx,[a64 rel dword es:0xffffffffcccccccc]
	mov eax,[a64 rel dword es:0xffffffffcccccccc]
	mov ebx,[a64 rel dword es:0xffffffffcccccccc]
	mov rax,[a64 rel dword es:0xffffffffcccccccc]
	mov rbx,[a64 rel dword es:0xffffffffcccccccc]

	mov al,[a64 rel qword es:foo]
	mov bl,[a64 rel qword es:foo]
	mov ax,[a64 rel qword es:foo]
	mov bx,[a64 rel qword es:foo]
	mov eax,[a64 rel qword es:foo]
	mov ebx,[a64 rel qword es:foo]
	mov rax,[a64 rel qword es:foo]
	mov rbx,[a64 rel qword es:foo]
	mov al,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword es:0xbbbbbbbb]
	mov bl,[a64 rel qword es:0xbbbbbbbb]
	mov ax,[a64 rel qword es:0xbbbbbbbb]
	mov bx,[a64 rel qword es:0xbbbbbbbb]
	mov eax,[a64 rel qword es:0xbbbbbbbb]
	mov ebx,[a64 rel qword es:0xbbbbbbbb]
	mov rax,[a64 rel qword es:0xbbbbbbbb]
	mov rbx,[a64 rel qword es:0xbbbbbbbb]
	mov al,[a64 rel qword es:0xffffffffcccccccc]
	mov bl,[a64 rel qword es:0xffffffffcccccccc]
	mov ax,[a64 rel qword es:0xffffffffcccccccc]
	mov bx,[a64 rel qword es:0xffffffffcccccccc]
	mov eax,[a64 rel qword es:0xffffffffcccccccc]
	mov ebx,[a64 rel qword es:0xffffffffcccccccc]
	mov rax,[a64 rel qword es:0xffffffffcccccccc]
	mov rbx,[a64 rel qword es:0xffffffffcccccccc]

	mov al,[a32 rel es:foo]
	mov bl,[a32 rel es:foo]
	mov ax,[a32 rel es:foo]
	mov bx,[a32 rel es:foo]
	mov eax,[a32 rel es:foo]
	mov ebx,[a32 rel es:foo]
	mov rax,[a32 rel es:foo]
	mov rbx,[a32 rel es:foo]
	mov al,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel es:0xbbbbbbbb]
	mov bl,[a32 rel es:0xbbbbbbbb]
	mov ax,[a32 rel es:0xbbbbbbbb]
	mov bx,[a32 rel es:0xbbbbbbbb]
	mov eax,[a32 rel es:0xbbbbbbbb]
	mov ebx,[a32 rel es:0xbbbbbbbb]
	mov rax,[a32 rel es:0xbbbbbbbb]
	mov rbx,[a32 rel es:0xbbbbbbbb]
	mov al,[a32 rel es:0xffffffffcccccccc]
	mov bl,[a32 rel es:0xffffffffcccccccc]
	mov ax,[a32 rel es:0xffffffffcccccccc]
	mov bx,[a32 rel es:0xffffffffcccccccc]
	mov eax,[a32 rel es:0xffffffffcccccccc]
	mov ebx,[a32 rel es:0xffffffffcccccccc]
	mov rax,[a32 rel es:0xffffffffcccccccc]
	mov rbx,[a32 rel es:0xffffffffcccccccc]

	mov al,[a32 rel dword es:foo]
	mov bl,[a32 rel dword es:foo]
	mov ax,[a32 rel dword es:foo]
	mov bx,[a32 rel dword es:foo]
	mov eax,[a32 rel dword es:foo]
	mov ebx,[a32 rel dword es:foo]
	mov rax,[a32 rel dword es:foo]
	mov rbx,[a32 rel dword es:foo]
	mov al,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword es:0xbbbbbbbb]
	mov bl,[a32 rel dword es:0xbbbbbbbb]
	mov ax,[a32 rel dword es:0xbbbbbbbb]
	mov bx,[a32 rel dword es:0xbbbbbbbb]
	mov eax,[a32 rel dword es:0xbbbbbbbb]
	mov ebx,[a32 rel dword es:0xbbbbbbbb]
	mov rax,[a32 rel dword es:0xbbbbbbbb]
	mov rbx,[a32 rel dword es:0xbbbbbbbb]
	mov al,[a32 rel dword es:0xffffffffcccccccc]
	mov bl,[a32 rel dword es:0xffffffffcccccccc]
	mov ax,[a32 rel dword es:0xffffffffcccccccc]
	mov bx,[a32 rel dword es:0xffffffffcccccccc]
	mov eax,[a32 rel dword es:0xffffffffcccccccc]
	mov ebx,[a32 rel dword es:0xffffffffcccccccc]
	mov rax,[a32 rel dword es:0xffffffffcccccccc]
	mov rbx,[a32 rel dword es:0xffffffffcccccccc]

	mov al,[a32 rel qword es:foo]
	mov bl,[a32 rel qword es:foo]
	mov ax,[a32 rel qword es:foo]
	mov bx,[a32 rel qword es:foo]
	mov eax,[a32 rel qword es:foo]
	mov ebx,[a32 rel qword es:foo]
	mov rax,[a32 rel qword es:foo]
	mov rbx,[a32 rel qword es:foo]
	mov al,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword es:0xbbbbbbbb]
	mov bl,[a32 rel qword es:0xbbbbbbbb]
	mov ax,[a32 rel qword es:0xbbbbbbbb]
	mov bx,[a32 rel qword es:0xbbbbbbbb]
	mov eax,[a32 rel qword es:0xbbbbbbbb]
	mov ebx,[a32 rel qword es:0xbbbbbbbb]
	mov rax,[a32 rel qword es:0xbbbbbbbb]
	mov rbx,[a32 rel qword es:0xbbbbbbbb]
	mov al,[a32 rel qword es:0xffffffffcccccccc]
	mov bl,[a32 rel qword es:0xffffffffcccccccc]
	mov ax,[a32 rel qword es:0xffffffffcccccccc]
	mov bx,[a32 rel qword es:0xffffffffcccccccc]
	mov eax,[a32 rel qword es:0xffffffffcccccccc]
	mov ebx,[a32 rel qword es:0xffffffffcccccccc]
	mov rax,[a32 rel qword es:0xffffffffcccccccc]
	mov rbx,[a32 rel qword es:0xffffffffcccccccc]


	default rel

	mov al,[foo]
	mov bl,[foo]
	mov ax,[foo]
	mov bx,[foo]
	mov eax,[foo]
	mov ebx,[foo]
	mov rax,[foo]
	mov rbx,[foo]
	mov al,[0xaaaaaaaaaaaaaaaa]
	mov bl,[0xaaaaaaaaaaaaaaaa]
	mov ax,[0xaaaaaaaaaaaaaaaa]
	mov bx,[0xaaaaaaaaaaaaaaaa]
	mov eax,[0xaaaaaaaaaaaaaaaa]
	mov ebx,[0xaaaaaaaaaaaaaaaa]
	mov rax,[0xaaaaaaaaaaaaaaaa]
	mov rbx,[0xaaaaaaaaaaaaaaaa]
	mov al,[0xbbbbbbbb]
	mov bl,[0xbbbbbbbb]
	mov ax,[0xbbbbbbbb]
	mov bx,[0xbbbbbbbb]
	mov eax,[0xbbbbbbbb]
	mov ebx,[0xbbbbbbbb]
	mov rax,[0xbbbbbbbb]
	mov rbx,[0xbbbbbbbb]
	mov al,[0xffffffffcccccccc]
	mov bl,[0xffffffffcccccccc]
	mov ax,[0xffffffffcccccccc]
	mov bx,[0xffffffffcccccccc]
	mov eax,[0xffffffffcccccccc]
	mov ebx,[0xffffffffcccccccc]
	mov rax,[0xffffffffcccccccc]
	mov rbx,[0xffffffffcccccccc]

	mov al,[dword foo]
	mov bl,[dword foo]
	mov ax,[dword foo]
	mov bx,[dword foo]
	mov eax,[dword foo]
	mov ebx,[dword foo]
	mov rax,[dword foo]
	mov rbx,[dword foo]
	mov al,[dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword 0xaaaaaaaaaaaaaaaa]
	mov al,[dword 0xbbbbbbbb]
	mov bl,[dword 0xbbbbbbbb]
	mov ax,[dword 0xbbbbbbbb]
	mov bx,[dword 0xbbbbbbbb]
	mov eax,[dword 0xbbbbbbbb]
	mov ebx,[dword 0xbbbbbbbb]
	mov rax,[dword 0xbbbbbbbb]
	mov rbx,[dword 0xbbbbbbbb]
	mov al,[dword 0xffffffffcccccccc]
	mov bl,[dword 0xffffffffcccccccc]
	mov ax,[dword 0xffffffffcccccccc]
	mov bx,[dword 0xffffffffcccccccc]
	mov eax,[dword 0xffffffffcccccccc]
	mov ebx,[dword 0xffffffffcccccccc]
	mov rax,[dword 0xffffffffcccccccc]
	mov rbx,[dword 0xffffffffcccccccc]

	mov al,[qword foo]
	mov bl,[qword foo]
	mov ax,[qword foo]
	mov bx,[qword foo]
	mov eax,[qword foo]
	mov ebx,[qword foo]
	mov rax,[qword foo]
	mov rbx,[qword foo]
	mov al,[qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword 0xaaaaaaaaaaaaaaaa]
	mov al,[qword 0xbbbbbbbb]
	mov bl,[qword 0xbbbbbbbb]
	mov ax,[qword 0xbbbbbbbb]
	mov bx,[qword 0xbbbbbbbb]
	mov eax,[qword 0xbbbbbbbb]
	mov ebx,[qword 0xbbbbbbbb]
	mov rax,[qword 0xbbbbbbbb]
	mov rbx,[qword 0xbbbbbbbb]
	mov al,[qword 0xffffffffcccccccc]
	mov bl,[qword 0xffffffffcccccccc]
	mov ax,[qword 0xffffffffcccccccc]
	mov bx,[qword 0xffffffffcccccccc]
	mov eax,[qword 0xffffffffcccccccc]
	mov ebx,[qword 0xffffffffcccccccc]
	mov rax,[qword 0xffffffffcccccccc]
	mov rbx,[qword 0xffffffffcccccccc]

	mov al,[a64 foo]
	mov bl,[a64 foo]
	mov ax,[a64 foo]
	mov bx,[a64 foo]
	mov eax,[a64 foo]
	mov ebx,[a64 foo]
	mov rax,[a64 foo]
	mov rbx,[a64 foo]
	mov al,[a64 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 0xbbbbbbbb]
	mov bl,[a64 0xbbbbbbbb]
	mov ax,[a64 0xbbbbbbbb]
	mov bx,[a64 0xbbbbbbbb]
	mov eax,[a64 0xbbbbbbbb]
	mov ebx,[a64 0xbbbbbbbb]
	mov rax,[a64 0xbbbbbbbb]
	mov rbx,[a64 0xbbbbbbbb]
	mov al,[a64 0xffffffffcccccccc]
	mov bl,[a64 0xffffffffcccccccc]
	mov ax,[a64 0xffffffffcccccccc]
	mov bx,[a64 0xffffffffcccccccc]
	mov eax,[a64 0xffffffffcccccccc]
	mov ebx,[a64 0xffffffffcccccccc]
	mov rax,[a64 0xffffffffcccccccc]
	mov rbx,[a64 0xffffffffcccccccc]

	mov al,[a64 dword foo]
	mov bl,[a64 dword foo]
	mov ax,[a64 dword foo]
	mov bx,[a64 dword foo]
	mov eax,[a64 dword foo]
	mov ebx,[a64 dword foo]
	mov rax,[a64 dword foo]
	mov rbx,[a64 dword foo]
	mov al,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword 0xbbbbbbbb]
	mov bl,[a64 dword 0xbbbbbbbb]
	mov ax,[a64 dword 0xbbbbbbbb]
	mov bx,[a64 dword 0xbbbbbbbb]
	mov eax,[a64 dword 0xbbbbbbbb]
	mov ebx,[a64 dword 0xbbbbbbbb]
	mov rax,[a64 dword 0xbbbbbbbb]
	mov rbx,[a64 dword 0xbbbbbbbb]
	mov al,[a64 dword 0xffffffffcccccccc]
	mov bl,[a64 dword 0xffffffffcccccccc]
	mov ax,[a64 dword 0xffffffffcccccccc]
	mov bx,[a64 dword 0xffffffffcccccccc]
	mov eax,[a64 dword 0xffffffffcccccccc]
	mov ebx,[a64 dword 0xffffffffcccccccc]
	mov rax,[a64 dword 0xffffffffcccccccc]
	mov rbx,[a64 dword 0xffffffffcccccccc]

	mov al,[a64 qword foo]
	mov bl,[a64 qword foo]
	mov ax,[a64 qword foo]
	mov bx,[a64 qword foo]
	mov eax,[a64 qword foo]
	mov ebx,[a64 qword foo]
	mov rax,[a64 qword foo]
	mov rbx,[a64 qword foo]
	mov al,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword 0xbbbbbbbb]
	mov bl,[a64 qword 0xbbbbbbbb]
	mov ax,[a64 qword 0xbbbbbbbb]
	mov bx,[a64 qword 0xbbbbbbbb]
	mov eax,[a64 qword 0xbbbbbbbb]
	mov ebx,[a64 qword 0xbbbbbbbb]
	mov rax,[a64 qword 0xbbbbbbbb]
	mov rbx,[a64 qword 0xbbbbbbbb]
	mov al,[a64 qword 0xffffffffcccccccc]
	mov bl,[a64 qword 0xffffffffcccccccc]
	mov ax,[a64 qword 0xffffffffcccccccc]
	mov bx,[a64 qword 0xffffffffcccccccc]
	mov eax,[a64 qword 0xffffffffcccccccc]
	mov ebx,[a64 qword 0xffffffffcccccccc]
	mov rax,[a64 qword 0xffffffffcccccccc]
	mov rbx,[a64 qword 0xffffffffcccccccc]

	mov al,[a32 foo]
	mov bl,[a32 foo]
	mov ax,[a32 foo]
	mov bx,[a32 foo]
	mov eax,[a32 foo]
	mov ebx,[a32 foo]
	mov rax,[a32 foo]
	mov rbx,[a32 foo]
	mov al,[a32 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 0xbbbbbbbb]
	mov bl,[a32 0xbbbbbbbb]
	mov ax,[a32 0xbbbbbbbb]
	mov bx,[a32 0xbbbbbbbb]
	mov eax,[a32 0xbbbbbbbb]
	mov ebx,[a32 0xbbbbbbbb]
	mov rax,[a32 0xbbbbbbbb]
	mov rbx,[a32 0xbbbbbbbb]
	mov al,[a32 0xffffffffcccccccc]
	mov bl,[a32 0xffffffffcccccccc]
	mov ax,[a32 0xffffffffcccccccc]
	mov bx,[a32 0xffffffffcccccccc]
	mov eax,[a32 0xffffffffcccccccc]
	mov ebx,[a32 0xffffffffcccccccc]
	mov rax,[a32 0xffffffffcccccccc]
	mov rbx,[a32 0xffffffffcccccccc]

	mov al,[a32 dword foo]
	mov bl,[a32 dword foo]
	mov ax,[a32 dword foo]
	mov bx,[a32 dword foo]
	mov eax,[a32 dword foo]
	mov ebx,[a32 dword foo]
	mov rax,[a32 dword foo]
	mov rbx,[a32 dword foo]
	mov al,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword 0xbbbbbbbb]
	mov bl,[a32 dword 0xbbbbbbbb]
	mov ax,[a32 dword 0xbbbbbbbb]
	mov bx,[a32 dword 0xbbbbbbbb]
	mov eax,[a32 dword 0xbbbbbbbb]
	mov ebx,[a32 dword 0xbbbbbbbb]
	mov rax,[a32 dword 0xbbbbbbbb]
	mov rbx,[a32 dword 0xbbbbbbbb]
	mov al,[a32 dword 0xffffffffcccccccc]
	mov bl,[a32 dword 0xffffffffcccccccc]
	mov ax,[a32 dword 0xffffffffcccccccc]
	mov bx,[a32 dword 0xffffffffcccccccc]
	mov eax,[a32 dword 0xffffffffcccccccc]
	mov ebx,[a32 dword 0xffffffffcccccccc]
	mov rax,[a32 dword 0xffffffffcccccccc]
	mov rbx,[a32 dword 0xffffffffcccccccc]

	mov al,[a32 qword foo]
	mov bl,[a32 qword foo]
	mov ax,[a32 qword foo]
	mov bx,[a32 qword foo]
	mov eax,[a32 qword foo]
	mov ebx,[a32 qword foo]
	mov rax,[a32 qword foo]
	mov rbx,[a32 qword foo]
	mov al,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword 0xbbbbbbbb]
	mov bl,[a32 qword 0xbbbbbbbb]
	mov ax,[a32 qword 0xbbbbbbbb]
	mov bx,[a32 qword 0xbbbbbbbb]
	mov eax,[a32 qword 0xbbbbbbbb]
	mov ebx,[a32 qword 0xbbbbbbbb]
	mov rax,[a32 qword 0xbbbbbbbb]
	mov rbx,[a32 qword 0xbbbbbbbb]
	mov al,[a32 qword 0xffffffffcccccccc]
	mov bl,[a32 qword 0xffffffffcccccccc]
	mov ax,[a32 qword 0xffffffffcccccccc]
	mov bx,[a32 qword 0xffffffffcccccccc]
	mov eax,[a32 qword 0xffffffffcccccccc]
	mov ebx,[a32 qword 0xffffffffcccccccc]
	mov rax,[a32 qword 0xffffffffcccccccc]
	mov rbx,[a32 qword 0xffffffffcccccccc]

	mov al,[abs foo]
	mov bl,[abs foo]
	mov ax,[abs foo]
	mov bx,[abs foo]
	mov eax,[abs foo]
	mov ebx,[abs foo]
	mov rax,[abs foo]
	mov rbx,[abs foo]
	mov al,[abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs 0xaaaaaaaaaaaaaaaa]
	mov al,[abs 0xbbbbbbbb]
	mov bl,[abs 0xbbbbbbbb]
	mov ax,[abs 0xbbbbbbbb]
	mov bx,[abs 0xbbbbbbbb]
	mov eax,[abs 0xbbbbbbbb]
	mov ebx,[abs 0xbbbbbbbb]
	mov rax,[abs 0xbbbbbbbb]
	mov rbx,[abs 0xbbbbbbbb]
	mov al,[abs 0xffffffffcccccccc]
	mov bl,[abs 0xffffffffcccccccc]
	mov ax,[abs 0xffffffffcccccccc]
	mov bx,[abs 0xffffffffcccccccc]
	mov eax,[abs 0xffffffffcccccccc]
	mov ebx,[abs 0xffffffffcccccccc]
	mov rax,[abs 0xffffffffcccccccc]
	mov rbx,[abs 0xffffffffcccccccc]

	mov al,[abs dword foo]
	mov bl,[abs dword foo]
	mov ax,[abs dword foo]
	mov bx,[abs dword foo]
	mov eax,[abs dword foo]
	mov ebx,[abs dword foo]
	mov rax,[abs dword foo]
	mov rbx,[abs dword foo]
	mov al,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword 0xbbbbbbbb]
	mov bl,[abs dword 0xbbbbbbbb]
	mov ax,[abs dword 0xbbbbbbbb]
	mov bx,[abs dword 0xbbbbbbbb]
	mov eax,[abs dword 0xbbbbbbbb]
	mov ebx,[abs dword 0xbbbbbbbb]
	mov rax,[abs dword 0xbbbbbbbb]
	mov rbx,[abs dword 0xbbbbbbbb]
	mov al,[abs dword 0xffffffffcccccccc]
	mov bl,[abs dword 0xffffffffcccccccc]
	mov ax,[abs dword 0xffffffffcccccccc]
	mov bx,[abs dword 0xffffffffcccccccc]
	mov eax,[abs dword 0xffffffffcccccccc]
	mov ebx,[abs dword 0xffffffffcccccccc]
	mov rax,[abs dword 0xffffffffcccccccc]
	mov rbx,[abs dword 0xffffffffcccccccc]

	mov al,[abs qword foo]
	mov bl,[abs qword foo]
	mov ax,[abs qword foo]
	mov bx,[abs qword foo]
	mov eax,[abs qword foo]
	mov ebx,[abs qword foo]
	mov rax,[abs qword foo]
	mov rbx,[abs qword foo]
	mov al,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword 0xbbbbbbbb]
	mov bl,[abs qword 0xbbbbbbbb]
	mov ax,[abs qword 0xbbbbbbbb]
	mov bx,[abs qword 0xbbbbbbbb]
	mov eax,[abs qword 0xbbbbbbbb]
	mov ebx,[abs qword 0xbbbbbbbb]
	mov rax,[abs qword 0xbbbbbbbb]
	mov rbx,[abs qword 0xbbbbbbbb]
	mov al,[abs qword 0xffffffffcccccccc]
	mov bl,[abs qword 0xffffffffcccccccc]
	mov ax,[abs qword 0xffffffffcccccccc]
	mov bx,[abs qword 0xffffffffcccccccc]
	mov eax,[abs qword 0xffffffffcccccccc]
	mov ebx,[abs qword 0xffffffffcccccccc]
	mov rax,[abs qword 0xffffffffcccccccc]
	mov rbx,[abs qword 0xffffffffcccccccc]

	mov al,[a64 abs foo]
	mov bl,[a64 abs foo]
	mov ax,[a64 abs foo]
	mov bx,[a64 abs foo]
	mov eax,[a64 abs foo]
	mov ebx,[a64 abs foo]
	mov rax,[a64 abs foo]
	mov rbx,[a64 abs foo]
	mov al,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs 0xbbbbbbbb]
	mov bl,[a64 abs 0xbbbbbbbb]
	mov ax,[a64 abs 0xbbbbbbbb]
	mov bx,[a64 abs 0xbbbbbbbb]
	mov eax,[a64 abs 0xbbbbbbbb]
	mov ebx,[a64 abs 0xbbbbbbbb]
	mov rax,[a64 abs 0xbbbbbbbb]
	mov rbx,[a64 abs 0xbbbbbbbb]
	mov al,[a64 abs 0xffffffffcccccccc]
	mov bl,[a64 abs 0xffffffffcccccccc]
	mov ax,[a64 abs 0xffffffffcccccccc]
	mov bx,[a64 abs 0xffffffffcccccccc]
	mov eax,[a64 abs 0xffffffffcccccccc]
	mov ebx,[a64 abs 0xffffffffcccccccc]
	mov rax,[a64 abs 0xffffffffcccccccc]
	mov rbx,[a64 abs 0xffffffffcccccccc]

	mov al,[a64 abs dword foo]
	mov bl,[a64 abs dword foo]
	mov ax,[a64 abs dword foo]
	mov bx,[a64 abs dword foo]
	mov eax,[a64 abs dword foo]
	mov ebx,[a64 abs dword foo]
	mov rax,[a64 abs dword foo]
	mov rbx,[a64 abs dword foo]
	mov al,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword 0xbbbbbbbb]
	mov bl,[a64 abs dword 0xbbbbbbbb]
	mov ax,[a64 abs dword 0xbbbbbbbb]
	mov bx,[a64 abs dword 0xbbbbbbbb]
	mov eax,[a64 abs dword 0xbbbbbbbb]
	mov ebx,[a64 abs dword 0xbbbbbbbb]
	mov rax,[a64 abs dword 0xbbbbbbbb]
	mov rbx,[a64 abs dword 0xbbbbbbbb]
	mov al,[a64 abs dword 0xffffffffcccccccc]
	mov bl,[a64 abs dword 0xffffffffcccccccc]
	mov ax,[a64 abs dword 0xffffffffcccccccc]
	mov bx,[a64 abs dword 0xffffffffcccccccc]
	mov eax,[a64 abs dword 0xffffffffcccccccc]
	mov ebx,[a64 abs dword 0xffffffffcccccccc]
	mov rax,[a64 abs dword 0xffffffffcccccccc]
	mov rbx,[a64 abs dword 0xffffffffcccccccc]

	mov al,[a64 abs qword foo]
	mov bl,[a64 abs qword foo]
	mov ax,[a64 abs qword foo]
	mov bx,[a64 abs qword foo]
	mov eax,[a64 abs qword foo]
	mov ebx,[a64 abs qword foo]
	mov rax,[a64 abs qword foo]
	mov rbx,[a64 abs qword foo]
	mov al,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword 0xbbbbbbbb]
	mov bl,[a64 abs qword 0xbbbbbbbb]
	mov ax,[a64 abs qword 0xbbbbbbbb]
	mov bx,[a64 abs qword 0xbbbbbbbb]
	mov eax,[a64 abs qword 0xbbbbbbbb]
	mov ebx,[a64 abs qword 0xbbbbbbbb]
	mov rax,[a64 abs qword 0xbbbbbbbb]
	mov rbx,[a64 abs qword 0xbbbbbbbb]
	mov al,[a64 abs qword 0xffffffffcccccccc]
	mov bl,[a64 abs qword 0xffffffffcccccccc]
	mov ax,[a64 abs qword 0xffffffffcccccccc]
	mov bx,[a64 abs qword 0xffffffffcccccccc]
	mov eax,[a64 abs qword 0xffffffffcccccccc]
	mov ebx,[a64 abs qword 0xffffffffcccccccc]
	mov rax,[a64 abs qword 0xffffffffcccccccc]
	mov rbx,[a64 abs qword 0xffffffffcccccccc]

	mov al,[a32 abs foo]
	mov bl,[a32 abs foo]
	mov ax,[a32 abs foo]
	mov bx,[a32 abs foo]
	mov eax,[a32 abs foo]
	mov ebx,[a32 abs foo]
	mov rax,[a32 abs foo]
	mov rbx,[a32 abs foo]
	mov al,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs 0xbbbbbbbb]
	mov bl,[a32 abs 0xbbbbbbbb]
	mov ax,[a32 abs 0xbbbbbbbb]
	mov bx,[a32 abs 0xbbbbbbbb]
	mov eax,[a32 abs 0xbbbbbbbb]
	mov ebx,[a32 abs 0xbbbbbbbb]
	mov rax,[a32 abs 0xbbbbbbbb]
	mov rbx,[a32 abs 0xbbbbbbbb]
	mov al,[a32 abs 0xffffffffcccccccc]
	mov bl,[a32 abs 0xffffffffcccccccc]
	mov ax,[a32 abs 0xffffffffcccccccc]
	mov bx,[a32 abs 0xffffffffcccccccc]
	mov eax,[a32 abs 0xffffffffcccccccc]
	mov ebx,[a32 abs 0xffffffffcccccccc]
	mov rax,[a32 abs 0xffffffffcccccccc]
	mov rbx,[a32 abs 0xffffffffcccccccc]

	mov al,[a32 abs dword foo]
	mov bl,[a32 abs dword foo]
	mov ax,[a32 abs dword foo]
	mov bx,[a32 abs dword foo]
	mov eax,[a32 abs dword foo]
	mov ebx,[a32 abs dword foo]
	mov rax,[a32 abs dword foo]
	mov rbx,[a32 abs dword foo]
	mov al,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword 0xbbbbbbbb]
	mov bl,[a32 abs dword 0xbbbbbbbb]
	mov ax,[a32 abs dword 0xbbbbbbbb]
	mov bx,[a32 abs dword 0xbbbbbbbb]
	mov eax,[a32 abs dword 0xbbbbbbbb]
	mov ebx,[a32 abs dword 0xbbbbbbbb]
	mov rax,[a32 abs dword 0xbbbbbbbb]
	mov rbx,[a32 abs dword 0xbbbbbbbb]
	mov al,[a32 abs dword 0xffffffffcccccccc]
	mov bl,[a32 abs dword 0xffffffffcccccccc]
	mov ax,[a32 abs dword 0xffffffffcccccccc]
	mov bx,[a32 abs dword 0xffffffffcccccccc]
	mov eax,[a32 abs dword 0xffffffffcccccccc]
	mov ebx,[a32 abs dword 0xffffffffcccccccc]
	mov rax,[a32 abs dword 0xffffffffcccccccc]
	mov rbx,[a32 abs dword 0xffffffffcccccccc]

	mov al,[a32 abs qword foo]
	mov bl,[a32 abs qword foo]
	mov ax,[a32 abs qword foo]
	mov bx,[a32 abs qword foo]
	mov eax,[a32 abs qword foo]
	mov ebx,[a32 abs qword foo]
	mov rax,[a32 abs qword foo]
	mov rbx,[a32 abs qword foo]
	mov al,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword 0xbbbbbbbb]
	mov bl,[a32 abs qword 0xbbbbbbbb]
	mov ax,[a32 abs qword 0xbbbbbbbb]
	mov bx,[a32 abs qword 0xbbbbbbbb]
	mov eax,[a32 abs qword 0xbbbbbbbb]
	mov ebx,[a32 abs qword 0xbbbbbbbb]
	mov rax,[a32 abs qword 0xbbbbbbbb]
	mov rbx,[a32 abs qword 0xbbbbbbbb]
	mov al,[a32 abs qword 0xffffffffcccccccc]
	mov bl,[a32 abs qword 0xffffffffcccccccc]
	mov ax,[a32 abs qword 0xffffffffcccccccc]
	mov bx,[a32 abs qword 0xffffffffcccccccc]
	mov eax,[a32 abs qword 0xffffffffcccccccc]
	mov ebx,[a32 abs qword 0xffffffffcccccccc]
	mov rax,[a32 abs qword 0xffffffffcccccccc]
	mov rbx,[a32 abs qword 0xffffffffcccccccc]

	mov al,[rel foo]
	mov bl,[rel foo]
	mov ax,[rel foo]
	mov bx,[rel foo]
	mov eax,[rel foo]
	mov ebx,[rel foo]
	mov rax,[rel foo]
	mov rbx,[rel foo]
	mov al,[rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel 0xaaaaaaaaaaaaaaaa]
	mov al,[rel 0xbbbbbbbb]
	mov bl,[rel 0xbbbbbbbb]
	mov ax,[rel 0xbbbbbbbb]
	mov bx,[rel 0xbbbbbbbb]
	mov eax,[rel 0xbbbbbbbb]
	mov ebx,[rel 0xbbbbbbbb]
	mov rax,[rel 0xbbbbbbbb]
	mov rbx,[rel 0xbbbbbbbb]
	mov al,[rel 0xffffffffcccccccc]
	mov bl,[rel 0xffffffffcccccccc]
	mov ax,[rel 0xffffffffcccccccc]
	mov bx,[rel 0xffffffffcccccccc]
	mov eax,[rel 0xffffffffcccccccc]
	mov ebx,[rel 0xffffffffcccccccc]
	mov rax,[rel 0xffffffffcccccccc]
	mov rbx,[rel 0xffffffffcccccccc]

	mov al,[rel dword foo]
	mov bl,[rel dword foo]
	mov ax,[rel dword foo]
	mov bx,[rel dword foo]
	mov eax,[rel dword foo]
	mov ebx,[rel dword foo]
	mov rax,[rel dword foo]
	mov rbx,[rel dword foo]
	mov al,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword 0xbbbbbbbb]
	mov bl,[rel dword 0xbbbbbbbb]
	mov ax,[rel dword 0xbbbbbbbb]
	mov bx,[rel dword 0xbbbbbbbb]
	mov eax,[rel dword 0xbbbbbbbb]
	mov ebx,[rel dword 0xbbbbbbbb]
	mov rax,[rel dword 0xbbbbbbbb]
	mov rbx,[rel dword 0xbbbbbbbb]
	mov al,[rel dword 0xffffffffcccccccc]
	mov bl,[rel dword 0xffffffffcccccccc]
	mov ax,[rel dword 0xffffffffcccccccc]
	mov bx,[rel dword 0xffffffffcccccccc]
	mov eax,[rel dword 0xffffffffcccccccc]
	mov ebx,[rel dword 0xffffffffcccccccc]
	mov rax,[rel dword 0xffffffffcccccccc]
	mov rbx,[rel dword 0xffffffffcccccccc]

	mov al,[rel qword foo]
	mov bl,[rel qword foo]
	mov ax,[rel qword foo]
	mov bx,[rel qword foo]
	mov eax,[rel qword foo]
	mov ebx,[rel qword foo]
	mov rax,[rel qword foo]
	mov rbx,[rel qword foo]
	mov al,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword 0xbbbbbbbb]
	mov bl,[rel qword 0xbbbbbbbb]
	mov ax,[rel qword 0xbbbbbbbb]
	mov bx,[rel qword 0xbbbbbbbb]
	mov eax,[rel qword 0xbbbbbbbb]
	mov ebx,[rel qword 0xbbbbbbbb]
	mov rax,[rel qword 0xbbbbbbbb]
	mov rbx,[rel qword 0xbbbbbbbb]
	mov al,[rel qword 0xffffffffcccccccc]
	mov bl,[rel qword 0xffffffffcccccccc]
	mov ax,[rel qword 0xffffffffcccccccc]
	mov bx,[rel qword 0xffffffffcccccccc]
	mov eax,[rel qword 0xffffffffcccccccc]
	mov ebx,[rel qword 0xffffffffcccccccc]
	mov rax,[rel qword 0xffffffffcccccccc]
	mov rbx,[rel qword 0xffffffffcccccccc]

	mov al,[a64 rel foo]
	mov bl,[a64 rel foo]
	mov ax,[a64 rel foo]
	mov bx,[a64 rel foo]
	mov eax,[a64 rel foo]
	mov ebx,[a64 rel foo]
	mov rax,[a64 rel foo]
	mov rbx,[a64 rel foo]
	mov al,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel 0xbbbbbbbb]
	mov bl,[a64 rel 0xbbbbbbbb]
	mov ax,[a64 rel 0xbbbbbbbb]
	mov bx,[a64 rel 0xbbbbbbbb]
	mov eax,[a64 rel 0xbbbbbbbb]
	mov ebx,[a64 rel 0xbbbbbbbb]
	mov rax,[a64 rel 0xbbbbbbbb]
	mov rbx,[a64 rel 0xbbbbbbbb]
	mov al,[a64 rel 0xffffffffcccccccc]
	mov bl,[a64 rel 0xffffffffcccccccc]
	mov ax,[a64 rel 0xffffffffcccccccc]
	mov bx,[a64 rel 0xffffffffcccccccc]
	mov eax,[a64 rel 0xffffffffcccccccc]
	mov ebx,[a64 rel 0xffffffffcccccccc]
	mov rax,[a64 rel 0xffffffffcccccccc]
	mov rbx,[a64 rel 0xffffffffcccccccc]

	mov al,[a64 rel dword foo]
	mov bl,[a64 rel dword foo]
	mov ax,[a64 rel dword foo]
	mov bx,[a64 rel dword foo]
	mov eax,[a64 rel dword foo]
	mov ebx,[a64 rel dword foo]
	mov rax,[a64 rel dword foo]
	mov rbx,[a64 rel dword foo]
	mov al,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword 0xbbbbbbbb]
	mov bl,[a64 rel dword 0xbbbbbbbb]
	mov ax,[a64 rel dword 0xbbbbbbbb]
	mov bx,[a64 rel dword 0xbbbbbbbb]
	mov eax,[a64 rel dword 0xbbbbbbbb]
	mov ebx,[a64 rel dword 0xbbbbbbbb]
	mov rax,[a64 rel dword 0xbbbbbbbb]
	mov rbx,[a64 rel dword 0xbbbbbbbb]
	mov al,[a64 rel dword 0xffffffffcccccccc]
	mov bl,[a64 rel dword 0xffffffffcccccccc]
	mov ax,[a64 rel dword 0xffffffffcccccccc]
	mov bx,[a64 rel dword 0xffffffffcccccccc]
	mov eax,[a64 rel dword 0xffffffffcccccccc]
	mov ebx,[a64 rel dword 0xffffffffcccccccc]
	mov rax,[a64 rel dword 0xffffffffcccccccc]
	mov rbx,[a64 rel dword 0xffffffffcccccccc]

	mov al,[a64 rel qword foo]
	mov bl,[a64 rel qword foo]
	mov ax,[a64 rel qword foo]
	mov bx,[a64 rel qword foo]
	mov eax,[a64 rel qword foo]
	mov ebx,[a64 rel qword foo]
	mov rax,[a64 rel qword foo]
	mov rbx,[a64 rel qword foo]
	mov al,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword 0xbbbbbbbb]
	mov bl,[a64 rel qword 0xbbbbbbbb]
	mov ax,[a64 rel qword 0xbbbbbbbb]
	mov bx,[a64 rel qword 0xbbbbbbbb]
	mov eax,[a64 rel qword 0xbbbbbbbb]
	mov ebx,[a64 rel qword 0xbbbbbbbb]
	mov rax,[a64 rel qword 0xbbbbbbbb]
	mov rbx,[a64 rel qword 0xbbbbbbbb]
	mov al,[a64 rel qword 0xffffffffcccccccc]
	mov bl,[a64 rel qword 0xffffffffcccccccc]
	mov ax,[a64 rel qword 0xffffffffcccccccc]
	mov bx,[a64 rel qword 0xffffffffcccccccc]
	mov eax,[a64 rel qword 0xffffffffcccccccc]
	mov ebx,[a64 rel qword 0xffffffffcccccccc]
	mov rax,[a64 rel qword 0xffffffffcccccccc]
	mov rbx,[a64 rel qword 0xffffffffcccccccc]

	mov al,[a32 rel foo]
	mov bl,[a32 rel foo]
	mov ax,[a32 rel foo]
	mov bx,[a32 rel foo]
	mov eax,[a32 rel foo]
	mov ebx,[a32 rel foo]
	mov rax,[a32 rel foo]
	mov rbx,[a32 rel foo]
	mov al,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel 0xbbbbbbbb]
	mov bl,[a32 rel 0xbbbbbbbb]
	mov ax,[a32 rel 0xbbbbbbbb]
	mov bx,[a32 rel 0xbbbbbbbb]
	mov eax,[a32 rel 0xbbbbbbbb]
	mov ebx,[a32 rel 0xbbbbbbbb]
	mov rax,[a32 rel 0xbbbbbbbb]
	mov rbx,[a32 rel 0xbbbbbbbb]
	mov al,[a32 rel 0xffffffffcccccccc]
	mov bl,[a32 rel 0xffffffffcccccccc]
	mov ax,[a32 rel 0xffffffffcccccccc]
	mov bx,[a32 rel 0xffffffffcccccccc]
	mov eax,[a32 rel 0xffffffffcccccccc]
	mov ebx,[a32 rel 0xffffffffcccccccc]
	mov rax,[a32 rel 0xffffffffcccccccc]
	mov rbx,[a32 rel 0xffffffffcccccccc]

	mov al,[a32 rel dword foo]
	mov bl,[a32 rel dword foo]
	mov ax,[a32 rel dword foo]
	mov bx,[a32 rel dword foo]
	mov eax,[a32 rel dword foo]
	mov ebx,[a32 rel dword foo]
	mov rax,[a32 rel dword foo]
	mov rbx,[a32 rel dword foo]
	mov al,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword 0xbbbbbbbb]
	mov bl,[a32 rel dword 0xbbbbbbbb]
	mov ax,[a32 rel dword 0xbbbbbbbb]
	mov bx,[a32 rel dword 0xbbbbbbbb]
	mov eax,[a32 rel dword 0xbbbbbbbb]
	mov ebx,[a32 rel dword 0xbbbbbbbb]
	mov rax,[a32 rel dword 0xbbbbbbbb]
	mov rbx,[a32 rel dword 0xbbbbbbbb]
	mov al,[a32 rel dword 0xffffffffcccccccc]
	mov bl,[a32 rel dword 0xffffffffcccccccc]
	mov ax,[a32 rel dword 0xffffffffcccccccc]
	mov bx,[a32 rel dword 0xffffffffcccccccc]
	mov eax,[a32 rel dword 0xffffffffcccccccc]
	mov ebx,[a32 rel dword 0xffffffffcccccccc]
	mov rax,[a32 rel dword 0xffffffffcccccccc]
	mov rbx,[a32 rel dword 0xffffffffcccccccc]

	mov al,[a32 rel qword foo]
	mov bl,[a32 rel qword foo]
	mov ax,[a32 rel qword foo]
	mov bx,[a32 rel qword foo]
	mov eax,[a32 rel qword foo]
	mov ebx,[a32 rel qword foo]
	mov rax,[a32 rel qword foo]
	mov rbx,[a32 rel qword foo]
	mov al,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword 0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword 0xbbbbbbbb]
	mov bl,[a32 rel qword 0xbbbbbbbb]
	mov ax,[a32 rel qword 0xbbbbbbbb]
	mov bx,[a32 rel qword 0xbbbbbbbb]
	mov eax,[a32 rel qword 0xbbbbbbbb]
	mov ebx,[a32 rel qword 0xbbbbbbbb]
	mov rax,[a32 rel qword 0xbbbbbbbb]
	mov rbx,[a32 rel qword 0xbbbbbbbb]
	mov al,[a32 rel qword 0xffffffffcccccccc]
	mov bl,[a32 rel qword 0xffffffffcccccccc]
	mov ax,[a32 rel qword 0xffffffffcccccccc]
	mov bx,[a32 rel qword 0xffffffffcccccccc]
	mov eax,[a32 rel qword 0xffffffffcccccccc]
	mov ebx,[a32 rel qword 0xffffffffcccccccc]
	mov rax,[a32 rel qword 0xffffffffcccccccc]
	mov rbx,[a32 rel qword 0xffffffffcccccccc]

	mov al,[fs:foo]
	mov bl,[fs:foo]
	mov ax,[fs:foo]
	mov bx,[fs:foo]
	mov eax,[fs:foo]
	mov ebx,[fs:foo]
	mov rax,[fs:foo]
	mov rbx,[fs:foo]
	mov al,[fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[fs:0xaaaaaaaaaaaaaaaa]
	mov al,[fs:0xbbbbbbbb]
	mov bl,[fs:0xbbbbbbbb]
	mov ax,[fs:0xbbbbbbbb]
	mov bx,[fs:0xbbbbbbbb]
	mov eax,[fs:0xbbbbbbbb]
	mov ebx,[fs:0xbbbbbbbb]
	mov rax,[fs:0xbbbbbbbb]
	mov rbx,[fs:0xbbbbbbbb]
	mov al,[fs:0xffffffffcccccccc]
	mov bl,[fs:0xffffffffcccccccc]
	mov ax,[fs:0xffffffffcccccccc]
	mov bx,[fs:0xffffffffcccccccc]
	mov eax,[fs:0xffffffffcccccccc]
	mov ebx,[fs:0xffffffffcccccccc]
	mov rax,[fs:0xffffffffcccccccc]
	mov rbx,[fs:0xffffffffcccccccc]

	mov al,[dword fs:foo]
	mov bl,[dword fs:foo]
	mov ax,[dword fs:foo]
	mov bx,[dword fs:foo]
	mov eax,[dword fs:foo]
	mov ebx,[dword fs:foo]
	mov rax,[dword fs:foo]
	mov rbx,[dword fs:foo]
	mov al,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[dword fs:0xbbbbbbbb]
	mov bl,[dword fs:0xbbbbbbbb]
	mov ax,[dword fs:0xbbbbbbbb]
	mov bx,[dword fs:0xbbbbbbbb]
	mov eax,[dword fs:0xbbbbbbbb]
	mov ebx,[dword fs:0xbbbbbbbb]
	mov rax,[dword fs:0xbbbbbbbb]
	mov rbx,[dword fs:0xbbbbbbbb]
	mov al,[dword fs:0xffffffffcccccccc]
	mov bl,[dword fs:0xffffffffcccccccc]
	mov ax,[dword fs:0xffffffffcccccccc]
	mov bx,[dword fs:0xffffffffcccccccc]
	mov eax,[dword fs:0xffffffffcccccccc]
	mov ebx,[dword fs:0xffffffffcccccccc]
	mov rax,[dword fs:0xffffffffcccccccc]
	mov rbx,[dword fs:0xffffffffcccccccc]

	mov al,[qword fs:foo]
	mov bl,[qword fs:foo]
	mov ax,[qword fs:foo]
	mov bx,[qword fs:foo]
	mov eax,[qword fs:foo]
	mov ebx,[qword fs:foo]
	mov rax,[qword fs:foo]
	mov rbx,[qword fs:foo]
	mov al,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[qword fs:0xbbbbbbbb]
	mov bl,[qword fs:0xbbbbbbbb]
	mov ax,[qword fs:0xbbbbbbbb]
	mov bx,[qword fs:0xbbbbbbbb]
	mov eax,[qword fs:0xbbbbbbbb]
	mov ebx,[qword fs:0xbbbbbbbb]
	mov rax,[qword fs:0xbbbbbbbb]
	mov rbx,[qword fs:0xbbbbbbbb]
	mov al,[qword fs:0xffffffffcccccccc]
	mov bl,[qword fs:0xffffffffcccccccc]
	mov ax,[qword fs:0xffffffffcccccccc]
	mov bx,[qword fs:0xffffffffcccccccc]
	mov eax,[qword fs:0xffffffffcccccccc]
	mov ebx,[qword fs:0xffffffffcccccccc]
	mov rax,[qword fs:0xffffffffcccccccc]
	mov rbx,[qword fs:0xffffffffcccccccc]

	mov al,[a64 fs:foo]
	mov bl,[a64 fs:foo]
	mov ax,[a64 fs:foo]
	mov bx,[a64 fs:foo]
	mov eax,[a64 fs:foo]
	mov ebx,[a64 fs:foo]
	mov rax,[a64 fs:foo]
	mov rbx,[a64 fs:foo]
	mov al,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 fs:0xbbbbbbbb]
	mov bl,[a64 fs:0xbbbbbbbb]
	mov ax,[a64 fs:0xbbbbbbbb]
	mov bx,[a64 fs:0xbbbbbbbb]
	mov eax,[a64 fs:0xbbbbbbbb]
	mov ebx,[a64 fs:0xbbbbbbbb]
	mov rax,[a64 fs:0xbbbbbbbb]
	mov rbx,[a64 fs:0xbbbbbbbb]
	mov al,[a64 fs:0xffffffffcccccccc]
	mov bl,[a64 fs:0xffffffffcccccccc]
	mov ax,[a64 fs:0xffffffffcccccccc]
	mov bx,[a64 fs:0xffffffffcccccccc]
	mov eax,[a64 fs:0xffffffffcccccccc]
	mov ebx,[a64 fs:0xffffffffcccccccc]
	mov rax,[a64 fs:0xffffffffcccccccc]
	mov rbx,[a64 fs:0xffffffffcccccccc]

	mov al,[a64 dword fs:foo]
	mov bl,[a64 dword fs:foo]
	mov ax,[a64 dword fs:foo]
	mov bx,[a64 dword fs:foo]
	mov eax,[a64 dword fs:foo]
	mov ebx,[a64 dword fs:foo]
	mov rax,[a64 dword fs:foo]
	mov rbx,[a64 dword fs:foo]
	mov al,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword fs:0xbbbbbbbb]
	mov bl,[a64 dword fs:0xbbbbbbbb]
	mov ax,[a64 dword fs:0xbbbbbbbb]
	mov bx,[a64 dword fs:0xbbbbbbbb]
	mov eax,[a64 dword fs:0xbbbbbbbb]
	mov ebx,[a64 dword fs:0xbbbbbbbb]
	mov rax,[a64 dword fs:0xbbbbbbbb]
	mov rbx,[a64 dword fs:0xbbbbbbbb]
	mov al,[a64 dword fs:0xffffffffcccccccc]
	mov bl,[a64 dword fs:0xffffffffcccccccc]
	mov ax,[a64 dword fs:0xffffffffcccccccc]
	mov bx,[a64 dword fs:0xffffffffcccccccc]
	mov eax,[a64 dword fs:0xffffffffcccccccc]
	mov ebx,[a64 dword fs:0xffffffffcccccccc]
	mov rax,[a64 dword fs:0xffffffffcccccccc]
	mov rbx,[a64 dword fs:0xffffffffcccccccc]

	mov al,[a64 qword fs:foo]
	mov bl,[a64 qword fs:foo]
	mov ax,[a64 qword fs:foo]
	mov bx,[a64 qword fs:foo]
	mov eax,[a64 qword fs:foo]
	mov ebx,[a64 qword fs:foo]
	mov rax,[a64 qword fs:foo]
	mov rbx,[a64 qword fs:foo]
	mov al,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword fs:0xbbbbbbbb]
	mov bl,[a64 qword fs:0xbbbbbbbb]
	mov ax,[a64 qword fs:0xbbbbbbbb]
	mov bx,[a64 qword fs:0xbbbbbbbb]
	mov eax,[a64 qword fs:0xbbbbbbbb]
	mov ebx,[a64 qword fs:0xbbbbbbbb]
	mov rax,[a64 qword fs:0xbbbbbbbb]
	mov rbx,[a64 qword fs:0xbbbbbbbb]
	mov al,[a64 qword fs:0xffffffffcccccccc]
	mov bl,[a64 qword fs:0xffffffffcccccccc]
	mov ax,[a64 qword fs:0xffffffffcccccccc]
	mov bx,[a64 qword fs:0xffffffffcccccccc]
	mov eax,[a64 qword fs:0xffffffffcccccccc]
	mov ebx,[a64 qword fs:0xffffffffcccccccc]
	mov rax,[a64 qword fs:0xffffffffcccccccc]
	mov rbx,[a64 qword fs:0xffffffffcccccccc]

	mov al,[a32 fs:foo]
	mov bl,[a32 fs:foo]
	mov ax,[a32 fs:foo]
	mov bx,[a32 fs:foo]
	mov eax,[a32 fs:foo]
	mov ebx,[a32 fs:foo]
	mov rax,[a32 fs:foo]
	mov rbx,[a32 fs:foo]
	mov al,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 fs:0xbbbbbbbb]
	mov bl,[a32 fs:0xbbbbbbbb]
	mov ax,[a32 fs:0xbbbbbbbb]
	mov bx,[a32 fs:0xbbbbbbbb]
	mov eax,[a32 fs:0xbbbbbbbb]
	mov ebx,[a32 fs:0xbbbbbbbb]
	mov rax,[a32 fs:0xbbbbbbbb]
	mov rbx,[a32 fs:0xbbbbbbbb]
	mov al,[a32 fs:0xffffffffcccccccc]
	mov bl,[a32 fs:0xffffffffcccccccc]
	mov ax,[a32 fs:0xffffffffcccccccc]
	mov bx,[a32 fs:0xffffffffcccccccc]
	mov eax,[a32 fs:0xffffffffcccccccc]
	mov ebx,[a32 fs:0xffffffffcccccccc]
	mov rax,[a32 fs:0xffffffffcccccccc]
	mov rbx,[a32 fs:0xffffffffcccccccc]

	mov al,[a32 dword fs:foo]
	mov bl,[a32 dword fs:foo]
	mov ax,[a32 dword fs:foo]
	mov bx,[a32 dword fs:foo]
	mov eax,[a32 dword fs:foo]
	mov ebx,[a32 dword fs:foo]
	mov rax,[a32 dword fs:foo]
	mov rbx,[a32 dword fs:foo]
	mov al,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword fs:0xbbbbbbbb]
	mov bl,[a32 dword fs:0xbbbbbbbb]
	mov ax,[a32 dword fs:0xbbbbbbbb]
	mov bx,[a32 dword fs:0xbbbbbbbb]
	mov eax,[a32 dword fs:0xbbbbbbbb]
	mov ebx,[a32 dword fs:0xbbbbbbbb]
	mov rax,[a32 dword fs:0xbbbbbbbb]
	mov rbx,[a32 dword fs:0xbbbbbbbb]
	mov al,[a32 dword fs:0xffffffffcccccccc]
	mov bl,[a32 dword fs:0xffffffffcccccccc]
	mov ax,[a32 dword fs:0xffffffffcccccccc]
	mov bx,[a32 dword fs:0xffffffffcccccccc]
	mov eax,[a32 dword fs:0xffffffffcccccccc]
	mov ebx,[a32 dword fs:0xffffffffcccccccc]
	mov rax,[a32 dword fs:0xffffffffcccccccc]
	mov rbx,[a32 dword fs:0xffffffffcccccccc]

	mov al,[a32 qword fs:foo]
	mov bl,[a32 qword fs:foo]
	mov ax,[a32 qword fs:foo]
	mov bx,[a32 qword fs:foo]
	mov eax,[a32 qword fs:foo]
	mov ebx,[a32 qword fs:foo]
	mov rax,[a32 qword fs:foo]
	mov rbx,[a32 qword fs:foo]
	mov al,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword fs:0xbbbbbbbb]
	mov bl,[a32 qword fs:0xbbbbbbbb]
	mov ax,[a32 qword fs:0xbbbbbbbb]
	mov bx,[a32 qword fs:0xbbbbbbbb]
	mov eax,[a32 qword fs:0xbbbbbbbb]
	mov ebx,[a32 qword fs:0xbbbbbbbb]
	mov rax,[a32 qword fs:0xbbbbbbbb]
	mov rbx,[a32 qword fs:0xbbbbbbbb]
	mov al,[a32 qword fs:0xffffffffcccccccc]
	mov bl,[a32 qword fs:0xffffffffcccccccc]
	mov ax,[a32 qword fs:0xffffffffcccccccc]
	mov bx,[a32 qword fs:0xffffffffcccccccc]
	mov eax,[a32 qword fs:0xffffffffcccccccc]
	mov ebx,[a32 qword fs:0xffffffffcccccccc]
	mov rax,[a32 qword fs:0xffffffffcccccccc]
	mov rbx,[a32 qword fs:0xffffffffcccccccc]

	mov al,[abs fs:foo]
	mov bl,[abs fs:foo]
	mov ax,[abs fs:foo]
	mov bx,[abs fs:foo]
	mov eax,[abs fs:foo]
	mov ebx,[abs fs:foo]
	mov rax,[abs fs:foo]
	mov rbx,[abs fs:foo]
	mov al,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs fs:0xbbbbbbbb]
	mov bl,[abs fs:0xbbbbbbbb]
	mov ax,[abs fs:0xbbbbbbbb]
	mov bx,[abs fs:0xbbbbbbbb]
	mov eax,[abs fs:0xbbbbbbbb]
	mov ebx,[abs fs:0xbbbbbbbb]
	mov rax,[abs fs:0xbbbbbbbb]
	mov rbx,[abs fs:0xbbbbbbbb]
	mov al,[abs fs:0xffffffffcccccccc]
	mov bl,[abs fs:0xffffffffcccccccc]
	mov ax,[abs fs:0xffffffffcccccccc]
	mov bx,[abs fs:0xffffffffcccccccc]
	mov eax,[abs fs:0xffffffffcccccccc]
	mov ebx,[abs fs:0xffffffffcccccccc]
	mov rax,[abs fs:0xffffffffcccccccc]
	mov rbx,[abs fs:0xffffffffcccccccc]

	mov al,[abs dword fs:foo]
	mov bl,[abs dword fs:foo]
	mov ax,[abs dword fs:foo]
	mov bx,[abs dword fs:foo]
	mov eax,[abs dword fs:foo]
	mov ebx,[abs dword fs:foo]
	mov rax,[abs dword fs:foo]
	mov rbx,[abs dword fs:foo]
	mov al,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword fs:0xbbbbbbbb]
	mov bl,[abs dword fs:0xbbbbbbbb]
	mov ax,[abs dword fs:0xbbbbbbbb]
	mov bx,[abs dword fs:0xbbbbbbbb]
	mov eax,[abs dword fs:0xbbbbbbbb]
	mov ebx,[abs dword fs:0xbbbbbbbb]
	mov rax,[abs dword fs:0xbbbbbbbb]
	mov rbx,[abs dword fs:0xbbbbbbbb]
	mov al,[abs dword fs:0xffffffffcccccccc]
	mov bl,[abs dword fs:0xffffffffcccccccc]
	mov ax,[abs dword fs:0xffffffffcccccccc]
	mov bx,[abs dword fs:0xffffffffcccccccc]
	mov eax,[abs dword fs:0xffffffffcccccccc]
	mov ebx,[abs dword fs:0xffffffffcccccccc]
	mov rax,[abs dword fs:0xffffffffcccccccc]
	mov rbx,[abs dword fs:0xffffffffcccccccc]

	mov al,[abs qword fs:foo]
	mov bl,[abs qword fs:foo]
	mov ax,[abs qword fs:foo]
	mov bx,[abs qword fs:foo]
	mov eax,[abs qword fs:foo]
	mov ebx,[abs qword fs:foo]
	mov rax,[abs qword fs:foo]
	mov rbx,[abs qword fs:foo]
	mov al,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword fs:0xbbbbbbbb]
	mov bl,[abs qword fs:0xbbbbbbbb]
	mov ax,[abs qword fs:0xbbbbbbbb]
	mov bx,[abs qword fs:0xbbbbbbbb]
	mov eax,[abs qword fs:0xbbbbbbbb]
	mov ebx,[abs qword fs:0xbbbbbbbb]
	mov rax,[abs qword fs:0xbbbbbbbb]
	mov rbx,[abs qword fs:0xbbbbbbbb]
	mov al,[abs qword fs:0xffffffffcccccccc]
	mov bl,[abs qword fs:0xffffffffcccccccc]
	mov ax,[abs qword fs:0xffffffffcccccccc]
	mov bx,[abs qword fs:0xffffffffcccccccc]
	mov eax,[abs qword fs:0xffffffffcccccccc]
	mov ebx,[abs qword fs:0xffffffffcccccccc]
	mov rax,[abs qword fs:0xffffffffcccccccc]
	mov rbx,[abs qword fs:0xffffffffcccccccc]

	mov al,[a64 abs fs:foo]
	mov bl,[a64 abs fs:foo]
	mov ax,[a64 abs fs:foo]
	mov bx,[a64 abs fs:foo]
	mov eax,[a64 abs fs:foo]
	mov ebx,[a64 abs fs:foo]
	mov rax,[a64 abs fs:foo]
	mov rbx,[a64 abs fs:foo]
	mov al,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs fs:0xbbbbbbbb]
	mov bl,[a64 abs fs:0xbbbbbbbb]
	mov ax,[a64 abs fs:0xbbbbbbbb]
	mov bx,[a64 abs fs:0xbbbbbbbb]
	mov eax,[a64 abs fs:0xbbbbbbbb]
	mov ebx,[a64 abs fs:0xbbbbbbbb]
	mov rax,[a64 abs fs:0xbbbbbbbb]
	mov rbx,[a64 abs fs:0xbbbbbbbb]
	mov al,[a64 abs fs:0xffffffffcccccccc]
	mov bl,[a64 abs fs:0xffffffffcccccccc]
	mov ax,[a64 abs fs:0xffffffffcccccccc]
	mov bx,[a64 abs fs:0xffffffffcccccccc]
	mov eax,[a64 abs fs:0xffffffffcccccccc]
	mov ebx,[a64 abs fs:0xffffffffcccccccc]
	mov rax,[a64 abs fs:0xffffffffcccccccc]
	mov rbx,[a64 abs fs:0xffffffffcccccccc]

	mov al,[a64 abs dword fs:foo]
	mov bl,[a64 abs dword fs:foo]
	mov ax,[a64 abs dword fs:foo]
	mov bx,[a64 abs dword fs:foo]
	mov eax,[a64 abs dword fs:foo]
	mov ebx,[a64 abs dword fs:foo]
	mov rax,[a64 abs dword fs:foo]
	mov rbx,[a64 abs dword fs:foo]
	mov al,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword fs:0xbbbbbbbb]
	mov bl,[a64 abs dword fs:0xbbbbbbbb]
	mov ax,[a64 abs dword fs:0xbbbbbbbb]
	mov bx,[a64 abs dword fs:0xbbbbbbbb]
	mov eax,[a64 abs dword fs:0xbbbbbbbb]
	mov ebx,[a64 abs dword fs:0xbbbbbbbb]
	mov rax,[a64 abs dword fs:0xbbbbbbbb]
	mov rbx,[a64 abs dword fs:0xbbbbbbbb]
	mov al,[a64 abs dword fs:0xffffffffcccccccc]
	mov bl,[a64 abs dword fs:0xffffffffcccccccc]
	mov ax,[a64 abs dword fs:0xffffffffcccccccc]
	mov bx,[a64 abs dword fs:0xffffffffcccccccc]
	mov eax,[a64 abs dword fs:0xffffffffcccccccc]
	mov ebx,[a64 abs dword fs:0xffffffffcccccccc]
	mov rax,[a64 abs dword fs:0xffffffffcccccccc]
	mov rbx,[a64 abs dword fs:0xffffffffcccccccc]

	mov al,[a64 abs qword fs:foo]
	mov bl,[a64 abs qword fs:foo]
	mov ax,[a64 abs qword fs:foo]
	mov bx,[a64 abs qword fs:foo]
	mov eax,[a64 abs qword fs:foo]
	mov ebx,[a64 abs qword fs:foo]
	mov rax,[a64 abs qword fs:foo]
	mov rbx,[a64 abs qword fs:foo]
	mov al,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword fs:0xbbbbbbbb]
	mov bl,[a64 abs qword fs:0xbbbbbbbb]
	mov ax,[a64 abs qword fs:0xbbbbbbbb]
	mov bx,[a64 abs qword fs:0xbbbbbbbb]
	mov eax,[a64 abs qword fs:0xbbbbbbbb]
	mov ebx,[a64 abs qword fs:0xbbbbbbbb]
	mov rax,[a64 abs qword fs:0xbbbbbbbb]
	mov rbx,[a64 abs qword fs:0xbbbbbbbb]
	mov al,[a64 abs qword fs:0xffffffffcccccccc]
	mov bl,[a64 abs qword fs:0xffffffffcccccccc]
	mov ax,[a64 abs qword fs:0xffffffffcccccccc]
	mov bx,[a64 abs qword fs:0xffffffffcccccccc]
	mov eax,[a64 abs qword fs:0xffffffffcccccccc]
	mov ebx,[a64 abs qword fs:0xffffffffcccccccc]
	mov rax,[a64 abs qword fs:0xffffffffcccccccc]
	mov rbx,[a64 abs qword fs:0xffffffffcccccccc]

	mov al,[a32 abs fs:foo]
	mov bl,[a32 abs fs:foo]
	mov ax,[a32 abs fs:foo]
	mov bx,[a32 abs fs:foo]
	mov eax,[a32 abs fs:foo]
	mov ebx,[a32 abs fs:foo]
	mov rax,[a32 abs fs:foo]
	mov rbx,[a32 abs fs:foo]
	mov al,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs fs:0xbbbbbbbb]
	mov bl,[a32 abs fs:0xbbbbbbbb]
	mov ax,[a32 abs fs:0xbbbbbbbb]
	mov bx,[a32 abs fs:0xbbbbbbbb]
	mov eax,[a32 abs fs:0xbbbbbbbb]
	mov ebx,[a32 abs fs:0xbbbbbbbb]
	mov rax,[a32 abs fs:0xbbbbbbbb]
	mov rbx,[a32 abs fs:0xbbbbbbbb]
	mov al,[a32 abs fs:0xffffffffcccccccc]
	mov bl,[a32 abs fs:0xffffffffcccccccc]
	mov ax,[a32 abs fs:0xffffffffcccccccc]
	mov bx,[a32 abs fs:0xffffffffcccccccc]
	mov eax,[a32 abs fs:0xffffffffcccccccc]
	mov ebx,[a32 abs fs:0xffffffffcccccccc]
	mov rax,[a32 abs fs:0xffffffffcccccccc]
	mov rbx,[a32 abs fs:0xffffffffcccccccc]

	mov al,[a32 abs dword fs:foo]
	mov bl,[a32 abs dword fs:foo]
	mov ax,[a32 abs dword fs:foo]
	mov bx,[a32 abs dword fs:foo]
	mov eax,[a32 abs dword fs:foo]
	mov ebx,[a32 abs dword fs:foo]
	mov rax,[a32 abs dword fs:foo]
	mov rbx,[a32 abs dword fs:foo]
	mov al,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword fs:0xbbbbbbbb]
	mov bl,[a32 abs dword fs:0xbbbbbbbb]
	mov ax,[a32 abs dword fs:0xbbbbbbbb]
	mov bx,[a32 abs dword fs:0xbbbbbbbb]
	mov eax,[a32 abs dword fs:0xbbbbbbbb]
	mov ebx,[a32 abs dword fs:0xbbbbbbbb]
	mov rax,[a32 abs dword fs:0xbbbbbbbb]
	mov rbx,[a32 abs dword fs:0xbbbbbbbb]
	mov al,[a32 abs dword fs:0xffffffffcccccccc]
	mov bl,[a32 abs dword fs:0xffffffffcccccccc]
	mov ax,[a32 abs dword fs:0xffffffffcccccccc]
	mov bx,[a32 abs dword fs:0xffffffffcccccccc]
	mov eax,[a32 abs dword fs:0xffffffffcccccccc]
	mov ebx,[a32 abs dword fs:0xffffffffcccccccc]
	mov rax,[a32 abs dword fs:0xffffffffcccccccc]
	mov rbx,[a32 abs dword fs:0xffffffffcccccccc]

	mov al,[a32 abs qword fs:foo]
	mov bl,[a32 abs qword fs:foo]
	mov ax,[a32 abs qword fs:foo]
	mov bx,[a32 abs qword fs:foo]
	mov eax,[a32 abs qword fs:foo]
	mov ebx,[a32 abs qword fs:foo]
	mov rax,[a32 abs qword fs:foo]
	mov rbx,[a32 abs qword fs:foo]
	mov al,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword fs:0xbbbbbbbb]
	mov bl,[a32 abs qword fs:0xbbbbbbbb]
	mov ax,[a32 abs qword fs:0xbbbbbbbb]
	mov bx,[a32 abs qword fs:0xbbbbbbbb]
	mov eax,[a32 abs qword fs:0xbbbbbbbb]
	mov ebx,[a32 abs qword fs:0xbbbbbbbb]
	mov rax,[a32 abs qword fs:0xbbbbbbbb]
	mov rbx,[a32 abs qword fs:0xbbbbbbbb]
	mov al,[a32 abs qword fs:0xffffffffcccccccc]
	mov bl,[a32 abs qword fs:0xffffffffcccccccc]
	mov ax,[a32 abs qword fs:0xffffffffcccccccc]
	mov bx,[a32 abs qword fs:0xffffffffcccccccc]
	mov eax,[a32 abs qword fs:0xffffffffcccccccc]
	mov ebx,[a32 abs qword fs:0xffffffffcccccccc]
	mov rax,[a32 abs qword fs:0xffffffffcccccccc]
	mov rbx,[a32 abs qword fs:0xffffffffcccccccc]

	mov al,[rel fs:foo]
	mov bl,[rel fs:foo]
	mov ax,[rel fs:foo]
	mov bx,[rel fs:foo]
	mov eax,[rel fs:foo]
	mov ebx,[rel fs:foo]
	mov rax,[rel fs:foo]
	mov rbx,[rel fs:foo]
	mov al,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel fs:0xbbbbbbbb]
	mov bl,[rel fs:0xbbbbbbbb]
	mov ax,[rel fs:0xbbbbbbbb]
	mov bx,[rel fs:0xbbbbbbbb]
	mov eax,[rel fs:0xbbbbbbbb]
	mov ebx,[rel fs:0xbbbbbbbb]
	mov rax,[rel fs:0xbbbbbbbb]
	mov rbx,[rel fs:0xbbbbbbbb]
	mov al,[rel fs:0xffffffffcccccccc]
	mov bl,[rel fs:0xffffffffcccccccc]
	mov ax,[rel fs:0xffffffffcccccccc]
	mov bx,[rel fs:0xffffffffcccccccc]
	mov eax,[rel fs:0xffffffffcccccccc]
	mov ebx,[rel fs:0xffffffffcccccccc]
	mov rax,[rel fs:0xffffffffcccccccc]
	mov rbx,[rel fs:0xffffffffcccccccc]

	mov al,[rel dword fs:foo]
	mov bl,[rel dword fs:foo]
	mov ax,[rel dword fs:foo]
	mov bx,[rel dword fs:foo]
	mov eax,[rel dword fs:foo]
	mov ebx,[rel dword fs:foo]
	mov rax,[rel dword fs:foo]
	mov rbx,[rel dword fs:foo]
	mov al,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword fs:0xbbbbbbbb]
	mov bl,[rel dword fs:0xbbbbbbbb]
	mov ax,[rel dword fs:0xbbbbbbbb]
	mov bx,[rel dword fs:0xbbbbbbbb]
	mov eax,[rel dword fs:0xbbbbbbbb]
	mov ebx,[rel dword fs:0xbbbbbbbb]
	mov rax,[rel dword fs:0xbbbbbbbb]
	mov rbx,[rel dword fs:0xbbbbbbbb]
	mov al,[rel dword fs:0xffffffffcccccccc]
	mov bl,[rel dword fs:0xffffffffcccccccc]
	mov ax,[rel dword fs:0xffffffffcccccccc]
	mov bx,[rel dword fs:0xffffffffcccccccc]
	mov eax,[rel dword fs:0xffffffffcccccccc]
	mov ebx,[rel dword fs:0xffffffffcccccccc]
	mov rax,[rel dword fs:0xffffffffcccccccc]
	mov rbx,[rel dword fs:0xffffffffcccccccc]

	mov al,[rel qword fs:foo]
	mov bl,[rel qword fs:foo]
	mov ax,[rel qword fs:foo]
	mov bx,[rel qword fs:foo]
	mov eax,[rel qword fs:foo]
	mov ebx,[rel qword fs:foo]
	mov rax,[rel qword fs:foo]
	mov rbx,[rel qword fs:foo]
	mov al,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword fs:0xbbbbbbbb]
	mov bl,[rel qword fs:0xbbbbbbbb]
	mov ax,[rel qword fs:0xbbbbbbbb]
	mov bx,[rel qword fs:0xbbbbbbbb]
	mov eax,[rel qword fs:0xbbbbbbbb]
	mov ebx,[rel qword fs:0xbbbbbbbb]
	mov rax,[rel qword fs:0xbbbbbbbb]
	mov rbx,[rel qword fs:0xbbbbbbbb]
	mov al,[rel qword fs:0xffffffffcccccccc]
	mov bl,[rel qword fs:0xffffffffcccccccc]
	mov ax,[rel qword fs:0xffffffffcccccccc]
	mov bx,[rel qword fs:0xffffffffcccccccc]
	mov eax,[rel qword fs:0xffffffffcccccccc]
	mov ebx,[rel qword fs:0xffffffffcccccccc]
	mov rax,[rel qword fs:0xffffffffcccccccc]
	mov rbx,[rel qword fs:0xffffffffcccccccc]

	mov al,[a64 rel fs:foo]
	mov bl,[a64 rel fs:foo]
	mov ax,[a64 rel fs:foo]
	mov bx,[a64 rel fs:foo]
	mov eax,[a64 rel fs:foo]
	mov ebx,[a64 rel fs:foo]
	mov rax,[a64 rel fs:foo]
	mov rbx,[a64 rel fs:foo]
	mov al,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel fs:0xbbbbbbbb]
	mov bl,[a64 rel fs:0xbbbbbbbb]
	mov ax,[a64 rel fs:0xbbbbbbbb]
	mov bx,[a64 rel fs:0xbbbbbbbb]
	mov eax,[a64 rel fs:0xbbbbbbbb]
	mov ebx,[a64 rel fs:0xbbbbbbbb]
	mov rax,[a64 rel fs:0xbbbbbbbb]
	mov rbx,[a64 rel fs:0xbbbbbbbb]
	mov al,[a64 rel fs:0xffffffffcccccccc]
	mov bl,[a64 rel fs:0xffffffffcccccccc]
	mov ax,[a64 rel fs:0xffffffffcccccccc]
	mov bx,[a64 rel fs:0xffffffffcccccccc]
	mov eax,[a64 rel fs:0xffffffffcccccccc]
	mov ebx,[a64 rel fs:0xffffffffcccccccc]
	mov rax,[a64 rel fs:0xffffffffcccccccc]
	mov rbx,[a64 rel fs:0xffffffffcccccccc]

	mov al,[a64 rel dword fs:foo]
	mov bl,[a64 rel dword fs:foo]
	mov ax,[a64 rel dword fs:foo]
	mov bx,[a64 rel dword fs:foo]
	mov eax,[a64 rel dword fs:foo]
	mov ebx,[a64 rel dword fs:foo]
	mov rax,[a64 rel dword fs:foo]
	mov rbx,[a64 rel dword fs:foo]
	mov al,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword fs:0xbbbbbbbb]
	mov bl,[a64 rel dword fs:0xbbbbbbbb]
	mov ax,[a64 rel dword fs:0xbbbbbbbb]
	mov bx,[a64 rel dword fs:0xbbbbbbbb]
	mov eax,[a64 rel dword fs:0xbbbbbbbb]
	mov ebx,[a64 rel dword fs:0xbbbbbbbb]
	mov rax,[a64 rel dword fs:0xbbbbbbbb]
	mov rbx,[a64 rel dword fs:0xbbbbbbbb]
	mov al,[a64 rel dword fs:0xffffffffcccccccc]
	mov bl,[a64 rel dword fs:0xffffffffcccccccc]
	mov ax,[a64 rel dword fs:0xffffffffcccccccc]
	mov bx,[a64 rel dword fs:0xffffffffcccccccc]
	mov eax,[a64 rel dword fs:0xffffffffcccccccc]
	mov ebx,[a64 rel dword fs:0xffffffffcccccccc]
	mov rax,[a64 rel dword fs:0xffffffffcccccccc]
	mov rbx,[a64 rel dword fs:0xffffffffcccccccc]

	mov al,[a64 rel qword fs:foo]
	mov bl,[a64 rel qword fs:foo]
	mov ax,[a64 rel qword fs:foo]
	mov bx,[a64 rel qword fs:foo]
	mov eax,[a64 rel qword fs:foo]
	mov ebx,[a64 rel qword fs:foo]
	mov rax,[a64 rel qword fs:foo]
	mov rbx,[a64 rel qword fs:foo]
	mov al,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword fs:0xbbbbbbbb]
	mov bl,[a64 rel qword fs:0xbbbbbbbb]
	mov ax,[a64 rel qword fs:0xbbbbbbbb]
	mov bx,[a64 rel qword fs:0xbbbbbbbb]
	mov eax,[a64 rel qword fs:0xbbbbbbbb]
	mov ebx,[a64 rel qword fs:0xbbbbbbbb]
	mov rax,[a64 rel qword fs:0xbbbbbbbb]
	mov rbx,[a64 rel qword fs:0xbbbbbbbb]
	mov al,[a64 rel qword fs:0xffffffffcccccccc]
	mov bl,[a64 rel qword fs:0xffffffffcccccccc]
	mov ax,[a64 rel qword fs:0xffffffffcccccccc]
	mov bx,[a64 rel qword fs:0xffffffffcccccccc]
	mov eax,[a64 rel qword fs:0xffffffffcccccccc]
	mov ebx,[a64 rel qword fs:0xffffffffcccccccc]
	mov rax,[a64 rel qword fs:0xffffffffcccccccc]
	mov rbx,[a64 rel qword fs:0xffffffffcccccccc]

	mov al,[a32 rel fs:foo]
	mov bl,[a32 rel fs:foo]
	mov ax,[a32 rel fs:foo]
	mov bx,[a32 rel fs:foo]
	mov eax,[a32 rel fs:foo]
	mov ebx,[a32 rel fs:foo]
	mov rax,[a32 rel fs:foo]
	mov rbx,[a32 rel fs:foo]
	mov al,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel fs:0xbbbbbbbb]
	mov bl,[a32 rel fs:0xbbbbbbbb]
	mov ax,[a32 rel fs:0xbbbbbbbb]
	mov bx,[a32 rel fs:0xbbbbbbbb]
	mov eax,[a32 rel fs:0xbbbbbbbb]
	mov ebx,[a32 rel fs:0xbbbbbbbb]
	mov rax,[a32 rel fs:0xbbbbbbbb]
	mov rbx,[a32 rel fs:0xbbbbbbbb]
	mov al,[a32 rel fs:0xffffffffcccccccc]
	mov bl,[a32 rel fs:0xffffffffcccccccc]
	mov ax,[a32 rel fs:0xffffffffcccccccc]
	mov bx,[a32 rel fs:0xffffffffcccccccc]
	mov eax,[a32 rel fs:0xffffffffcccccccc]
	mov ebx,[a32 rel fs:0xffffffffcccccccc]
	mov rax,[a32 rel fs:0xffffffffcccccccc]
	mov rbx,[a32 rel fs:0xffffffffcccccccc]

	mov al,[a32 rel dword fs:foo]
	mov bl,[a32 rel dword fs:foo]
	mov ax,[a32 rel dword fs:foo]
	mov bx,[a32 rel dword fs:foo]
	mov eax,[a32 rel dword fs:foo]
	mov ebx,[a32 rel dword fs:foo]
	mov rax,[a32 rel dword fs:foo]
	mov rbx,[a32 rel dword fs:foo]
	mov al,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword fs:0xbbbbbbbb]
	mov bl,[a32 rel dword fs:0xbbbbbbbb]
	mov ax,[a32 rel dword fs:0xbbbbbbbb]
	mov bx,[a32 rel dword fs:0xbbbbbbbb]
	mov eax,[a32 rel dword fs:0xbbbbbbbb]
	mov ebx,[a32 rel dword fs:0xbbbbbbbb]
	mov rax,[a32 rel dword fs:0xbbbbbbbb]
	mov rbx,[a32 rel dword fs:0xbbbbbbbb]
	mov al,[a32 rel dword fs:0xffffffffcccccccc]
	mov bl,[a32 rel dword fs:0xffffffffcccccccc]
	mov ax,[a32 rel dword fs:0xffffffffcccccccc]
	mov bx,[a32 rel dword fs:0xffffffffcccccccc]
	mov eax,[a32 rel dword fs:0xffffffffcccccccc]
	mov ebx,[a32 rel dword fs:0xffffffffcccccccc]
	mov rax,[a32 rel dword fs:0xffffffffcccccccc]
	mov rbx,[a32 rel dword fs:0xffffffffcccccccc]

	mov al,[a32 rel qword fs:foo]
	mov bl,[a32 rel qword fs:foo]
	mov ax,[a32 rel qword fs:foo]
	mov bx,[a32 rel qword fs:foo]
	mov eax,[a32 rel qword fs:foo]
	mov ebx,[a32 rel qword fs:foo]
	mov rax,[a32 rel qword fs:foo]
	mov rbx,[a32 rel qword fs:foo]
	mov al,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword fs:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword fs:0xbbbbbbbb]
	mov bl,[a32 rel qword fs:0xbbbbbbbb]
	mov ax,[a32 rel qword fs:0xbbbbbbbb]
	mov bx,[a32 rel qword fs:0xbbbbbbbb]
	mov eax,[a32 rel qword fs:0xbbbbbbbb]
	mov ebx,[a32 rel qword fs:0xbbbbbbbb]
	mov rax,[a32 rel qword fs:0xbbbbbbbb]
	mov rbx,[a32 rel qword fs:0xbbbbbbbb]
	mov al,[a32 rel qword fs:0xffffffffcccccccc]
	mov bl,[a32 rel qword fs:0xffffffffcccccccc]
	mov ax,[a32 rel qword fs:0xffffffffcccccccc]
	mov bx,[a32 rel qword fs:0xffffffffcccccccc]
	mov eax,[a32 rel qword fs:0xffffffffcccccccc]
	mov ebx,[a32 rel qword fs:0xffffffffcccccccc]
	mov rax,[a32 rel qword fs:0xffffffffcccccccc]
	mov rbx,[a32 rel qword fs:0xffffffffcccccccc]

	mov al,[es:foo]
	mov bl,[es:foo]
	mov ax,[es:foo]
	mov bx,[es:foo]
	mov eax,[es:foo]
	mov ebx,[es:foo]
	mov rax,[es:foo]
	mov rbx,[es:foo]
	mov al,[es:0xaaaaaaaaaaaaaaaa]
	mov bl,[es:0xaaaaaaaaaaaaaaaa]
	mov ax,[es:0xaaaaaaaaaaaaaaaa]
	mov bx,[es:0xaaaaaaaaaaaaaaaa]
	mov eax,[es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[es:0xaaaaaaaaaaaaaaaa]
	mov rax,[es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[es:0xaaaaaaaaaaaaaaaa]
	mov al,[es:0xbbbbbbbb]
	mov bl,[es:0xbbbbbbbb]
	mov ax,[es:0xbbbbbbbb]
	mov bx,[es:0xbbbbbbbb]
	mov eax,[es:0xbbbbbbbb]
	mov ebx,[es:0xbbbbbbbb]
	mov rax,[es:0xbbbbbbbb]
	mov rbx,[es:0xbbbbbbbb]
	mov al,[es:0xffffffffcccccccc]
	mov bl,[es:0xffffffffcccccccc]
	mov ax,[es:0xffffffffcccccccc]
	mov bx,[es:0xffffffffcccccccc]
	mov eax,[es:0xffffffffcccccccc]
	mov ebx,[es:0xffffffffcccccccc]
	mov rax,[es:0xffffffffcccccccc]
	mov rbx,[es:0xffffffffcccccccc]

	mov al,[dword es:foo]
	mov bl,[dword es:foo]
	mov ax,[dword es:foo]
	mov bx,[dword es:foo]
	mov eax,[dword es:foo]
	mov ebx,[dword es:foo]
	mov rax,[dword es:foo]
	mov rbx,[dword es:foo]
	mov al,[dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[dword es:0xbbbbbbbb]
	mov bl,[dword es:0xbbbbbbbb]
	mov ax,[dword es:0xbbbbbbbb]
	mov bx,[dword es:0xbbbbbbbb]
	mov eax,[dword es:0xbbbbbbbb]
	mov ebx,[dword es:0xbbbbbbbb]
	mov rax,[dword es:0xbbbbbbbb]
	mov rbx,[dword es:0xbbbbbbbb]
	mov al,[dword es:0xffffffffcccccccc]
	mov bl,[dword es:0xffffffffcccccccc]
	mov ax,[dword es:0xffffffffcccccccc]
	mov bx,[dword es:0xffffffffcccccccc]
	mov eax,[dword es:0xffffffffcccccccc]
	mov ebx,[dword es:0xffffffffcccccccc]
	mov rax,[dword es:0xffffffffcccccccc]
	mov rbx,[dword es:0xffffffffcccccccc]

	mov al,[qword es:foo]
	mov bl,[qword es:foo]
	mov ax,[qword es:foo]
	mov bx,[qword es:foo]
	mov eax,[qword es:foo]
	mov ebx,[qword es:foo]
	mov rax,[qword es:foo]
	mov rbx,[qword es:foo]
	mov al,[qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[qword es:0xbbbbbbbb]
	mov bl,[qword es:0xbbbbbbbb]
	mov ax,[qword es:0xbbbbbbbb]
	mov bx,[qword es:0xbbbbbbbb]
	mov eax,[qword es:0xbbbbbbbb]
	mov ebx,[qword es:0xbbbbbbbb]
	mov rax,[qword es:0xbbbbbbbb]
	mov rbx,[qword es:0xbbbbbbbb]
	mov al,[qword es:0xffffffffcccccccc]
	mov bl,[qword es:0xffffffffcccccccc]
	mov ax,[qword es:0xffffffffcccccccc]
	mov bx,[qword es:0xffffffffcccccccc]
	mov eax,[qword es:0xffffffffcccccccc]
	mov ebx,[qword es:0xffffffffcccccccc]
	mov rax,[qword es:0xffffffffcccccccc]
	mov rbx,[qword es:0xffffffffcccccccc]

	mov al,[a64 es:foo]
	mov bl,[a64 es:foo]
	mov ax,[a64 es:foo]
	mov bx,[a64 es:foo]
	mov eax,[a64 es:foo]
	mov ebx,[a64 es:foo]
	mov rax,[a64 es:foo]
	mov rbx,[a64 es:foo]
	mov al,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 es:0xbbbbbbbb]
	mov bl,[a64 es:0xbbbbbbbb]
	mov ax,[a64 es:0xbbbbbbbb]
	mov bx,[a64 es:0xbbbbbbbb]
	mov eax,[a64 es:0xbbbbbbbb]
	mov ebx,[a64 es:0xbbbbbbbb]
	mov rax,[a64 es:0xbbbbbbbb]
	mov rbx,[a64 es:0xbbbbbbbb]
	mov al,[a64 es:0xffffffffcccccccc]
	mov bl,[a64 es:0xffffffffcccccccc]
	mov ax,[a64 es:0xffffffffcccccccc]
	mov bx,[a64 es:0xffffffffcccccccc]
	mov eax,[a64 es:0xffffffffcccccccc]
	mov ebx,[a64 es:0xffffffffcccccccc]
	mov rax,[a64 es:0xffffffffcccccccc]
	mov rbx,[a64 es:0xffffffffcccccccc]

	mov al,[a64 dword es:foo]
	mov bl,[a64 dword es:foo]
	mov ax,[a64 dword es:foo]
	mov bx,[a64 dword es:foo]
	mov eax,[a64 dword es:foo]
	mov ebx,[a64 dword es:foo]
	mov rax,[a64 dword es:foo]
	mov rbx,[a64 dword es:foo]
	mov al,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 dword es:0xbbbbbbbb]
	mov bl,[a64 dword es:0xbbbbbbbb]
	mov ax,[a64 dword es:0xbbbbbbbb]
	mov bx,[a64 dword es:0xbbbbbbbb]
	mov eax,[a64 dword es:0xbbbbbbbb]
	mov ebx,[a64 dword es:0xbbbbbbbb]
	mov rax,[a64 dword es:0xbbbbbbbb]
	mov rbx,[a64 dword es:0xbbbbbbbb]
	mov al,[a64 dword es:0xffffffffcccccccc]
	mov bl,[a64 dword es:0xffffffffcccccccc]
	mov ax,[a64 dword es:0xffffffffcccccccc]
	mov bx,[a64 dword es:0xffffffffcccccccc]
	mov eax,[a64 dword es:0xffffffffcccccccc]
	mov ebx,[a64 dword es:0xffffffffcccccccc]
	mov rax,[a64 dword es:0xffffffffcccccccc]
	mov rbx,[a64 dword es:0xffffffffcccccccc]

	mov al,[a64 qword es:foo]
	mov bl,[a64 qword es:foo]
	mov ax,[a64 qword es:foo]
	mov bx,[a64 qword es:foo]
	mov eax,[a64 qword es:foo]
	mov ebx,[a64 qword es:foo]
	mov rax,[a64 qword es:foo]
	mov rbx,[a64 qword es:foo]
	mov al,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 qword es:0xbbbbbbbb]
	mov bl,[a64 qword es:0xbbbbbbbb]
	mov ax,[a64 qword es:0xbbbbbbbb]
	mov bx,[a64 qword es:0xbbbbbbbb]
	mov eax,[a64 qword es:0xbbbbbbbb]
	mov ebx,[a64 qword es:0xbbbbbbbb]
	mov rax,[a64 qword es:0xbbbbbbbb]
	mov rbx,[a64 qword es:0xbbbbbbbb]
	mov al,[a64 qword es:0xffffffffcccccccc]
	mov bl,[a64 qword es:0xffffffffcccccccc]
	mov ax,[a64 qword es:0xffffffffcccccccc]
	mov bx,[a64 qword es:0xffffffffcccccccc]
	mov eax,[a64 qword es:0xffffffffcccccccc]
	mov ebx,[a64 qword es:0xffffffffcccccccc]
	mov rax,[a64 qword es:0xffffffffcccccccc]
	mov rbx,[a64 qword es:0xffffffffcccccccc]

	mov al,[a32 es:foo]
	mov bl,[a32 es:foo]
	mov ax,[a32 es:foo]
	mov bx,[a32 es:foo]
	mov eax,[a32 es:foo]
	mov ebx,[a32 es:foo]
	mov rax,[a32 es:foo]
	mov rbx,[a32 es:foo]
	mov al,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 es:0xbbbbbbbb]
	mov bl,[a32 es:0xbbbbbbbb]
	mov ax,[a32 es:0xbbbbbbbb]
	mov bx,[a32 es:0xbbbbbbbb]
	mov eax,[a32 es:0xbbbbbbbb]
	mov ebx,[a32 es:0xbbbbbbbb]
	mov rax,[a32 es:0xbbbbbbbb]
	mov rbx,[a32 es:0xbbbbbbbb]
	mov al,[a32 es:0xffffffffcccccccc]
	mov bl,[a32 es:0xffffffffcccccccc]
	mov ax,[a32 es:0xffffffffcccccccc]
	mov bx,[a32 es:0xffffffffcccccccc]
	mov eax,[a32 es:0xffffffffcccccccc]
	mov ebx,[a32 es:0xffffffffcccccccc]
	mov rax,[a32 es:0xffffffffcccccccc]
	mov rbx,[a32 es:0xffffffffcccccccc]

	mov al,[a32 dword es:foo]
	mov bl,[a32 dword es:foo]
	mov ax,[a32 dword es:foo]
	mov bx,[a32 dword es:foo]
	mov eax,[a32 dword es:foo]
	mov ebx,[a32 dword es:foo]
	mov rax,[a32 dword es:foo]
	mov rbx,[a32 dword es:foo]
	mov al,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 dword es:0xbbbbbbbb]
	mov bl,[a32 dword es:0xbbbbbbbb]
	mov ax,[a32 dword es:0xbbbbbbbb]
	mov bx,[a32 dword es:0xbbbbbbbb]
	mov eax,[a32 dword es:0xbbbbbbbb]
	mov ebx,[a32 dword es:0xbbbbbbbb]
	mov rax,[a32 dword es:0xbbbbbbbb]
	mov rbx,[a32 dword es:0xbbbbbbbb]
	mov al,[a32 dword es:0xffffffffcccccccc]
	mov bl,[a32 dword es:0xffffffffcccccccc]
	mov ax,[a32 dword es:0xffffffffcccccccc]
	mov bx,[a32 dword es:0xffffffffcccccccc]
	mov eax,[a32 dword es:0xffffffffcccccccc]
	mov ebx,[a32 dword es:0xffffffffcccccccc]
	mov rax,[a32 dword es:0xffffffffcccccccc]
	mov rbx,[a32 dword es:0xffffffffcccccccc]

	mov al,[a32 qword es:foo]
	mov bl,[a32 qword es:foo]
	mov ax,[a32 qword es:foo]
	mov bx,[a32 qword es:foo]
	mov eax,[a32 qword es:foo]
	mov ebx,[a32 qword es:foo]
	mov rax,[a32 qword es:foo]
	mov rbx,[a32 qword es:foo]
	mov al,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 qword es:0xbbbbbbbb]
	mov bl,[a32 qword es:0xbbbbbbbb]
	mov ax,[a32 qword es:0xbbbbbbbb]
	mov bx,[a32 qword es:0xbbbbbbbb]
	mov eax,[a32 qword es:0xbbbbbbbb]
	mov ebx,[a32 qword es:0xbbbbbbbb]
	mov rax,[a32 qword es:0xbbbbbbbb]
	mov rbx,[a32 qword es:0xbbbbbbbb]
	mov al,[a32 qword es:0xffffffffcccccccc]
	mov bl,[a32 qword es:0xffffffffcccccccc]
	mov ax,[a32 qword es:0xffffffffcccccccc]
	mov bx,[a32 qword es:0xffffffffcccccccc]
	mov eax,[a32 qword es:0xffffffffcccccccc]
	mov ebx,[a32 qword es:0xffffffffcccccccc]
	mov rax,[a32 qword es:0xffffffffcccccccc]
	mov rbx,[a32 qword es:0xffffffffcccccccc]

	mov al,[abs es:foo]
	mov bl,[abs es:foo]
	mov ax,[abs es:foo]
	mov bx,[abs es:foo]
	mov eax,[abs es:foo]
	mov ebx,[abs es:foo]
	mov rax,[abs es:foo]
	mov rbx,[abs es:foo]
	mov al,[abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs es:0xbbbbbbbb]
	mov bl,[abs es:0xbbbbbbbb]
	mov ax,[abs es:0xbbbbbbbb]
	mov bx,[abs es:0xbbbbbbbb]
	mov eax,[abs es:0xbbbbbbbb]
	mov ebx,[abs es:0xbbbbbbbb]
	mov rax,[abs es:0xbbbbbbbb]
	mov rbx,[abs es:0xbbbbbbbb]
	mov al,[abs es:0xffffffffcccccccc]
	mov bl,[abs es:0xffffffffcccccccc]
	mov ax,[abs es:0xffffffffcccccccc]
	mov bx,[abs es:0xffffffffcccccccc]
	mov eax,[abs es:0xffffffffcccccccc]
	mov ebx,[abs es:0xffffffffcccccccc]
	mov rax,[abs es:0xffffffffcccccccc]
	mov rbx,[abs es:0xffffffffcccccccc]

	mov al,[abs dword es:foo]
	mov bl,[abs dword es:foo]
	mov ax,[abs dword es:foo]
	mov bx,[abs dword es:foo]
	mov eax,[abs dword es:foo]
	mov ebx,[abs dword es:foo]
	mov rax,[abs dword es:foo]
	mov rbx,[abs dword es:foo]
	mov al,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs dword es:0xbbbbbbbb]
	mov bl,[abs dword es:0xbbbbbbbb]
	mov ax,[abs dword es:0xbbbbbbbb]
	mov bx,[abs dword es:0xbbbbbbbb]
	mov eax,[abs dword es:0xbbbbbbbb]
	mov ebx,[abs dword es:0xbbbbbbbb]
	mov rax,[abs dword es:0xbbbbbbbb]
	mov rbx,[abs dword es:0xbbbbbbbb]
	mov al,[abs dword es:0xffffffffcccccccc]
	mov bl,[abs dword es:0xffffffffcccccccc]
	mov ax,[abs dword es:0xffffffffcccccccc]
	mov bx,[abs dword es:0xffffffffcccccccc]
	mov eax,[abs dword es:0xffffffffcccccccc]
	mov ebx,[abs dword es:0xffffffffcccccccc]
	mov rax,[abs dword es:0xffffffffcccccccc]
	mov rbx,[abs dword es:0xffffffffcccccccc]

	mov al,[abs qword es:foo]
	mov bl,[abs qword es:foo]
	mov ax,[abs qword es:foo]
	mov bx,[abs qword es:foo]
	mov eax,[abs qword es:foo]
	mov ebx,[abs qword es:foo]
	mov rax,[abs qword es:foo]
	mov rbx,[abs qword es:foo]
	mov al,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[abs qword es:0xbbbbbbbb]
	mov bl,[abs qword es:0xbbbbbbbb]
	mov ax,[abs qword es:0xbbbbbbbb]
	mov bx,[abs qword es:0xbbbbbbbb]
	mov eax,[abs qword es:0xbbbbbbbb]
	mov ebx,[abs qword es:0xbbbbbbbb]
	mov rax,[abs qword es:0xbbbbbbbb]
	mov rbx,[abs qword es:0xbbbbbbbb]
	mov al,[abs qword es:0xffffffffcccccccc]
	mov bl,[abs qword es:0xffffffffcccccccc]
	mov ax,[abs qword es:0xffffffffcccccccc]
	mov bx,[abs qword es:0xffffffffcccccccc]
	mov eax,[abs qword es:0xffffffffcccccccc]
	mov ebx,[abs qword es:0xffffffffcccccccc]
	mov rax,[abs qword es:0xffffffffcccccccc]
	mov rbx,[abs qword es:0xffffffffcccccccc]

	mov al,[a64 abs es:foo]
	mov bl,[a64 abs es:foo]
	mov ax,[a64 abs es:foo]
	mov bx,[a64 abs es:foo]
	mov eax,[a64 abs es:foo]
	mov ebx,[a64 abs es:foo]
	mov rax,[a64 abs es:foo]
	mov rbx,[a64 abs es:foo]
	mov al,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs es:0xbbbbbbbb]
	mov bl,[a64 abs es:0xbbbbbbbb]
	mov ax,[a64 abs es:0xbbbbbbbb]
	mov bx,[a64 abs es:0xbbbbbbbb]
	mov eax,[a64 abs es:0xbbbbbbbb]
	mov ebx,[a64 abs es:0xbbbbbbbb]
	mov rax,[a64 abs es:0xbbbbbbbb]
	mov rbx,[a64 abs es:0xbbbbbbbb]
	mov al,[a64 abs es:0xffffffffcccccccc]
	mov bl,[a64 abs es:0xffffffffcccccccc]
	mov ax,[a64 abs es:0xffffffffcccccccc]
	mov bx,[a64 abs es:0xffffffffcccccccc]
	mov eax,[a64 abs es:0xffffffffcccccccc]
	mov ebx,[a64 abs es:0xffffffffcccccccc]
	mov rax,[a64 abs es:0xffffffffcccccccc]
	mov rbx,[a64 abs es:0xffffffffcccccccc]

	mov al,[a64 abs dword es:foo]
	mov bl,[a64 abs dword es:foo]
	mov ax,[a64 abs dword es:foo]
	mov bx,[a64 abs dword es:foo]
	mov eax,[a64 abs dword es:foo]
	mov ebx,[a64 abs dword es:foo]
	mov rax,[a64 abs dword es:foo]
	mov rbx,[a64 abs dword es:foo]
	mov al,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs dword es:0xbbbbbbbb]
	mov bl,[a64 abs dword es:0xbbbbbbbb]
	mov ax,[a64 abs dword es:0xbbbbbbbb]
	mov bx,[a64 abs dword es:0xbbbbbbbb]
	mov eax,[a64 abs dword es:0xbbbbbbbb]
	mov ebx,[a64 abs dword es:0xbbbbbbbb]
	mov rax,[a64 abs dword es:0xbbbbbbbb]
	mov rbx,[a64 abs dword es:0xbbbbbbbb]
	mov al,[a64 abs dword es:0xffffffffcccccccc]
	mov bl,[a64 abs dword es:0xffffffffcccccccc]
	mov ax,[a64 abs dword es:0xffffffffcccccccc]
	mov bx,[a64 abs dword es:0xffffffffcccccccc]
	mov eax,[a64 abs dword es:0xffffffffcccccccc]
	mov ebx,[a64 abs dword es:0xffffffffcccccccc]
	mov rax,[a64 abs dword es:0xffffffffcccccccc]
	mov rbx,[a64 abs dword es:0xffffffffcccccccc]

	mov al,[a64 abs qword es:foo]
	mov bl,[a64 abs qword es:foo]
	mov ax,[a64 abs qword es:foo]
	mov bx,[a64 abs qword es:foo]
	mov eax,[a64 abs qword es:foo]
	mov ebx,[a64 abs qword es:foo]
	mov rax,[a64 abs qword es:foo]
	mov rbx,[a64 abs qword es:foo]
	mov al,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 abs qword es:0xbbbbbbbb]
	mov bl,[a64 abs qword es:0xbbbbbbbb]
	mov ax,[a64 abs qword es:0xbbbbbbbb]
	mov bx,[a64 abs qword es:0xbbbbbbbb]
	mov eax,[a64 abs qword es:0xbbbbbbbb]
	mov ebx,[a64 abs qword es:0xbbbbbbbb]
	mov rax,[a64 abs qword es:0xbbbbbbbb]
	mov rbx,[a64 abs qword es:0xbbbbbbbb]
	mov al,[a64 abs qword es:0xffffffffcccccccc]
	mov bl,[a64 abs qword es:0xffffffffcccccccc]
	mov ax,[a64 abs qword es:0xffffffffcccccccc]
	mov bx,[a64 abs qword es:0xffffffffcccccccc]
	mov eax,[a64 abs qword es:0xffffffffcccccccc]
	mov ebx,[a64 abs qword es:0xffffffffcccccccc]
	mov rax,[a64 abs qword es:0xffffffffcccccccc]
	mov rbx,[a64 abs qword es:0xffffffffcccccccc]

	mov al,[a32 abs es:foo]
	mov bl,[a32 abs es:foo]
	mov ax,[a32 abs es:foo]
	mov bx,[a32 abs es:foo]
	mov eax,[a32 abs es:foo]
	mov ebx,[a32 abs es:foo]
	mov rax,[a32 abs es:foo]
	mov rbx,[a32 abs es:foo]
	mov al,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs es:0xbbbbbbbb]
	mov bl,[a32 abs es:0xbbbbbbbb]
	mov ax,[a32 abs es:0xbbbbbbbb]
	mov bx,[a32 abs es:0xbbbbbbbb]
	mov eax,[a32 abs es:0xbbbbbbbb]
	mov ebx,[a32 abs es:0xbbbbbbbb]
	mov rax,[a32 abs es:0xbbbbbbbb]
	mov rbx,[a32 abs es:0xbbbbbbbb]
	mov al,[a32 abs es:0xffffffffcccccccc]
	mov bl,[a32 abs es:0xffffffffcccccccc]
	mov ax,[a32 abs es:0xffffffffcccccccc]
	mov bx,[a32 abs es:0xffffffffcccccccc]
	mov eax,[a32 abs es:0xffffffffcccccccc]
	mov ebx,[a32 abs es:0xffffffffcccccccc]
	mov rax,[a32 abs es:0xffffffffcccccccc]
	mov rbx,[a32 abs es:0xffffffffcccccccc]

	mov al,[a32 abs dword es:foo]
	mov bl,[a32 abs dword es:foo]
	mov ax,[a32 abs dword es:foo]
	mov bx,[a32 abs dword es:foo]
	mov eax,[a32 abs dword es:foo]
	mov ebx,[a32 abs dword es:foo]
	mov rax,[a32 abs dword es:foo]
	mov rbx,[a32 abs dword es:foo]
	mov al,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs dword es:0xbbbbbbbb]
	mov bl,[a32 abs dword es:0xbbbbbbbb]
	mov ax,[a32 abs dword es:0xbbbbbbbb]
	mov bx,[a32 abs dword es:0xbbbbbbbb]
	mov eax,[a32 abs dword es:0xbbbbbbbb]
	mov ebx,[a32 abs dword es:0xbbbbbbbb]
	mov rax,[a32 abs dword es:0xbbbbbbbb]
	mov rbx,[a32 abs dword es:0xbbbbbbbb]
	mov al,[a32 abs dword es:0xffffffffcccccccc]
	mov bl,[a32 abs dword es:0xffffffffcccccccc]
	mov ax,[a32 abs dword es:0xffffffffcccccccc]
	mov bx,[a32 abs dword es:0xffffffffcccccccc]
	mov eax,[a32 abs dword es:0xffffffffcccccccc]
	mov ebx,[a32 abs dword es:0xffffffffcccccccc]
	mov rax,[a32 abs dword es:0xffffffffcccccccc]
	mov rbx,[a32 abs dword es:0xffffffffcccccccc]

	mov al,[a32 abs qword es:foo]
	mov bl,[a32 abs qword es:foo]
	mov ax,[a32 abs qword es:foo]
	mov bx,[a32 abs qword es:foo]
	mov eax,[a32 abs qword es:foo]
	mov ebx,[a32 abs qword es:foo]
	mov rax,[a32 abs qword es:foo]
	mov rbx,[a32 abs qword es:foo]
	mov al,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 abs qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 abs qword es:0xbbbbbbbb]
	mov bl,[a32 abs qword es:0xbbbbbbbb]
	mov ax,[a32 abs qword es:0xbbbbbbbb]
	mov bx,[a32 abs qword es:0xbbbbbbbb]
	mov eax,[a32 abs qword es:0xbbbbbbbb]
	mov ebx,[a32 abs qword es:0xbbbbbbbb]
	mov rax,[a32 abs qword es:0xbbbbbbbb]
	mov rbx,[a32 abs qword es:0xbbbbbbbb]
	mov al,[a32 abs qword es:0xffffffffcccccccc]
	mov bl,[a32 abs qword es:0xffffffffcccccccc]
	mov ax,[a32 abs qword es:0xffffffffcccccccc]
	mov bx,[a32 abs qword es:0xffffffffcccccccc]
	mov eax,[a32 abs qword es:0xffffffffcccccccc]
	mov ebx,[a32 abs qword es:0xffffffffcccccccc]
	mov rax,[a32 abs qword es:0xffffffffcccccccc]
	mov rbx,[a32 abs qword es:0xffffffffcccccccc]

	mov al,[rel es:foo]
	mov bl,[rel es:foo]
	mov ax,[rel es:foo]
	mov bx,[rel es:foo]
	mov eax,[rel es:foo]
	mov ebx,[rel es:foo]
	mov rax,[rel es:foo]
	mov rbx,[rel es:foo]
	mov al,[rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel es:0xbbbbbbbb]
	mov bl,[rel es:0xbbbbbbbb]
	mov ax,[rel es:0xbbbbbbbb]
	mov bx,[rel es:0xbbbbbbbb]
	mov eax,[rel es:0xbbbbbbbb]
	mov ebx,[rel es:0xbbbbbbbb]
	mov rax,[rel es:0xbbbbbbbb]
	mov rbx,[rel es:0xbbbbbbbb]
	mov al,[rel es:0xffffffffcccccccc]
	mov bl,[rel es:0xffffffffcccccccc]
	mov ax,[rel es:0xffffffffcccccccc]
	mov bx,[rel es:0xffffffffcccccccc]
	mov eax,[rel es:0xffffffffcccccccc]
	mov ebx,[rel es:0xffffffffcccccccc]
	mov rax,[rel es:0xffffffffcccccccc]
	mov rbx,[rel es:0xffffffffcccccccc]

	mov al,[rel dword es:foo]
	mov bl,[rel dword es:foo]
	mov ax,[rel dword es:foo]
	mov bx,[rel dword es:foo]
	mov eax,[rel dword es:foo]
	mov ebx,[rel dword es:foo]
	mov rax,[rel dword es:foo]
	mov rbx,[rel dword es:foo]
	mov al,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel dword es:0xbbbbbbbb]
	mov bl,[rel dword es:0xbbbbbbbb]
	mov ax,[rel dword es:0xbbbbbbbb]
	mov bx,[rel dword es:0xbbbbbbbb]
	mov eax,[rel dword es:0xbbbbbbbb]
	mov ebx,[rel dword es:0xbbbbbbbb]
	mov rax,[rel dword es:0xbbbbbbbb]
	mov rbx,[rel dword es:0xbbbbbbbb]
	mov al,[rel dword es:0xffffffffcccccccc]
	mov bl,[rel dword es:0xffffffffcccccccc]
	mov ax,[rel dword es:0xffffffffcccccccc]
	mov bx,[rel dword es:0xffffffffcccccccc]
	mov eax,[rel dword es:0xffffffffcccccccc]
	mov ebx,[rel dword es:0xffffffffcccccccc]
	mov rax,[rel dword es:0xffffffffcccccccc]
	mov rbx,[rel dword es:0xffffffffcccccccc]

	mov al,[rel qword es:foo]
	mov bl,[rel qword es:foo]
	mov ax,[rel qword es:foo]
	mov bx,[rel qword es:foo]
	mov eax,[rel qword es:foo]
	mov ebx,[rel qword es:foo]
	mov rax,[rel qword es:foo]
	mov rbx,[rel qword es:foo]
	mov al,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[rel qword es:0xbbbbbbbb]
	mov bl,[rel qword es:0xbbbbbbbb]
	mov ax,[rel qword es:0xbbbbbbbb]
	mov bx,[rel qword es:0xbbbbbbbb]
	mov eax,[rel qword es:0xbbbbbbbb]
	mov ebx,[rel qword es:0xbbbbbbbb]
	mov rax,[rel qword es:0xbbbbbbbb]
	mov rbx,[rel qword es:0xbbbbbbbb]
	mov al,[rel qword es:0xffffffffcccccccc]
	mov bl,[rel qword es:0xffffffffcccccccc]
	mov ax,[rel qword es:0xffffffffcccccccc]
	mov bx,[rel qword es:0xffffffffcccccccc]
	mov eax,[rel qword es:0xffffffffcccccccc]
	mov ebx,[rel qword es:0xffffffffcccccccc]
	mov rax,[rel qword es:0xffffffffcccccccc]
	mov rbx,[rel qword es:0xffffffffcccccccc]

	mov al,[a64 rel es:foo]
	mov bl,[a64 rel es:foo]
	mov ax,[a64 rel es:foo]
	mov bx,[a64 rel es:foo]
	mov eax,[a64 rel es:foo]
	mov ebx,[a64 rel es:foo]
	mov rax,[a64 rel es:foo]
	mov rbx,[a64 rel es:foo]
	mov al,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel es:0xbbbbbbbb]
	mov bl,[a64 rel es:0xbbbbbbbb]
	mov ax,[a64 rel es:0xbbbbbbbb]
	mov bx,[a64 rel es:0xbbbbbbbb]
	mov eax,[a64 rel es:0xbbbbbbbb]
	mov ebx,[a64 rel es:0xbbbbbbbb]
	mov rax,[a64 rel es:0xbbbbbbbb]
	mov rbx,[a64 rel es:0xbbbbbbbb]
	mov al,[a64 rel es:0xffffffffcccccccc]
	mov bl,[a64 rel es:0xffffffffcccccccc]
	mov ax,[a64 rel es:0xffffffffcccccccc]
	mov bx,[a64 rel es:0xffffffffcccccccc]
	mov eax,[a64 rel es:0xffffffffcccccccc]
	mov ebx,[a64 rel es:0xffffffffcccccccc]
	mov rax,[a64 rel es:0xffffffffcccccccc]
	mov rbx,[a64 rel es:0xffffffffcccccccc]

	mov al,[a64 rel dword es:foo]
	mov bl,[a64 rel dword es:foo]
	mov ax,[a64 rel dword es:foo]
	mov bx,[a64 rel dword es:foo]
	mov eax,[a64 rel dword es:foo]
	mov ebx,[a64 rel dword es:foo]
	mov rax,[a64 rel dword es:foo]
	mov rbx,[a64 rel dword es:foo]
	mov al,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel dword es:0xbbbbbbbb]
	mov bl,[a64 rel dword es:0xbbbbbbbb]
	mov ax,[a64 rel dword es:0xbbbbbbbb]
	mov bx,[a64 rel dword es:0xbbbbbbbb]
	mov eax,[a64 rel dword es:0xbbbbbbbb]
	mov ebx,[a64 rel dword es:0xbbbbbbbb]
	mov rax,[a64 rel dword es:0xbbbbbbbb]
	mov rbx,[a64 rel dword es:0xbbbbbbbb]
	mov al,[a64 rel dword es:0xffffffffcccccccc]
	mov bl,[a64 rel dword es:0xffffffffcccccccc]
	mov ax,[a64 rel dword es:0xffffffffcccccccc]
	mov bx,[a64 rel dword es:0xffffffffcccccccc]
	mov eax,[a64 rel dword es:0xffffffffcccccccc]
	mov ebx,[a64 rel dword es:0xffffffffcccccccc]
	mov rax,[a64 rel dword es:0xffffffffcccccccc]
	mov rbx,[a64 rel dword es:0xffffffffcccccccc]

	mov al,[a64 rel qword es:foo]
	mov bl,[a64 rel qword es:foo]
	mov ax,[a64 rel qword es:foo]
	mov bx,[a64 rel qword es:foo]
	mov eax,[a64 rel qword es:foo]
	mov ebx,[a64 rel qword es:foo]
	mov rax,[a64 rel qword es:foo]
	mov rbx,[a64 rel qword es:foo]
	mov al,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a64 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a64 rel qword es:0xbbbbbbbb]
	mov bl,[a64 rel qword es:0xbbbbbbbb]
	mov ax,[a64 rel qword es:0xbbbbbbbb]
	mov bx,[a64 rel qword es:0xbbbbbbbb]
	mov eax,[a64 rel qword es:0xbbbbbbbb]
	mov ebx,[a64 rel qword es:0xbbbbbbbb]
	mov rax,[a64 rel qword es:0xbbbbbbbb]
	mov rbx,[a64 rel qword es:0xbbbbbbbb]
	mov al,[a64 rel qword es:0xffffffffcccccccc]
	mov bl,[a64 rel qword es:0xffffffffcccccccc]
	mov ax,[a64 rel qword es:0xffffffffcccccccc]
	mov bx,[a64 rel qword es:0xffffffffcccccccc]
	mov eax,[a64 rel qword es:0xffffffffcccccccc]
	mov ebx,[a64 rel qword es:0xffffffffcccccccc]
	mov rax,[a64 rel qword es:0xffffffffcccccccc]
	mov rbx,[a64 rel qword es:0xffffffffcccccccc]

	mov al,[a32 rel es:foo]
	mov bl,[a32 rel es:foo]
	mov ax,[a32 rel es:foo]
	mov bx,[a32 rel es:foo]
	mov eax,[a32 rel es:foo]
	mov ebx,[a32 rel es:foo]
	mov rax,[a32 rel es:foo]
	mov rbx,[a32 rel es:foo]
	mov al,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel es:0xbbbbbbbb]
	mov bl,[a32 rel es:0xbbbbbbbb]
	mov ax,[a32 rel es:0xbbbbbbbb]
	mov bx,[a32 rel es:0xbbbbbbbb]
	mov eax,[a32 rel es:0xbbbbbbbb]
	mov ebx,[a32 rel es:0xbbbbbbbb]
	mov rax,[a32 rel es:0xbbbbbbbb]
	mov rbx,[a32 rel es:0xbbbbbbbb]
	mov al,[a32 rel es:0xffffffffcccccccc]
	mov bl,[a32 rel es:0xffffffffcccccccc]
	mov ax,[a32 rel es:0xffffffffcccccccc]
	mov bx,[a32 rel es:0xffffffffcccccccc]
	mov eax,[a32 rel es:0xffffffffcccccccc]
	mov ebx,[a32 rel es:0xffffffffcccccccc]
	mov rax,[a32 rel es:0xffffffffcccccccc]
	mov rbx,[a32 rel es:0xffffffffcccccccc]

	mov al,[a32 rel dword es:foo]
	mov bl,[a32 rel dword es:foo]
	mov ax,[a32 rel dword es:foo]
	mov bx,[a32 rel dword es:foo]
	mov eax,[a32 rel dword es:foo]
	mov ebx,[a32 rel dword es:foo]
	mov rax,[a32 rel dword es:foo]
	mov rbx,[a32 rel dword es:foo]
	mov al,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel dword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel dword es:0xbbbbbbbb]
	mov bl,[a32 rel dword es:0xbbbbbbbb]
	mov ax,[a32 rel dword es:0xbbbbbbbb]
	mov bx,[a32 rel dword es:0xbbbbbbbb]
	mov eax,[a32 rel dword es:0xbbbbbbbb]
	mov ebx,[a32 rel dword es:0xbbbbbbbb]
	mov rax,[a32 rel dword es:0xbbbbbbbb]
	mov rbx,[a32 rel dword es:0xbbbbbbbb]
	mov al,[a32 rel dword es:0xffffffffcccccccc]
	mov bl,[a32 rel dword es:0xffffffffcccccccc]
	mov ax,[a32 rel dword es:0xffffffffcccccccc]
	mov bx,[a32 rel dword es:0xffffffffcccccccc]
	mov eax,[a32 rel dword es:0xffffffffcccccccc]
	mov ebx,[a32 rel dword es:0xffffffffcccccccc]
	mov rax,[a32 rel dword es:0xffffffffcccccccc]
	mov rbx,[a32 rel dword es:0xffffffffcccccccc]

	mov al,[a32 rel qword es:foo]
	mov bl,[a32 rel qword es:foo]
	mov ax,[a32 rel qword es:foo]
	mov bx,[a32 rel qword es:foo]
	mov eax,[a32 rel qword es:foo]
	mov ebx,[a32 rel qword es:foo]
	mov rax,[a32 rel qword es:foo]
	mov rbx,[a32 rel qword es:foo]
	mov al,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bl,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov bx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov eax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov ebx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rax,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov rbx,[a32 rel qword es:0xaaaaaaaaaaaaaaaa]
	mov al,[a32 rel qword es:0xbbbbbbbb]
	mov bl,[a32 rel qword es:0xbbbbbbbb]
	mov ax,[a32 rel qword es:0xbbbbbbbb]
	mov bx,[a32 rel qword es:0xbbbbbbbb]
	mov eax,[a32 rel qword es:0xbbbbbbbb]
	mov ebx,[a32 rel qword es:0xbbbbbbbb]
	mov rax,[a32 rel qword es:0xbbbbbbbb]
	mov rbx,[a32 rel qword es:0xbbbbbbbb]
	mov al,[a32 rel qword es:0xffffffffcccccccc]
	mov bl,[a32 rel qword es:0xffffffffcccccccc]
	mov ax,[a32 rel qword es:0xffffffffcccccccc]
	mov bx,[a32 rel qword es:0xffffffffcccccccc]
	mov eax,[a32 rel qword es:0xffffffffcccccccc]
	mov ebx,[a32 rel qword es:0xffffffffcccccccc]
	mov rax,[a32 rel qword es:0xffffffffcccccccc]
	mov rbx,[a32 rel qword es:0xffffffffcccccccc]


foo:
